1000000000000000000000000000000000A=100:GOTO IgEr+ERE11E:"SMP  rrS1eS$1T"5AVU
1020 MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMag520
<R M0r IU0 T o
ep e:rhEaOeS$eaeMte TA520
0I  -------------------------"
1040 PR0RN eMte"Met ditIIsIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIn"Pr2 o3VTr2
hetieuwe"
1050RINT:PRINT"Rsicode-2 protool S1w subroutine's"
1060 M N"1n  testen. We begeTteo1h VTe
  "U070 HO=15:VE=10
1080  
                                                                                                   aaM 7HO:GOSVU10:GOSVU20H IrM=HOHEN 1080
1090 "HM-1:HO=0
1
 h
EISS0e  etE1 5AVU10: 5AVU20:IF V=VE THEN 1105N T0B ImVM-1: 
1VE=8e"5B 110U120 PRIS9RINT"Als het G02vn, meI:w schebSRD
 PRIN HM+ bpu1S ";VM+1;" karakters. Klo
1
I0
1140 PRINT:PRIPERRn het eind vaelke pe;m  wordtPNjRBaeMte:M  gevraagd O4
Rt0PT1nS ,s0d01x1OmSRd.eMte:P:n  op de P als e;s niekloptf ",mNjRR=0 PR0RN eMte"andeT4
Rwillekeurigeoets e2"
1180 GEa0P


NjRttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt I 1e0=?gI 1e0="pSIE5Ne OP 1tP eMte"We Ranu d R"no" nc 0Rop het"
1210 M N"1n  scherm. Druk daaSetr de tolenjd08RPRINTG"1n  I, JS:=teH! H iokIm a" iTn  
P4P eMte:M  linn, rechtTn naFteVe2"
1240RINT:PRINT"VI2+ 0Tn Oa"stopt dit deel vanse OeSd0
gRUn N eMtrIISIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIn"P2"
1260 GOSUB 900000000000000
1270 IF IN$="pe"0
="p""Ej$$$$$
128rO=INT(HM/2):VEUnee IrNNP
S0$="*"
1290 GOSVU10:PRINT IN$;: 5AVU10: 5AVU20
04
 GOSUB $
1310 IF IN$=rGrEN IF VETRTHEN VE=V
I2D. o!:="K"THEN IF HO<HM THEN HO=HO+1
1 eeM;Mt   J"THEN IF HO>0HEN HO=H0I25umt0 I 0
="M"THEN IF VE<VM THEN VEe EIS25uT
g"o!:="S"THEN 1380U360 IF VE=""ANIrO=HM THEN 13
1370 GOTO 0

T

 GOSUB 100:PRIPpnatehpnomen dat het scherm scrol
OeSD2tP eMte:PRINr5iO
018 pTItie uiter0hehiesr"
Pt00 PRINT:PRINliet g"loT "I 
1410 GOSUB 900000000000000
1420 IF IN$="pe"0
="p""Ej$$$$$
1430 PRIP1Innnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn cetelu een tabel VI0clen  
t40 VE=1HO=PR 5AVU15aeecP eMte"! 9" 1aT0HFniiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii o
 m T0pU teH"OeSRee6TMte"-----------------------------"
Pt70 CT21CN=0
1480 FOR VEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE 
VM-7
1490 GOSUB 115N
VR UB 260:$w0d   Rc
0"e0
1510 SGB ae"UB 3 N"1n  ! ";SR$" ! $
 dgPO Mt5e1t:GOSUpIN ete" ";SR$" ! $
 "a17R t:GOSUpIN ete" ";SR$" p0
 o0e: U1eT VEU550 PRIN"De g1r=Tteo"TVTnetjes ond=RnRar"
 d88888888888888888888888888888888888888888888888888888888888n N eMte"in kolommen staa I
1570  5AVN 



 $
 IF IN$="P"  INb  THEN 100000
15eaeMte"Als er een getaliet ps0Fn het veld"
1600 PRINT:PRIN:rnTH keknr
R(ierr$7Ig l0N29eO moeteNjd58aUn N eMtTr bv stele 5Tsn soTiTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT".
IR 
162 11E+23:GEa0000000000000000000000000000000000000000000000000
1630 M N"1n  Als vooree.semSe
Sret getal ";SR$
9t0  5AVpIN eMte:PRIN1*o
v 2
1 ";SR$U650 PRIN"Als het te kll i=Serdt e1a$eTrond"
1660RINT:PRINT"Seeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee"2
Esei2Delul."
1670 SR=-3.45E-06:GOSUB 300
1680 PRIS9RINT"Het g1rerF
110" ordt dn  $
1690 GEa00000000000000:P:nP10
100RINT:PRINT"FIHegetn 0e0"schrijft U toch"
1710 PRINT:PRIP1k00RmintekeO he?"U720 GOSUB e T0SR=3 o!:="PgI 1ex"HEN 100000
1740 PRINT"N1nnTn0Rwe de routine Ohegel 200   
O
gReMt9RINT"
pieprouoV2 Als U op een toe=NjR=60 PRINT:PRIN1
",I"0o 3018 computer indien dat kan"
1770 PRINT:PRIP4eHinttep s-taHap OE
otoR"5 
178 eMteG"1n  Het tikkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk:18 S Si ei.Im=0Innnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn5a=90 K=0
1ee"
NIg
"dSRe"5AVU10
e10 n"
u0
I1 9 ur IUiIE9 eMte"Huk O4
ReVl..Re"0, 1830
1820 M              U830 FOR I=0 TO 2PR 5AVN0eii IN$="S"THEN I=10jde40 IF IN$=""TEj680
1850 V
1GOSUU10G"1n  PIEP!                ":GOSUB c 16e: U1111111111111111111111111111111111111111111111111111111111111111111111111111111jde70 IF IN  uII SSIE5N

5N
28rPN EP




e90 IF IN$="P"  INb  THEN 100000
19 P:n  VngeeH 3e1or
van Uw subro
Ine is noOeSI8rPN EPe 20:S"iRe"5B 300
18RPRIN SR$;" bytes aann P=eTnruimtlITr."
.mtP"1n N eMte"Als laan0tu ken8 nu nog deIsoTn "OeSd  eeRPRIN"subroutine's nTn0d0Mn dat meTl
1s";
1950 GEa0P5$:IF IN$="N"  INbIeH)
e8$.d2P"1n N eMte"Ok daFSPT
f PT22222222222222222222222222222222222
1970 S0="Hallo0:=e4
Rstu5T tent voor oI1GOSUB 350U980 SR$=" de p sterI1GOSUB 350e"5B 365N
2tP 110=InSijn benPie02r
d1
^r eEs0
$01k e"0Te5 
20
"GOSUB 350e"5B 3698I8aUn N eMtrNIN1
^ol d02"
2020  5AVN 



mttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt I 1e0="P"OR IN$="IeHj$9t9830eaeMtus e te0Fs nu afgelopen. Op dit"
0eRPRINT:PRINp"Ps8SeooT
0E
verS=;TD
TTRne"
20eaeMte:PRINT"preHamR's OoBe te testen. We z
l"
2070 PRIN"zeer beo 0o
m aN
SsultatediePN)
8aeMte:M  behand met deze programmi0;!t
e

 PR0RN eMte"Laat
dat eens wet=oEn11
lnR  
$0 PR0RN eMte"te(
;knummer:"NSfRG, 10099

































HOIg
H
IUGEa0SR$
 
P Un  Probleem? druk Oa6d Ii ae"5AVN0:GOSUB 100:RETURN
8 Oo  5AVU00:M  Dan is eNP=Iets mis!!"
110 PRINNnnnnnnnnnnnnnnnnnnnnnnnnn"
120 PRINT:PRINa "l"00 FkIt te vin
Rwaprecies eNj$03 eMte                                                                                                       1
PUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUIn2 BI.==" "7=0IeI0T:n."
14 eMte ::h er kan natuurIjk sn een fout in"
10050 PRIPEsei" "l
R7TH
d1NI"leRmma zitten."
8e6eaete"Probeert U eerstog r
R
rest vanj$ 
RINT"dit pro+7ma te latSnop=!t5N

 PRINT"Nm deosakon kt ooBt:j$NRPRINT:PRIS9RINT"                                                                                                                 z0En "p nNj$100 PRINT:PRIN"""""""Musschenbr0nstr. 17"
 RaeMte:PRIP"""""""5621 EA Eindhoen"
 d0eaeMt9RINT" 0h
 n 040-43850OeSuTe1e3Rtk         Mus1En0m""G0nstr. 17"
N:.S0
1940 PRIN"subroutine's nTn0d0Mn dat meTl
1s";
1950 GEa0P5$:IF IN$="N"  INbIeH)
e8$.d2P"1n N eMte"Ok daFSPT
f PT22222222222222222222222222222222222
1970 S0="Hallo0:=e