5 '     :----------->>T0 1mtt,0. 2.7 ki o
8 U 
D  1To
NO0 '                                                            aso03:t  						    :
H:'    : Mes08)9( ,0UL0R5
G"NG'1smT(o		SoNO
6NNNN: from Howard Moul FeN:o6ginal SJBBS ( :5SUIMS93 
B0 ' b  Basic):SmR G'1ted to t:SBsI2,ASPUhdRBBS or     :
30=:t : RIBBSRT=Ba F2Gtoff, and exten0,0ely revised/    :
35 'So-'FT0o8ER$mORT(2R1ESw5RE tASmyR(BBv
4  
40 '    :----------------------------------------------------:
45 2 A The Fowler0ersion,BBS22, was split into 2 mod- :
00=:t : ules, :C(BOand MIN03t:by Ben Bronson.       :
55 2 A----------------------------------------------------:R8NT    : Both were revis,sI2,R05,0en RBBS-compa0E 0R,0er-  :
6AE0 t siTRsoAin 3/81 by Tim Nicholas, to  ET1porate e
:T b  updates from hi,0eC00(A24 o ROOOOOOOOOOOOOOOO:
75=:t :---------------------------------
80 '    : BillarnesTs bell-atline-e,SfS10FOg  18,S(NOR fNT    : fr7(BBS 2.5 1' nU6nes 260000+),$0,h:EBBBBBB:
9 Ec( S0o chaned  XTL$F00BI2UL0'6th MINICBB?A
95 '    : Now both 'G' & ' Eeturn thetUPU'to CP/M   gSes6P En   0,R/Fe1$s UTA26m off.  TheBBS22/24Udt,:E RT
105 F^umber 02N(lE tS(
t)TtSUhu5Gcilitr 9UF   02'Ses"0 '  : fur(er changes      --Ben 1onson, 3/20 E T93 TtH:'  9c"Se00=T

  Lin1
I & T2 remov,TiFiR
 double-counti2PSes :'  : o call1s. (b) Comme",lea5F8="ir0FRsRonger :
130 '  sas "Thanks for theE ment" when yo didTt      :
135 '  : l08BR0(FA	7?sr= 60(
	SoNOTt05 FN,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,:
150 '  * No n"(at mossUdt73B nT5mOt),,6n confo SM))))*
155 ,E)wit the li nT5mbers0i,0ersmRlR, 25, &4     *
g-'iF S01 Ds:1 teuRFTi1s+Tir0FOTTiand  9Ot1$*
165 ' 3T1 F:into cus FEGoRed programs.                     
M170 ,  1TG)TfE99RaturesLI  IN:added to OtNE6 (i ome from BillTE  T AEarnest, Jim  RHank Szyszk9sO2 S9n5SfS :S$LU3UUs$fNT  -  : 1C0c: 4
0Gn2Gntor, & Ski Hansen
19 E 13M195=Se(6P E99EA QtuFtRI1II$ 6tion o WDE featres @ 6nes
6u ' T6o#0E9  8G
de9l0T$, 1020-11i9,LRU t ->  BB, 06C B210 '
*GAE NRines 10000- altered to acceptE   C0m9
908:& O
8G-RsR2(23S6Cnle by ssops or other P+111111111111111111111111111111111111111111111111104T1 NW pe
sZ T)
5 '  - (:EH=47 u12 KI$0,RtS8I  05R:n STCALRLFT0 $1M1hy230 '  - heLIN:ZTeuRFT1i5sZ B ,6C  rotines)
235 ' 
#0:' APut in auto datER2"1y rout t7G1omTDE 
05 ' ARea   r  TfR3ttT0"aE85"om BK$ dF90iEFT80E1 O,,5sers onl
2P E0 
5)
B0AE99y0FtFIraE85"om HS  9Ot11 ,(:1022/81.
256 '  - B ommand$ d,EkUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUnRT6norE  SU0 Ss0
tY2tRTh2ei10/14/81
260 ,  N"'Grd Boow"'s fix at lin12D=,LlH0u adhU02TH8 81
261 '  ---------------------------------------------------------------
262 ' NO - 06 91530E r05FsEFR t1$ad"ess:2G:2GS6,$tSe0S= E:SmG0,BB ,FuR$tBZ$S aF0
V:the progr AwilSBi :witout
264 ' this routine, hasT' FL9o1Gbled in thesnG11ibution OtNE6 )
U0aAEEo2)7P   T,35t it'll run better if you usSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSroutin

S265 '  ----------------------------------------------------------------
270 ')TE that t S"outine  61T$ (and the S RR S0  ) "e set up
275 ' for a Mi 0"0n H"dware clock at ports #S: 
O2BR0'6ll have
280 '0RE t,'0 2w,cCyERn" changed to
0nT6th your sys F:clock.
:P 3eTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTr mGAETA 1 SeT"A T FHSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS0m0rNG'1s.O"
340"0 RTs
0UsO
(2,2),R6),A203(36tR6)yu0 POKE 0ST5f32 
"'To disableR2BTu2 INClnhS$B0o2O+"$13bIgeTe:P= eemt( M
,B6U 3 y A $'
:ET5,Is4ai 1100(os t y1 )T200 MS
SlsLLS=M:r:M1 UNA0 n<BOT2200:GOSUlHv0 N=1:A$BYSR0 5k/Chicao Remote :8 M M$1Gge SubS Z 2
1Tt1A)23 SUB 13020
060 BEL=-1:XPREsGsol :L BEL:- Me=SZ S)m                                                           $=VE3 SUB 13G)T280 SAIEtH6GsB43M507
M50AE03ynTycatus &sCw2a1om LASTCALR
509 '
5N4 SSl>X  r LA1E:LR":INPUT #1,N )$ IR0S tCLOSE
7P3$#0:GOUO1302TsS N780t,E:of msg's: ":N=13 SUB 13G)
sGS PEN 01,1,"A:COUNTERS",5:FIELD#1G7TM 2o4C "
SGAT =
:L(R )
C00 A  eL$(M):GrCNCi00
I8csStPGretUPU'# ":N=1:GOUO13020C  UNA0 n
T
4 CN=VR(R )+INC:A$=SU
9)
 :LSERR$Nn GOS)13020:PUT#1,CRLS
780 A$="NexF98=E:will be:":N=23 SUB 13020:GET#1,MNUM:U=VAL(RR$)
A 4 ?STR$(U+1):GOSUB3020: 0eE=)SUB3020
800 )R UGAE92n9 foRTM$1Gge0i ter(is caller
82 E( PR
)":MX=0:MZ=0:I 6NTFLAG on' TIMFOR PRAlPa HEAING
2iP=:>EEL ","A:Z:
MfT1,3(E=1:FIELD#1U27TM 2+ORgK=0:c1,RTnRh1) THE,6 Be24 GFTA.(R$):MZ=MZ+1
RMZ,N anR032:THE,fG)R,:IF I G

GP'Oa
 4 IF G>99998HEN MZ=MZ-13 TO 960(:64T#1,6C123 UO16500:IF IeL(S =<412 AND INSTR(S$,D::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::u1SRa)(:B0 IF N$="XXXXXX" aPNS+N,
2 r
91$nA<>"SD r THEN 950
92$nT0 A.TYS*EN")=0 THENfeR:'nRR
eSu1S7N1Te following message(=2'G22''RswE for you."3 SUB 13G)(:0 IF FT THETs"Please U9NISSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSL t7777777777777777777777777777777777777777777777777Gt woulRsy982" t)T0K SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS'c1sw"s":FT=03 SUB 13643 SUB 13020
l00 A  eL$(G):N=1:GOS)13020
950Z" ",RE+5:M(MZ,2)=VAL(US'A1N (E$O
2 ReRgO0ARE=RE+6:GOTO 02
960  0eE=)SUB3020:c3sB6
970  9trSYSOPyPNS+ rXXXXXX"
10000 'TI 6NT     **** Main Comm 0,7:S Sh
tor/Dispatcher ****
i05 '
10:'  (6nes176-1198 dealT6th privileged (SP)+tS#EB0nction,'OT
aAE5SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS9eeping them away from nonp6vileged(G & NW) users
1040 'TIi0 A1$= t6S7r00(((((((((((((((((((((((((((((((((((((nA
e ":yPcs<,  +"
r dn,-K,CPs  Kmhn  1eRor '?s0Eo t know=  m1esGddddNt +"?":GOSUlHv0 C=13 SUB 13v C=0
iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiin2HSSeSu1BE  Bes"20 FF=INS RhDCGPXQTB",B$)3 SUB 1140:GOTlU 3 TtO6 n((S2:THECCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC0
1160 S((,0)TO lSo9  U Rt61T$,18060,110000,100000,20000,OOOOOO17040,:U t ,18080240Y,i6
 TtcEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEnA+O$=Sl
EHM
G 1:Bes"76 IF F$"U1SP" THEN 0000000000000000000000000000000000EkrBes"""""""""""""""""""""""""""""""""""""n(sSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS THEN0000    '<CR> brings all except SPTGck  nuFLRSa)181 IFIEtOO M
GPN:t                                         ditto
1184 A1 rO2(SnEor 9U9+100(S0Uai ETtiRl0T1 speci1D0sers (O,M,U,3FRor ? if  S9nown)":
118Ts<, 1$+SSU)SUB3020:NU GOS)13260:C=0
1188 IF B$USSSu1S23 SURBu00:M
,UlSes"90 IF B$BNZ3aP4T1CNI:Un GOTO0000
110 IF B$=
" THEN c3( AU t :GO  10000
1194 IFK 
s"XXXXXXyP'nR0HSSUs1 THEN GOUO220000:GOTO 1T$Tt$inR0HSSteSu1S2T1CN:61T$:GOTlU 3 Tt$M$IF B$=eEeSu1SOSUB 2300000000000000
1I 8

,UlS+O200 ?",2(STt understand ' "+T, "+N$+".":GOS)13020:GOUO1302
34 
" V$=U RET0 
M1201 G3  10000
20K:3e(0:'So"Ff ts"22ATO
U t 0 ' 
2230 GOSUlHv0 GOTO  U0a)
37 c3A#0t 
2240 GOUO13020 )KE 4,0 $="Now,TGck  nB:8 M....":GOS)13020:POKE 0,&HC3:SYSTyHlS8:3eSSSS '
5020=EH t  Di
sU:SN
enu of FunctmRl01"T$
#:3eS0060)SUB3020:?"i ETtions supported:":GOUO1302sR,3$oS1S
 e 0 
iU,:?"?sTetUTRTM$12OT :R--> Retri2tF S T9gU GOSUlHv0 

      IF BK THEN  SP
 Eiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii rE-->nter message       : 1US0s 1n
$12OE0)S)13020:IF
GPM eE:
M5120 A rP--> Promt (bUO togl  =S,> eXpert us1 m,'U GOSUB 136'nR$oSu1S
SI2eS0140 A rQ--> Qick summ"y                                 UO =IsY( S FBXTL t)A 0it to CP/M"3 SUB 136'nR$oSu1S
SI2eS0160 A$="G-->$n,6'7to C/PM  T--> Time on system":GOS)13020:IF
GPM eE:
M5180 A$*--> ReaSnulletin on lata$softw"e":
5195 GOS)13020:IF
GPM eE:
M5200 GOSUlHv0 A$=Bm( S0o8T:may bT0"1ung together,OFT0H5BERdby semiolons.":GrCNCi00:
5205 A$PR t='F$2
e, 'R;123' retri2t7LTM$12Og N:G[l0T1CNCi00:I0
/T"S
SI2eS0210 ?" t=E6S;S0H8tS.Na2"0I1Ietrie5U u d'+sE<w" Msg #.":GrCNCi00:GOS)13020
5280 GOUO1302(ET0 
M60000 F 
0BEA OFBtc="outine for sysop (e0n5 SLsyn
IN9'1(ru ENTERO
NO210 IF XS>"XXXXXX" aP4g02
60123 SUB 13020:A1$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$,Gys date:T
/DE y=":GOSUlHv0 GOSUB 13260tS+ 1
g$'
v:' nter a new message
604 3e2g0F=03 SUB 136N4 >EEL ","A:=CAC(: :A$="Msg # 5s E :  N=1:GOSUlHv0 FIELD#1,5TM 2o4C=1,M1 V=VR(R )
g:A$=STR$(V+1):GOSUB3020: 0eE"0gd $'  ** T08 at0a17:n STCALRRGIG23 SUlHv0  A$="Today is "+DT$:GrCNCi00
0P0:A1$="Who tos$o22i te:LL)?":GOSUlHv0 C=13 SUB 13v C=0:I0HSr THEN T$="AL1 F"oS+ 1
6130 's t  RB=tP"outineHt tituted here ----
6140 A ="Subject (0AS 2Grs. max.):"3 SUB 136'3 ":GOSUl)Uv 40 K$=B$
600R, X hK$)Sa

GP43 TO 600RGE A1$="Gsswor =":GOUO1302s)":c3sB Uv C=0 =T$=B GOSUB3020
617:1$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$Q98Aup to 16 li T: E ll soundsOI
ESSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSLER,nE+tTh.":GOSUB 13020
6180 A ="To edit oS(2Ahit 2 C/Rs.  Don't+tFC FESmUmRI T1:GOSUB 13020:GOSUB3020: G)CgG7C+  RING$(62,45):A1$="  |"+A1$+"| GOSUB3020
619$n(SSE6y51S$="Msg full":GOSUB3020:M
,0R=03M6200 F=F+1:A1$=SU
nT=D#1:N=1:GOUO130203 SUl)Uv  g="" aPhS,T,1:GOTO #ORo6u IRSSCeSu1S2s:' "(3 li TCR<  TR7FA.)ORo*GTnRRSS:THEN PRINT "(Last 6ne. .  .)"Ro8G$(F)=B$+"P0)TO I:Be2nE00 GrCNCi00:A1$UB 2n.B (L6st,S3RD
n )bort, (Oont 30e, or (S)ave -- "nR,1: 0

GPcsN1L,, ,C,S: ?"
6260 GOUO1302s)":c3sB Uv C=0RoolS,  It<(9+$rir0FlE tR05FN(ere
nIgTnR0E Ct21 THEN 633M62P0)SUB 12b3M6300 GOSUB 136hS R L=1O F:A$eL$(LD1+A$R)
632$n2
/aP4nE EEKBc1CB60:1  = 0)R+0:GOSUlHv0 CLOSE:GOTOR=0:::::'this CL"+0T:froS131(T12a0sw)R52 IF B$=NZ3aPcsSSP borted":GOSUlHv0 REoP
 R+                                     n$="C" AShAT T"S290
6400 IF B$="E"HEN 646:
5 E:YFr(atDE0(222222222222222222222222222222222222222222222222222222222222222222222222222222222222 ISB+T; r t= Sm(6ling
0 8GTnR0EtNr:$)F4:THE00a0e20 GTnR+ rS" AND FM=1 THEN7150
6 64y0R=03M260 GrCNCi00:A1$BRin04SP0)SUB 13020:GOSUB3260:L=VR(B$)
6480 IF#e2A0ELFSu1S2nE00 ELSE A rWas:":GOSUlHv0 A$=p3T2T1CNCi00
66cs<SUx"EFO0'TltSlsA
e "0

GPcs<, 1$1 f02iEF$9Range1
6;et13sB600:A1$="or227-7"ing/ne a11ing/   mBnstitute"
6520 A1  Nt +":":GrCNCi00:GOS)13260
6521 IF LEFT$(mS3N$+Z3aP40a *ORGG:IF B$BZ3aP4nGTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTEY $(L)=B$+"P0)TO 280RGG ;sRF,6BbzB$,1)="/"HEN B$=LEFT$(B e "A  ")
6542 B eTd
pG,2,99)RGG)FORN e "G)   1 ST N,1
6544 IF MID$(B$,Q3N r/" aPh
BAT?LEF (B$,Q-1)
sSS
ID$(B$,QP2A 1=20aGA1  beM111111111111111111111111111111111111111111111111111 <, $(O
6546 FOR Q=1 TO LEN(TEM+= X hFROM$)+e20a oIsR
$ 
p s1
P$,Q,L:F (OM$))=FROM$ THE00aiBe2028 NEXT'F:1$="Strin not ound!