1 W3TH155Ve230)3Ot3HR$((OE3l=:+10"
l10 GO:1010
100 PRINT
KR(
sG4$00s1$S
aC 
T270O HO
")
 EN HO=51"H1 IF VE>23 THEN V tt RINT
KR(
? 4:"3$3HR$ 
E"G0E50000D O+32)
115ETUY20 HO=PEEK(&HE VP0R=D
,00G  =VOO5B)&HI e1 VE E2
12IF HO>127 THEN HO=HO-128:VE=VE+1
12VE=O
-U(

=VOO62):IF VE(O VO21 E=OTVl4 RETURN
2 IS931IE$:RETURN
 = OR4gRRUF IN$"1O VO2"aP
211 RET0H 
250 PRINT CHR$(7):RETURN
260 RV=RND(1):RETURN
2GFR=FRE1):BURN
300 SR$=$R(0NR)1
NQ
 3(H(SR$)0O Q7=R1 O2I9SS
e IF E ((0NR$,10iO" " THEN 304
3K0a0FT$(SRCQ7-1
:OTO 301
3HIF LEFT$(SR$,1)<>" " THEN RETURN
t 1IURN$0E HT$NR$,Q7-1):GOTO 301
( e08IE0OE10iO0 THEN 316
3)1:3Op8O1PVGOSUB 300:GOTO30
3QgSGN(SR):
:0sI=U:6 QU3Op8G6 jIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIFtQW J=U0OOR 6=1 TOE1QAX AB 207XQVJ10 Q9=IN( 0sT.5):SR=Q9:G"R4EK- ="e Q9$=RIGHT$(0O 0BSR$,CN)
ONE0O 8=0 AND Q9=0 THEN Q5=11nB)1:GiOSUB000O Q5=-1 THEN SR$U .TSR$
3I0810RFS1"SsQ0iRV30 IF1%UR:CEPTO2==O
 
33SR$=LEFT0 2P=T).=39
:OTO40
1ES08IS$0HT$("                                                                               s08I3CT)
P:SR=Q4:RETURN
1GLP01NR$;:RE$S
360 LP01I9SR$Y 20000 A=100:GE:20
LDO GP0gPt0 
1060 :
1T:G"R4e00:HO=11 E=6 OR4e10:PRINT"TANSCHIETEY090 VHO GOSUB 110:)3O"I 0O0bY $:VE=1lGTESUB 110:PRINT"Instrukties ? (j/n) ";
1"uRwUT IN$
1120F IN$= NR =SNnd1 O2+B 60000:GOTO 20000
113r=(SE41FP100
aaT1=5:T2= THY "LvFOR=1 TO 39:P01I =R3 OEO
l1030 HE=Om:H
GTO2:G"R4e10:PRINT"*":NEXl40 VE=23T+lECPTO 1 STEP-1:GOSUB 1:PR*";:NE6Vn!0 HO=0:FOR 32 :1 STEP-1:GOSUB 1:PR*";:NE6VnFR0FR 3 T17 STEP 3
2070 HOR=E41FP110:)3O"7I(034+ 0K  
2T:VH
oe:GOSUB 110:)3O"5;(0"3$ R0OPsT(VE+3)/7);
2090W)
C B1:B2FP110
21 PRINC00B sTT1E 3F :NY "H=:HO=1:VH
oe:GOSUB 110:)3O"t90F :0EYH10 VE=VE+1 OR4e10:PRINT"  ' :VnHP:NE4H
- "8-
 
;O HO=12:GOSUB 110:PRINT3
D3TP
PPPPsecondenl50 FOR I=5 TO 1 :OK 8 HO=18:VE=0:B2FP110:P01E50000000000000000000000000000000000000000000000OBI)
2160FR J)E:500:NEXT JU

I::
30000 F 8
O7"TO 1 STEP-1
aUF os3=0 THEN 50000
3020 :VE=23 OF G"R4e10
3030 :PRINU =T)gDlP+ ::VE=0:HO=12 OR4e10
3045 :S8
OUE OSUEK- Pt0 PRINT" Nog ";SR$" doelen *****"
3060GOSUB 260:L=5*INT5O7
QT 
3070GOSUB 260:LA=13+INT(26*RV)1
ST::GOSUB 20UF =R0iO"
 1= ST- = TOG:HO=LA
3100 :FOR VE=1 TO 22
3110 ::GOSUB 110
3(G:P011n:LB$ 
3130:FOR J=1 TO1A OEO
lNt0    GOR4gRRUF IN$TO""THEN GOSUB 35
3150 E0O V=1HEN1)
BO 324 Jsv::GOST 0:PRINT"":KL=98
31G::3Nro2:GOSUB 110:PRINTV2E =OG:T+lN=1 TO1A OEO
lNRs0T 200:IF IN$<>dT1=E41FP3RP







































































::IF V=1  EV=0:GOTO 3240
3(G:VH
4
IE OSUB 110:)3O"51="eAEO
VE
3230 :FOR=1 TO 20000:NE6VJ140 4F
WW:GE:5T2  "  
3R
  QaN$):TH RE+ T1O VO2I900 J "(UF 34eMVN=1011IL=98  E3540
"=:IF VE=7*Y-4 AND KL=1GTHEN 354 J 1
IL=32
354B11VE OTO 3600,37,3800
355rER00 IF T1=0 THEN RET0H 
3610 T1=T11:HO=0:VH=ESUB 110:PRINT CHR$(48+TT i:VEYOA0 GOTO 38P
3T 
lN IR
R0:T2=0  ERETURN
3710                                                
 )
 
C5IE OSUe10:PRINC00B sTT2)1e=10 Ve0
37
:OTO 38P
3T 
lPd(U0C=0  ERETURN
3810 20C-1:H)
 
CUO
:OSUB 1:PRW3PKR(5oF= 0P
38
 3?= t0O 
=12 TO 37:GOST 0:PRINT"I2EI0XT HO
3840 ,5I06 Ve TO 22 OR4e10
38:PR                            "
3860EXT VE
3 I OR400O"
lPZ0 V=1:BURN
3890
40000 VE=23:HO=16:GOSUB 110
PN(UHR0"C2 THEN PRINT" misser 2"3$E OT4050
4020 IF KL=98HENI001S2 
NF1r ! ";:S(Y)=G  :oNIETO 40-
h
R0:KL=160 THEN PRINT")B
1G
NG0QR2r ! ";
4040 S(Y)10GoN=4050 T0a

:i(O VO2O=- O
+(1 E=7*Y-2:HO=39:B2FP110
4070 )3O" NY O
ST:VE=7*Y-3:HO=39 OR4e10
4090 PR1rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrRETURN
4110 VE=7*Y-2 O=O
:OSUB 110
N5vPRINT CHR$(48S(Y))
Nt :FOI=1 TO 20000:N=4E
rT2GRE$S
415rH(S?EUNT(100*(S(1)+S(2)+S(3 *
1*(19-WWF"
l t= O=H
O B2FP110
5020 PRje scod 1en g034O3=
1Vvan ";O;"32V hlE;ER1=23:GOSUB 110
5040I001S1"N= eenR0O2llet 1 ?  01Y"";
5050 GOSUB 21 e1OR0 IF IN$=""srL$="J"THEN RUN
50GIF IN$<>"2 C=NE00343"O V 5050
5080 GOSUe00:PRIN0K0RA0): 1OdA0)3O"1111111111111111111111111111111111111111111111111111105T562ns 0O"n:P0130)(30NT
5100 END
(0OE "R4e00:PRINT
3vPRINTj31ISCHI
T11Ts e" pe waarbijG1 ":PRINT
6020 P01 0I180 
O tanks met elk 1Tjf kgels":PRINT
(0t0K001S0oet trachten om zoveel mogelijk":PRINT
(B :PRINTRoelen
Vraken.":PRINT:PRIN0K0RVE
t000"Je kn e" o
7GolleiI3 half of"
(B(30)3OGPRhelemaal niet raken, watG1 2, 1 of 0"
(
I:PRINT Rpu :2OT(R 5 ( 1rt."
6080 PRd0)3 PRIN0K0RVE>GPRINT"DruV1eHF4Y8R "T0Gv
ELG :":=NL1":G"R4=- O







































































B2FP100:P01 Ea0)311 0E
D"0B(=1nl21Re twntig bewegene":)3O  
6120I001S"ToNGH1n  0  
N3"8oVh0V"ummer in te" RdO
 P:)3O"1111111111111111111111111111111111111111111111111111111111111111111N+1n01
bij02 tank hot.0K0RVEB :PRINT:PRINT et012G=KB2
=
161Ts links vermeld,"
6150I001RA0)3O"N S9o  Q3Ehts.":PRINT
:svPRINT Rd0)3 PRIN0K0RA0)(30NT:PRINT
6170 PRINT"Druk een toets in m te beginnen6180 GOSUVERT:RETURN
6200 :
9T2KC0: ***********************=O3vPT
                     *
9020 REM  * (0:"00c5E
BEN(0I E0t00=
*  04
 
9040 REM  ***********************
3H:r+:
9070 PT
EPPENS JOS=OId)3PT
KO
:H6STRAAT 6
Od)3PT
3580 NEERPELT - BEGIE=I=R 
9110 REM OORSPRONKELIJK INGEZO3EN
9(IC0 O E:HO4  T=3OOPWEDS RD=It :REM INRGN80
Ist0
91:REM AANGEPST VOOR BASIODE-2
90GREM       DOOR1='N VAN=I?GRO O"=PGBAS3ODEGROEP
)3PTE00::N>1 
sG
&GPTj 0=EPAST VOOR BSICOE-2
9160 R1
RINT
1OdA0)3O"1111111111111111111111111111111111111111111111111111105T562ns 0O"n:P0130)(30NT
5100 END
(0OE "R4e00:PRINT
3vPRINTj31ISCHI
T11Ts e" 