10 REM                    Tier Calculations **************
20 REM By Ken L. Greene
30 REM #5I5T3r03S1 7 Sa"0E
2F0 REM Edmonton00be                                              Ca1da
 0 REM T54C8
t 0 EE2
) 475F56
 0 N=8
80 GOSUB 770
92RI: TIMER CALCs ON4 "
A0 PRINT" This program calcula": values and timeTo)r tese timers:"
1 EINT TAB(10)Ca9601"
120
 6 10B(
s2      9602""""""""""""""""""""""""""""""""""""""""""""""""""""0 PR"SGEFOA)RNoT96L02"
1C2RINT TAB(10)"4      74121"
150
 6 10B(
s5      7443
2a60 PRIN10BG
s6      741232a70 PKT TAe10)"7)T5C0:80 PRINT 4F0)"8                                                      56  8ual AAL3
190 PRIN10BG
s9      T0"3d"
202RIsPRI3
210 INPUTT
ter the number corr"ponding I G0 INURred tFer :";T
220 IF T=9 THREND
230 IFD -T iGGCt02P40 Ka84CoN2=K0 u:K3=
(T"1
R0MAX=RMAX(n
26tOSU0ER2070 IF TK>"TAND T$<>"t" GOTO 340

0 GOSUB 540:GOST 
0
2R K1+K2*R*C*(1+K3)/R). SC=T:GOSU0NS
e<S"1: 1dRI$G910.C2RINT "THE TIME IS AItSC$;"s(2"135CtOTO 220.4p  1o32 AND T$<>"r" THEN GOT
0S20.50 GOSUB 560:GOSU0O
0

ER000000000000000000000000000000000000eT-K1)/(K2*C))-K3
37C8
 :1EC 0 KR:GOSU0NS
2 =SC
390 R="$0
A)/10
400 PRINT "THE RESISTANCE IS AOtS2G"ohms2F10 IF aK3TU 
  t5GOT"Et1(: E3ssPRINT05INT0":istane iThre (ran maximum re5stane foEIt" Rmer."
5C2RINT"use a83W
 
al* TIf car)0O1nce'8iT H1(S
al*T3":C<T:C<T
44tOT"Et1P 0 IF T$>0eR6>S*1
U(eRt5GGAA
460  9" 
0S3I t7" 
e:1B0 K((TK1)/K2)/(R+K3)
480RN4; " "0:C Ra, C=INT(C*10710
500 PRINe-T 0 tE4
 )TANCIS ";C;SC$;"farads"
510EEGA
T2i20 IF T$<>"E" AND TK> "e" THRGOTO 260
530 GOTO 90
540 RE0 "0UTINE TR5TN FOR VALUE O 2 "
550 INT6 26r (r value for 'RORn ohms :";R:RETU
2i6CUT"00TUTI  1T AN  i VALUE0T"C"HE RT2UTT
ter value for 'C' iTo1u0Ut2 ETU
2i80 T60 "00TU=E TORTN F  VsT4 FOR "T"
590 INPUTT
ter value for 'T' in 0I0onds :"T:RET NM AEM SUBROUTINE TO ASK WHICH: eTGEoRt"1E PRINT"EntersT Ger for vari*e you wi/o fin :"

RE3 6 10B(
sR       res:tor"
5C2RINT 4FOA)"C       Capacitor"
640 PRINT 4F0)"T       Time2B50 PRIN10BG
sE)))))))))))))))))))))))))))))))))))))))))))))dit"
ERTKPUT T$:RET NME R0B0 "00TUTINE t 0)R7Is hIR(  & FIND SCALE00G5
680F SnMTc
E I5t RSC/1E+06:SC$=T":RETUR2B90F SnG A! Tt5SC R G A!:SC$="K0CCC32900 IFRIN1 THEN SC$=N0CC,RN
t Td  I6I:sLRSC=0:SC$="":RET N/Sp0 daE-09 O i KS71E12:SC$="p":RETU
293p R0 d> =oT1 THRSC=SC/1ia  R

1:T"REiN
740 IF  d> A1 Tt5SC RT30000001: c="u":RETURN
750 IFRIN1 THEN SC=SC/.001: c="m":RETURN
760 RETU
297CUTNITIALIZE TIMER CONSTANT"I NEC4OR I=1 TT
2990 READ K1(I),K2(*n(I),TAX(I2rTT
800 0  G5E
810 DATA 0n32,.702a02D28ATA 0,.31m2a
83010TA 0,.33,3,2000000
840 ATAU.693147,0,400000
R0 DATA 0,.6
14T2U=o7:I
60 ATAU.693147,0,400000
SR1OA 0,1.1,0,20P0>D0 DAS
Ta.1,0,20E6
890  1T
2Wlr/"644444444444444040$HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH R 0aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa6RBB+  Taaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa6""LN:NLN:105S1n6
TN0MATt"LN:1 "T1
I5N>S6HUD0N)e8ST