5 RESET
9 PRINT 0EU  E6;
 $INT "DIRECTORY"
19 PRINT TAB(6;
20 PRINT 1,O6 ONE OF F
,ELLOWO 8MNUMBER:"
2 PRIN
YEFTE;
30 PRO2R1. EXAMINE 2AIDcT0$5 o0S Y ====================================================================="
39 PRINT 0EUS5O;
MPRINT "0le      a rcord to the file"
49 PPEMF 
B 6;
50 PRINT SA DELETE  a1A=E. E:d fYA 1 the fiED"1$
# LT TAUS5O;
60 PRO2R4. PRINT OUT the entire file"
69  IM 86U  E6;
70NPUT $
DPC8 (P02R,CHOICE1FGEF CHOICEST  ,EN 7 SITT6ME0OICE>  ,E70
75 ONTBUE GOTO 80,20,30, 17 S MTD7H= ST LESUB 60 SET
 
1,7MTH2N"DPR :I
Y E$5 I"T5 FIRST.0 #042FL1 
TT
"= S$.o C8IRMO"T.853 E$ = ST$
89 Z
"= Z$
I0 TELEPHONE$ = T I 
UIA100
93 IF TO$(RESPONSH1,1)="N  ,E9$I4)SUB00
95 GOSUB 30 IO EMTTO$(R$AP#T3E6="Y  ,E92EN
16GE"R 0PRRT  :IB*E$+FIRST.N E$ THEN 11 INROPEN "R",2
OIRECTRY.BAS",104
100 FIEE #1,20 AS L$,20 AS F$,G: T1=SH  MON10MSH5  UtN1iT T$
10LSET L$ = LAST.0 RTC,2 LS F$ =
"SES*E$
F0TR BL S$53 
T427,R T C$ = CITY$
105 LSET ST$ = .TE$
FF(

NtR= ZIP$
107 F  2ER= T6PHO P SSBt962 "2
T                                                                                     ANUMBRTC,9 TOSE #1
110 GOTO 9
M# L$62RLASTND FIRST NAMES MAYOT BE CHANTO."
114 PPE2RYO  MUST DELE THELDECORD AND F9(  EO PRINTle THeRONE."
118 INPUT "PRESSET NE CONTIA4TB0$
119 GOTO 9
H GOSUB 200
1RGOSUB 30 S4LTMID$(RESPONSH1,1)="Y",EN 120
1;R6SUB 400
Z2 6TO$27SFMLEA,SH0CSM
R6TO 9
170PEN " , 1,"DI F 
:002L3B 4 TCS,RFIELD #1,04 AS)1"E.RECOT427SI  "L$62RDIRECTORY": LPRINT
176 GET #1
1. 5EIOFI6=-1 T$S EN
"TCS2 RINT MID$(ENT1 ICOTP3,20 TCSI
(#GENT MT4UTIRE. .$ D$,1,20)
8 GL$6M2EPN$ERE.RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRD$,41T2)CA0#$6M2EDN$6 E.RECORD$,66,20)
184 RL$MTTO$$61
O ECORD$,83$OCABRLPRINT TO$(ENTIRE ECORD$,:F$O
188 LPRIN TTON$6 E.RECORD$,93,1E
189 LPPEY2  "LT: LPRINT
190 GO
SC27PT 
 ETOSE #1
194 GOTO 9
200EM *********** INPUT ROUTIN0 I T3G"L$6E0R$(26)
20 LESU $"TME PRINT86U  ( $ D1 ORY"
208 PRINT 0EUS NTP4T:6 IR",E FOLL0NP:"
210 GIA,442aS # L$2.B(O;
21
9NNT "Last 20 EAr               ",LAST.N E$
214GENT TAB(8) TM 2ENPUT "First Name:              "OERST.NAME$
$I GOSUB 700
H PPEMF -6;MA$ I
)2RStreet AddTOss:          ",STREET$
224GENT TAB(8) TM L$IO2RCity:                    31ETY$
228 PRINT 0EUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU;
230 INPUT "Stae A 0=tO:          7I.TE$
232 PRINT 0EUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU;
234 ENNT "ZipYI
$D:                