0 n 	rNr0wtT 10/23/84
10 ' MoiNA$oBelM by LsMcnce Davi'65vT)24
12 ' In rt yoiF1,RF
 M1D2 at lo 9R%%' Clear $t en st2Ihoo1iiRo0  t0oo"-I- Mm 0IH0 ' tNN:ograIPshf  coIiled f2IhfMCOM
1
l 	 ilas follows: BAS$MoT0
 MP2IMER.BAoT0fnCiGIE H' A>BAS$M05S2IM
hH/O sT ' ADsnCcGinoiNAi1nE:MTiN0 
89+(o(S MAi1l)20 PRINT CHR$T6)TAB(20)" x TimJD1MOIO/ Version 1.2
25'  NT TAB(27);"For:q QX-10 
oHnT:PRINT:PRINT
40NPUTL(BUheuARTiA  M
I(Enter N1%:MM) ",A$
45'  NT:PRINT"EntdBiaSex COMMAND L2de+EgNn1x ONE.PHN;READs$+I"
47 INPUT "M 1T,M$ 
oHnT O cMo"
 2he STARTUP TIMENaDoESys
A$
55 
ns1NI";"ThMex COMMbrns66666666666LG(r38m  ,P NT:PR2,8P mrHmustcave the compu r and mode0UA ' 20 GOSU
+$I'read cloc
90 IF TM$=A"HEN64 	 s itr;$R0nyesoUBIET06 	HR;0ML1M +"M:: 
0?ot, thenM,lag2I' sOPaMUB9p


$qRR	'	RgT0 IF TM$>ML1MTHEN 80 
1,GOTO10
16 L=Lf M:e
	'LeSUN> omma Rnuo   sp$  (20h)
B 
meaE &H80,L		'Poke length in(CRLg"ebuffer
166 POKE H8nn%25) 
e spa  (20)0InT J=130		'R$2
  &equivalent P0Ese0Is2 o)c'	HE"O LENM =RK$ times "
N(of charPC
 omI  line
10 La	H)rnL MoN I%,1)TbLn6lstrIhlogDc NToIto each char 0oF l1line
AE0$	hOKE J,ASCS M%p'Poe Y c  4 liIin(CRLg"ebuffer ndresse' E EHJ;1		'IncremPeadiaNNS"oLo9
15 N "'	H		'Do it
r1 ' sT0 PRIHCHR$(26):RUN "MEX"
190 OUT &H3D,4:TH=INP(&H3C

NEidT=Ut0P3333333333333333333333333333333333333	'vk
iPMl(
cM9
2;u &HhdT:TH=It$n%3)poHUB 220:n "H$	e
1nd Q-10
TO7Se+fNOr 
 0O 
 fD
H020 TH$T"
vpF TH<10 THEN TH$="0"
240 TH$1O M3 EX$(TH)	'End clock M1D2
2,RET U5gggggggggggggggggggggggggggggggggggggggggg
Ml MEPTCcino'-N/E
+(o(S MAi1l)20 PRINT CHR$T6)T