10 REM Test SWAP statement
20 A = 10
30 B = 20
40 PRINT "Before SWAP: A="; A; " B="; B
50 SWAP A, B
60 PRINT "After SWAP:  A="; A; " B="; B
70 X$ = "HELLO"
80 Y$ = "WORLD"
90 PRINT "Before SWAP: X$="; X$; " Y$="; Y$
100 SWAP X$, Y$
110 PRINT "After SWAP:  X$="; X$; " Y$="; Y$
999 END
