10 PRINT  PRINT "GEgST.BAS b Kei8tetersen,rtSDZ"
20 tD0 Version 1.0 - Nu1 t,s89
30 PI
00
40 PR00
d8iEOfgr
 okes a list with one filename and u=ardesc20tion"
00eIu0l)Itn8f"uf8 Ooutput file.  It is intended to be used with"
60 PRINTan in.e0le whic" N opturedB 
 a Gstr0 'ePory 2is o9 
70 PRINTThet"
turfile m 2 be ed-to reiru,R'non-directory"
8tRINT "informatioat the headr tail.  There is of 
iof 500 4) "E 
0 PRI""the li.R 28i0EP intended fiE5n3ofire ary liet only fo 
50 PRINT "weekly or moT"o 'updates using GEnie menfption 3."
r2tRINT
 
=1:DI F$("ctDn0 
)T4f'"'"0,mWeIT N3ae 11o#u>
9eNuiTcllyPRIe file
140 PRINT "Read u
ut file";
15 R6ci"#T ET re0
160      LINE INPUT #1,F$H0      LINE INPUT 1, 00
t0      A$(I)=MI 0n00P7,12)+"    "+MI 0nnO6t(LEN(D$)-10))
ts0      PI
0
IO3"d83IugKder2 Rp
'"dI 
 CLOS0P1830 ' SorroutinN0 eh I=I-1  N=I : PR00. eIuF0
28tRINT I "files 2 
Nto8i.
20 '
e
 ' This Crts thactuoI
#2
280p
290 PRINT: PRI""Starting sort...."0m
S=N
310S=J4\"do I
o =dl0,T NG)( ;nham$o 
0
f T do d
TdK4Tt=p
30 J3=I+J4
370 '0p 
 IF A$(I) <= A$(J3) THEN 4NN0as0 Sl+ AnDn1od
(J3)
400 I=I-J40 Uo0 I>=1 THEN 360
420 J=P1
430 IF L L0,T N e5
44 4># 350
450 PRINTSort completed.."
460 '0 "r4R> tO2edo t futpe0"4) "d
t0 '
490 tENO",2,aPM.OUT' name of output filNST
 FPITL NS60 PRINT #2,AnDn "0 
 i$ 
INNSuui T0o
rt
52tRINT  PRINT N "name" #yo  t.e0le." : PRINTSRF END
de6lNAo5 T