3 RANDOMIZE
10 REM PROGRAM FROM CREATIVE COMPUTING
20 REM MODIFIED AND MAINTAINED BY STEVE GILBREATH (CMRLBLG, TEGAMES)
30 PRINT CHR$(26)
40 PRINT
50 PRINT
60 PRINT
70 PRINT TAB(5);"************************ VADER ************************"
80 S1=0
90 DIM P(1)
100 PRINT
110 X8=0
120 Q=1
130 PRINT
140 PRINT"WHAT IS YOUR NAME ";
150 INPUT A$
160 H9=0
170 D9=0
180 S1=0
190 PRINT
200 A1$="NO"
210 IF A2$="YES" THEN 1200
220 PRINT"GREETINGS ";A$;", THIS IS DARTH VADER."
230 PRINT"I'M ABOUT TO WIPE THE FLOOR WITH YOU, BUT FOR THE SAKE OF"
240 PRINT"SORT, I WILL GIVE YOU A CHANCE TO DEFEND YOURSELF AND"
250 PRINT"PERHAPS, THOUGH I SINCERLY DOUBT IT, DESTROY ME INSTEAD."
260 PRINT
270 H9=0
280 D9=0
290 S1=0
300 PRINT"ENTER A SECRET PASSWORD, ";A$
310 PRINT"IT MUST NOT BE OVER SEVEN LETTERS"
320 INPUT P4$
330 IF LEN(P4$)<=7 THEN 370
340 PRINT
350 PRINT"ARE YOU DEAF OR SOMETHING....I SAID..."
360 GOTO 310
370 PRINT
380 PRINT"THIS IS YOUR DISRUPTER PASSWORD.  IF YOU DECIDE TO"
390 PRINT"USE THE DISRUPTERS YOU WILL NEED THIS THIS PASSWORD."
400 PRINT
410 PRINT
420 PRINT"DO YOU THINK THAT INSTRUCTIONS WILL HELP YOU ";A$;
430 INPUT B$
440 IF B$="NO" THEN 730
450 IF B$="N" THEN 730
460 PRINT
470 PRINT
480 PRINT
490 PRINT"HISTORY TAPE - DATA LIBRARY - A FEW MILLENIA AGO"
500 PRINT
510 PRINT"YOU ARE THE CAPTAIN OF THE MILLENNIUM FALCON, YOU AND YOUR CO-PILOT," 
520 PRINT"THE WOOKIE CHEWBACCA, ARE MERCENARIES, PLYING YOUR TRADE THOUGHOUT"
530 PRINT"THE GALAXY.  AFTER TAKING ON FOUR PASSENGERS, LUKE SKYWALKER,"
540 PRINT"OBI-WAN-KENOBI, AND TWO DRIODS, R2D2, AND 3CPO, AND ESCAPING"
550 PRINT"THE IMPERIAL FORCES AT MOSE EISLEY, IN THE TATOOINE SYSTEM,"
560 PRINT"YOU HAVE RESCUED THE PRINCESS LEIA ORGANA OF ALDERAAN FROM"
570 PRINT"THE EVIL CLUTCHES OF EVIL GRAND MOTH TARKIN AND THE DARK"
580 PRINT"LORD OF THE SITH, DARTH VADER."
590 PRINT
600 PRINT"YOUR MISSION IS TO REACH THE REBEL BASE LOCATED ON YAVIN-4."
610 PRINT"DARTH VADER IS BETWEEN YOU AND YAVIN-4.  HIS SHIP HAS THE SAME AMOUNT"
620 PRINT"OF POWER AVAILABLE.  YOU MUST DEFEAT HIM IN ORDER TO REACH SAFTEY."
630 PRINT"AND DELIVER YOUR CARGO-(THE PRINCESS LEIA AND THE DETAILED"
640 PRINT"PLANS OF THE DEATHSTAR STORED IN THE MEMORY CIRCUITS OF R2D2)"
650 PRINT
660 PRINT
670 PRINT"DO YOU WISH FURTHER INSTRUCTIONS, ";A$;
680 INPUT B$
690 IF B$="NO" THEN 720
700 IF B$="N" THEN 720
710 GOSUB 5090
720 PRINT
730 PRINT"DO YOU WISH ARMAMENT INFORMATION ";
740 INPUT B$
750 IF B$="N" THEN 1190
760 IF B$="NO" THEN 1190
770 PRINT
780 PRINT
790 PRINT TAB(15);"HERE ARE YOUR VITAL DATUM:"
800 PRINT
810 PRINT"YOU ARE EQUIPED WITH 100,000 STROMS OF ENERGY."
820 PRINT"WHEN YOU RUN OUT DARTH VADER WILL DESTROY YOU."
830 PRINT
840 PRINT
850 PRINT TAB(25);"ARMAMENT:"
860 PRINT
870 PRINT"TYPE";TAB(10);"DESCRIPTION";TAB(30);"RANGE(KILOMETERS)";TAB(50);"FUEL DRAIN"
880 PRINT"1";TAB(10);"HEAVY GUNS";TAB(30);"0-11,000";TAB(50);"10 STROMS"
890 PRINT"2";TAB(10);"WARHEADS";TAB(30);"10,000-100,000";TAB(50);"100 STROMS"
900 PRINT"3";TAB(10);"LASERS";TAB(30);"100,000-200,000";TAB(50);"1,000 STROMS"
910 PRINT
920 PRINT
930 PRINT TAB(25);"OPTIONS:"
940 PRINT
950 PRINT"4";TAB(10);"APPROACH";TAB(50);"100 STROMS"
960 PRINT"5";TAB(10);"RETREAT";TAB(50);"100 STROMS"
970 PRINT"6";TAB(10);"WE WILL CONTINUE TO YAVIN-4 AND GAIN ENERGY AT .9C"
980 PRINT"7";TAB(10);"ENTER HYPERSPACE"
990 PRINT"8";TAB(10);"DISRUPTERS"
1000 PRINT"9";TAB(10);"DEFLECTOR SCREENS"
1010 PRINT
1020 PRINT"ENTER ANY NUMBER WHEN READY TO CONTINUE ";
1030 INPUT Z9
1040 PRINT
1050 PRINT
1060 PRINT
1070 PRINT
1080 PRINT"DARTH VADER HAS THE SAME CAPABILITES AS YOU."
1090 PRINT
1100 PRINT"EACH TIME A SHIP IS HIT, THE ENERGY DRAIN FROM THE SCREENS IS EQUAL"
1110 PRINT"TO THE AMOUNT OF ENERGY EXPENDED BY THE STRIKING WEAPON TIMES TEN,"
1120 PRINT"(EXCEPT LASERS, WHICH ARE EQUAL TO AN EXPENDITURE THAT VARIES WITH"
1130 PRINT"DISTANCE TO THE TARGET)"
1140 PRINT
1150 PRINT"NOTE:  YOU ARE CONTINUOUSLY BEING DRAWN TOWARD DARTH VADER"
1160 PRINT"WATCH YOUR RANGE CLOSELY!!"
1170 PRINT
1180 PRINT
1190 PRINT"THIS IS COMPUTER CONTROL."
1200 P=100000!
1210 B1=9.45426E+12
1220 P(1)=100000!
1230 A=INT(RND(1)*200000!)
1240 PRINT
1250 PRINT"DARTH VADER APPROACHING AT ";A;" KILOMETERS"
1260 PRINT"DISTANCE TO YAVIN-4 IS ";B1;" KILOMETERS"
1270 PRINT
1280 PRINT"MAY THE FORCE BE WITH YOU!!"
1290 PRINT
1300 PRINT
1310 PRINT
1320 ON ATTENTION GOTO 1520
1330 IF A2$<>"Y" THEN 1540
1340 D9=D9+1
1350 C=INT(RND(1)*3.14159*(RND(1)*3.14159))
1360 O=INT(RND(1)*2+1)
1370 IF A>200050! THEN 3180
1380 IF C=O THEN 1350
1390 IF A>50000! THEN 1410
1400 IF C=4 THEN 1770
1410 IF C=5 THEN 1350
1420 IF C<>6 THEN 1440
1430 IF P>5000 THEN 1350
1440 IF C<7 THEN 1460
1450 IF C=7 THEN 1500
1460 IF C>7 THEN 1350
1470 N=0
1480 B1=B1-(2.23119E+10)
1490 GOTO 2060
1500 IF N>0 THEN 1350
1510 GOTO 2060
1520 X7=0
1530 X8=0
1540 PRINT
1550 X7=X7+1
1560 IF X7<X8 THEN 1620
1565 GOSUB 6720
1570 PRINT"WHAT ARE YOUR INSTRUCTIONS ";
1580 X8=0
1590 X7=0
1600 ON ATTENTION GOTO 1520
1610 INPUT C
1620 IF C>=1 THEN 1640
1630 GOTO 1730
1640 IF C<=9 THEN 1770
1650 IF C<>10 THEN 1720
1660 PRINT"ENTER NUMBER OF AUTO-PLAYS ";
1670 INPUT X8
1675 GOSUB 6720
1680 PRINT"ENTER COMMAND TO EXECUTE ";
1690 INPUT C
1700 ON ATTENTION GOTO 1520
1710 GOTO 1620
1720 REM C
1730 PRINT
1740 PRINT"THAT NUMBER IS NOT A COMMAND ";A$
1750 PRINT"TRY AGAIN"
1760 GOTO 1540
1770 D9=D9+1
1780 O=INT(RND(1)*2+1)
1790 REM X
1800 GOTO 1820
1810 IF C<6 THEN 2510
1820 IF C=1 THEN 1840
1830 GOTO 1880
1840 IF A>=0 THEN 1860
1850 GOTO 2510
1860 IF A<11001 THEN 2000
1870 GOTO 2510
1880 IF C=2 THEN 1900
1890 GOTO 1940
1900 IF A>10999 THEN 1920
1910 GOTO 2510
1920 IF A<100001! THEN 2000
1930 GOTO 2510
1940 IF C=3 THEN 1960
1950 GOTO 2000
1960 IF A>99999! THEN 1980
1970 GOTO 2510
1980 IF A<200001! THEN 2000
1990 GOTO 2510
2000 IF C<7 THEN 2040
2010 IF C=7 THEN 2060
2020 IF C=8 THEN 5420
2030 IF C=9 THEN 5900
2040 N=0
2050 B1=B1-(2.33119E+10)
2060 IF C=1 THEN 2530
2070 IF C=2 THEN 2680
2080 IF C=3 THEN 2840
2090 IF C=4 THEN 2970
2100 IF C=5 THEN 3070
2110 IF C=6 THEN 3180
2120 IF A2$<>"Y" THEN 2180
2130 H=INT(RND(1)*10+1)
2140 IF P-(10000*H^.3)<500 THEN 1350
2150 IF H=0 THEN 2130
2160 GOSUB 6070
2170 GOTO 2230
2180 IF C>77 THEN 2490
2190 PRINT"PLEASE INDICATE HYPER-FACTOR";
2200 INPUT H
2210 IF S1>0 THEN 2160
2220 H2=1
2230 IF H<13 THEN 2250
2240 GOTO 2180
2250 P=P-(10000*(H^.3))
2260 N=N+1
2270 PRINT"COMPUTING COURSE AT H-F: ";H
2280 H9=H9+1
2290 IF P<100 THEN 4440
2300 IF B1-((H^3*299793!)*60^2)<1E+06 THEN 4190
2310 IF N>1 THEN 4410
2320 A=A+((H^3*299793!)*60^2)
2330 IF O=1 THEN 4970
2340 O2=INT(RND(1)*3.1415926#+1)
2350 IF O2=1 THEN 4970
2360 IF O2=4 THEN 4940
2370 B1=B1-(H^3*299793!)*(INT(3.14159^3*RND(1)+29)^2)
2380 PRINT"SORRY, ERROR PUT US OFF LINE."
2390 IF O2=3 THEN 2450
2400 IF P(1)=P(1)-(H^.3*10000)<10000 THEN 3350
2410 PRINT"DARTH VADER FOLLOWED!!"
2420 P(1)=P(1)-(10000*(H^.3))
2430 A=INT(RND(1)*200000!)
2440 GOTO 3210
2450 PRINT"NO SIGN OF DARTH VADER, CRUISING AT .9C"
2460 B1=B1-(2.33118E+10)
2470 IF B1<1E+06 THEN 4530
2480 GOTO 4050
2490 IF O=1 THEN 4020
2500 GOTO 1330
2510 PRINT A$;", LETS NOT CRACK UNDER PRESSURE, CHECK YOUR RANGE!!"
2520 GOTO 1330
2530 IF A>11005 THEN 2490
2540 IF A<10 THEN 2490
2550 P=P-100
2560 PRINT
2570 PRINT"GUNS HAVE BEEN FIRE..."
2580 IF O=1 THEN 2610
2590 PRINT"DARTH VADER MANUEVERING..."
2600 GOTO 2780
2610 PRINT"AWAITING DAMAGE ASSESSMENT"
2620 IF O=1 THEN 2650
2630 PRINT"MISSED - DRAT!!"
2640 GOTO 3210
2650 PRINT"HIT!!!  - - HIS POWER DOWN!!"
2660 P(1)=P(1)-100
2670 GOTO 3210
2680 IF A>100000! THEN 2490
2690 IF A<10000 THEN 2490
2700 P=P-100
2710 PRINT
2720 PRINT"WE HAVE LAUNCHED A WARHEAD..."
2730 O1=INT(RND(1)*2)+1
2740 IF O1=1 THEN 2770
2750 PRINT"DARTH VADER MANEUVERING..."
2760 GOTO 2780
2770 PRINT"DARTH VADER IS TRYING AVOID..."
2780 IF O=1 THEN 2810
2790 PRINT"MISSED!! - - DRAT!!"
2800 GOTO 3210
2810 PRINT"GOT HIM!!!"
2820 P(1)=P(1)-1000
2830 GOTO 3210
2840 IF A<100000! THEN 2490
2850 P=P-1000
2860 PRINT"LASERS FIRED!!"
2870 O1=INT(RND(1)*2+1)
2880 IF 1=1 THEN 2900
2890 PRINT"I THINK...I THINK..."
2900 PRINT"MAYBE..."
2910 IF 0=1 THEN 2940
2920 PRINT"MISSED!!...PHOOEY!!"
2930 GOTO 3210
2940 PRINT"GOT HIM!!!  GOOD SHOOTING ";A$;"!"
2950 P(1)=P(1)-(((200000!-A)/100000!)*3000)
2960 GOTO 3290
2970 PRINT
2980 PRINT"APPROACHING, ";A$
2990 B=INT(RND(1)*30000+60000!)
3000 A=A-B
3010 P=P-100
3020 IF A<1 THEN 3040
3030 GOTO 3210
3040 PRINT TAB(15);">>COLLISION<<"
3050 Q=4
3060 GOTO 5670
3070 PRINT
3080 PRINT"RETREATING ";A$
3090 B=RND(1)*40000!+10000
3100 A=A+B
3110 P=P-100
3120 IF A>175000! THEN 4290
3130 GOTO 3210
3140 PRINT A$;" YOUR RANGE IS ";A;", WE CANNOT RUN."
3150 A=200000!
3160 IF O1=1 THEN 4290
3170 GOTO 3210
3180 PRINT
3190 PRINT"RESTING, ";A$
3200 P=P+1000
3210 PRINT
3220 PRINT
3230 IF O=1 THEN 3290
3240 PRINT
3250 PRINT
3260 PRINT TAB(10);"SENSOR READINGS ON DARTH VADER'S SHIP"
3270 PRINT
3280 PRINT"RANGE: ";INT(A);TAB(30);"POWER: ";INT(P(1))
3290 IF A>200050! THEN 3350
3300 IF P(1)<100 THEN 4510
3310 IF P(1)<5000 THEN 4230
3320 IF A>175000! THEN 4290
3330 IF A<5000 THEN 4350
3340 GOTO 3420
3350 IF P(1)-(10000*H^.3)<2000 THEN 4230
3360 P(1)=P(1)-(10000*H^.3)
3370 O1=INT(RND(1)*3.14159+1)
3380 PRINT
3390 IF O1=4 THEN 4920
3400 A=INT(RND(1)*40000!+10000)
3410 PRINT"DARTH VADER IS ON US!!!!"
3420 IF B1<1.5E+06 THEN 4530
3430 G=INT(RND(1)*30+1)
3440 IF G=3 THEN 6660
3450 R=INT(RND(1)*3.14159+1)
3460 O=INT(RND(1)*2+1)
3470 IF R=1 THEN 3880
3480 IF R=2 THEN 3730
3490 IF R=4 THEN 4270
3500 IF R=3 THEN 3750
3510 IF A<100000! THEN 3430
3520 PRINT
3530 IF A<10001 THEN 3930
3540 IF A<100001! THEN 3800
3550 IF A>200001! THEN 3430
3560 PRINT
3570 P(1)=P(1)-1000
3580 PRINT
3590 PRINT"DARTH VADER HAS FIRED LASERS..."
3600 O1=INT(RND(1)*2+1)
3610 IF O1=1 THEN 3640
3620 PRINT"VH-OH..."
3630 GOTO 3650
3640 PRINT"SCREEN AT FULL POWER..."
3650 IF O1=1 THEN 3680
3660 PRINT"MISSED...WHEW!!!"
3670 GOTO 4050
3680 IF O1=2 THEN 3700
3690 PRINT"  OOOOFF..."
3700 PRINT"DARTH VADER GOT US!!!"
3710 Q=1
3720 GOTO 5670
3730 IF A<100000! THEN 3430
3740 IF A>10000 THEN 3430
3750 IF A>10999 THEN 3770
3760 GOTO 3430
3770 IF A<1E+06 THEN 3790
3780 GOTO 3430
3790 REM X
3800 P(1)=P(1)-100
3810 PRINT"DARTH VADER HAS LAUNCHED A WARHEAD..."
3820 IF O=1 THEN 3850
3830 PRINT"MISSED!!!..HA!!"
3840 GOTO 4050
3850 PRINT"  HIT!!! OUR POWER DOWN!!"
3860 Q=2
3870 GOTO 5670
3880 IF A>200000! THEN 3430
3890 IF A<11001 THEN 3940
3900 IF A<100001! THEN 3800
3910 IF A<200001! THEN 3570
3920 REM X
3930 P(1)=P(1)-10
3940 PRINT"DARTH VADER HAS FIRED A SHELL..."
3950 PRINT"I AM ATTEMPTING TO AVOID..."
3960 IF O=1 THEN 4020
3970 PRINT"MISSED!!"
3980 IF O1=1 THEN 4050
3990 PRINT"THAT'LL TEACH YOU WHAT CLEAN LIVING DOES ";
4000 PRINT"FOR YA', ";A$
4010 GOTO 4050
4020 PRINT"DIRECT HIT!!! POWER DOWN!!"
4030 Q=3
4040 GOTO 5670
4050 PRINT
4060 PRINT
4070 PRINT TAB(10);"STATUS OF MILLENNIUM FALCON"
4080 PRINT
4090 A=(A*.98)
4100 PRINT"POWER IN PRIMARY SCREENS:";INT(S1)
4110 PRINT"RANGE:";INT(A);TAB(30);"POWER:";INT(P)
4120 IF P<1 THEN 4580
4130 IF O=1 THEN 4170
4140 PRINT"DISTANCE TO YAVIN-4 :";B1;" KILOMETERS"
4150 Q=Q+1
4160 PRINT"DAYS IN TRANSIT:";D9;"    HYPER SPACE JUMPS:";H9
4170 IF D9>=365 THEN 4570
4180 IF B1>1E+06 THEN 4220
4190 IF O=1 THEN 4530
4200 PRINT"WE ARE GOING TO COLLIDE IN YAVIN-4 !!!"
4210 GOTO 4450
4220 GOTO 1330
4230 PRINT
4240 P(1)=P(1)+1000
4250 PRINT"DARTH VADER RESTING, ";A$
4260 GOTO 4050
4270 IF A<150000! THEN 3430
4280 IF A>200050! THEN 3290
4290 B=RND(1)*40000!+10000
4300 A=A+B
4310 PRINT
4320 PRINT"DARTH VADER APPROACHING, ";A$
4330 P(1)=P(1)-100
4340 GOTO 4050
4350 B=RND(1)*40000!+10000
4360 A=A+B
4370 PRINT
4380 PRINT"?"DARTH VADER RETREATING, ";A$
4390 P(1)=P(1)-100
4400 GOTO 4050
4410 PRINT A$;", YOU HAVE JUST ENTERED HYPERSPACE TWICE...ENGINES BLOWN!!!"
4420 PRINT"WE'RE STUCK HERE FOR EVER!!!!"
4430 GOTO 4450
4440 PRINT"YOU JUST HYPERED AWAY ALL OUR POWER..."
4450 PRINT"THAT WAS A PRETTY DUMB THING FOR YOU TO DO!!  YOUR"
4460 PRINT"MISSION WAS TO DELIVER YOUR PASSENGERS AND THE VITAL INFORMATION"
4470 PRINT"TO YAVIN-4, NOT TO GET EVERYBODY KILLED!!"
4480 PRINT
4490 PRINT A$;", YOUR A FIEG!!"
4500 GOTO 4590
4510 PRINT"DARTH VADER'S SHIP'S POWER GONE...NO LIFE FORMS PRESENT."
4520 GOTO 4550
4530 PRINT"HA! HA!  DARTH VADER GOT TOO CLOSE TO OUR HIDDEN BASE."
4540 PRINT"GROUND BASED LASERS DESTROYED HIS SHIP!!"
4550 PRINT"MISSION SUCCESSFUL!!!!"
4560 GOTO 4830
4570 PRINT"WE HAVE BEEN IN TRANSIT FOR MORE THAN A YEAR"
4580 PRINT"DARTH VADER IS THE VICTOR!!!"
4590 PRINT"LIFE SUPPORT SYSTEMS GONE..."
4600 PRINT"LIFE SUPPORT FADING..."
4610 PRINT"C"
4620 PRINT" R"
4630 PRINT"  E"
4640 PRINT"   W"
4650 PRINT"     "
4660 PRINT"     D"
4670 PRINT"      Y"
4680 PRINT"       I"
4690 PRINT"        N"
4700 PRINT"         G"
4710 PRINT"          ."
4720 PRINT"           ."
4730 PRINT"            ."
4740 PRINT"             ."
4750 PRINT"              ."
4760 PRINT"               ."
4770 V=V+1
4780 D3=INT(5*RND(1))+1
4790 IF D3=5 THEN 6150
4800 IF D3=4 THEN 6340
4810 IF D3=3 THEN 6470
4820 PRINT
4830 PRINT"PLAY AGAIN ";
4840 INPUT B$
4850 N=0
4860 IF B$="YES" THEN 260
4870 IF B$="Y" THEN 130 
4880 C5$="LOST"
4890 PRINT"VERY WELL"
4900 GOTO 6100
4910 REM X
4920 PRINT"DARTH VADER IS BEING SUCKED INTO A BLACK HOLE!!"
4930 GOTO 4550
4940 PRINT"OOPS...WE ARE BEING SUCKED INTO A BLACK HOLE!!"
4950 PRINT"SORRY ABOUT THAT CHIEF."
4960 GOTO 4610
4970 O2=INT(RND(1)*3.14159+1)
4980 B1=B1-((H^3*299793!)*60^2)
4990 IF B1<1E+06 THEN 4940
5000 IF P(1)-(H^.3*10000)<10000 THEN 3350
5010 PRINT"DARTH VADER FOLLOWED US THROUGH!!"
5020 P(1)=P(1)-(10000*(H^.3))
5030 A=INT(RND(1)*200000!)
5040 IF O2=4 THEN 5060
5050 GOTO 3210
5060 P=P+1000
5070 P(1)=P(1)+1000
5080 GOTO 4050
5090 PRINT
5100 PRINT"YOU ARE BOUND YAVIN-4, WHICH IS ONE LIGHT YEAR DISTANT."
5110 PRINT
5120 PRINT
5130 PRINT TAB(10);"HYPERDRIVE INFORMATION"
5140 PRINT
5150 FOR I=1 TO 12
5160 PRINT TAB(1);"H-F";I;TAB(10);"VELOCITY";299793!*I^3;TAB(35);"KPS"
5170 NEXT I
5180 PRINT
5190 PRINT
5200 PRINT"HYPERDRIVE CONSUMES ENERGY AT A MINIMUM OF 10,1000 STROMS AND A"
5210 PRINT"MAXIMUM OF 21,074 STROMS, AS FOLLOWS:"
5220 PRINT
5230 PRINT
5240 PRINT"ENTER ANY NUMBER WHEN READY TO CONTINUE ";
5250 INPUT Z9
5260 PRINT
5270 PRINT
5280 FOR I=1 TO 12
5290 II=I^.3*10000
5300 PRINT"HF -";I;TAB(9);"POWER CONSUMED -";II;"  STROMS"     
5310 NEXT I
5320 PRINT
5330 PRINT"HYPERSPACE NAVIGATION TENDS TO BE A BIT ERRATIC, RESULTING IN"
5340 PRINT"NAVIGATION ERRORS;  THE HIGHER THE HF FACTOR THE GREATER THE"
5350 PRINT"POTENTIAL ERROR."
5360 PRINT
5370 PRINT"THE DISRUPTERS ARE USED IF ALL ELSE FAILS.  DISRUPTERS"
5380 PRINT"CREATE A HIGH ENERGY FIELD IN SPACE.  THIS FIELD"
5390 PRINT"CAN DESTROY YOU OR DARTH VADER.  HOWEVER, DISRUPTERS"
5400 PRINT"SHOULD BE CONSIDERED AS THE LAST RESORT."
5410 RETURN
5420 Z=INT(RND(1)*3+1)
5430 PRINT
5440 PRINT"CONDITION RED  - DISRUPTER COMMAND ACTIVATED"
5450 PRINT
5460 PRINT"INPUT THE DISRUPTER PASSWORD ";:INPUT P6$
5470 IF P6$=P4$ THEN 5540
5480 PRINT
5490 PRINT"ILLEGAL PASSWORD  - ABORT DISRUPTER COMMAND"
5500 PRINT
5510 GOTO 1540
5520 PRINT
5530 PRINT
5540 PRINT
5550 PRINT"PASSWORD CORRECT  - ENGAGE DISRUPTER COMMAND"
5560 PRINT
5570 PRINT
5580 PRINT"DISRUPTERS ENGAGED..."
5590 PRINT"POWER BUILDING..."
5600 PRINT"DISRUPTERS FIRED!!!"
5610 IF Z=2 THEN 5640
5620 PRINT"THE DISRUPTERS HAVE FAILED!!!!...GAD!!!"
5630 GOTO 4450
5640 PRINT"THE DISRUPTERS HAVE DESTROYED DARTH VADER!!!!"
5650 PRINT
5660 GOTO 4510
5670 IF Q=1 THEN 5710
5680 IF Q=2 THEN 5750
5690 IF Q=3 THEN 5790
5700 IF Q=4 THEN 5840
5710 S1=S1-(((200000!-A)/100000!)*3000)
5720 IF S1<1 THEN 5880
5730 GOTO 5810
5740 REM X
5750 S1=S1-1000
5760 IF S1<1 THEN 5880
5770 GOTO 5810
5780 REM X
5790 S1=S1-100
5800 IF S1<S1 THEN 5880
5810 PRINT"SCREENS ABSORB BLAST."
5820 PRINT
5830 GOTO 4050
5840 PRINT"SCREEN OVERLOAD."
5850 PRINT"POWER DRAINED FROM BOTH SHIPS!!"
5860 REM X
5870 GOTO 4600
5880 PRINT"SHEILDS HAVE BUCKLED!!"
5890 GOTO 4580
5900 PRINT"RAISE OR LOWER PRIMARY SCREENS";
5910 INPUT S2$
5920 IF S2$="RAISE" THEN 5980
5930 IF S2$="R" THEN 5980
5940 P=P+S1
5950 PRINT"PRIMARY SCREENS ABSORBED."
5960 S1=0
5970 GOTO 4050
5980 PRINT"ENERGY TO PRIMARY SCREENS";
5990 INPUT S3
6000 IF S3>-1 THEN 6040
6010 PRINT"YOU CAN'T CHEAT ME ";A$;"!!"
6020 PRINT
6030 GOTO 5900
6040 P=P-S3
6050 S1=S1+S3
6060 GOTO 4050
6070 PRINT"ALL SCREEN ENERGY LOST."
6080 S1=0
6090 RETURN
6100 PRINT
6110 PRINT
6120 END
6130 PRINT
6140 PRINT
6150 PRINT
6160 PRINT"TO: GRAND MOTH TARKIN"
6170 PRINT"FROM: LORD DARTH VADER                 DATE: 26575"
6180 PRINT
6190 PRINT"TARKIN, THE VESSEL CONTAINING PRINCESS LEIA HAS BEEN"
6200 PRINT"DESTROYED.  ALL CREW MEMBERS AND PASSENGERS ARE DEAD."
6210 PRINT"THE PLAN OF THE DEATHSTAR ARE SAFE."
6220 PRINT"I SHALL RETURN SHORTLY, AFTER I HARASS PSGAMES AND"
6230 PRINT"SNARF THE *UPDATE* ON FORUM."
6240 PRINT
6250 PRINT
6260 PRINT"                    LORD DARTH VADER"
6270 PRINT
6280 PRINT
6290 PRINT
6300 PRINT
6310 GOTO 4830
6320 STOP
6330 PRINT
6340 PRINT
6350 PRINT"TO: REBEL BASES ON YAVIN-4"
6360 PRINT"FROM: SCOUT SHIP #13         DATE: 26768"
6370 PRINT
6380 PRINT"REGRET TO INFORM YOU THAT SPACE WRECKAGE WAS DISCOVERED"
6390 PRINT"IN SECTION #6.  THOUGHT TO BE REMAINS OF THE MILLENNIUM"
6400 PRINT"FALCON. NO SURVIVORS."
6410 PRINT
6420 PRINT
6430 PRINT"            CAPT. ERNEST"
6440 PRINT
6450 PRINT
6460 GOTO 4830
6470 PRINT
6480 PRINT
6490 PRINT
6500 PRINT"TO: STARFLEET COMMAND"
6510 PRINT"FROM: USS ENTERPRISE                 STARDATE: 2324"
6520 PRINT"OFFICER REPORTING:  CAPTAIN JAMES T. KIRK"
6530 PRINT
6540 PRINT
6550 PRINT"AFTER A LONG TOUR OF QUADANT H9 THE ENTERPRISE ENTERED"
6560 PRINT"A SPACE STORM WHICH PUT US OFF COURSE.  LONG RANGE"
6570 PRINT"SENORS DETECTED A SMALL MASS OF DEBRIS.  AFTER CLOSE"
6580 PRINT"INSPECTION FIRST OFFICER SPOCK DETERMINED THAT IT WAS"
6590 PRINT"A SPACE VESSEL BUILT BY A PRIMITIVE RACE."
6600 PRINT
6610 PRINT"                 USS ENTERPRISE"
6620 PRINT"                 CAPTAIN JAMES T. KIRK"
6630 PRINT
6640 PRINT
6650 GOTO 4830
6660 PRINT
6670 PRINT"LUCK...LUCK...LUCK..."
6680 PRINT
6690 PRINT"DARTH VADER LURKING, ";A$
6700 GOTO 3450
6710 END
6720 PRINT"1) HEAVY GUNS            4)APPROACH              7) ENTER HYPERSPACE"
6730 PRINT"2) WARHEADS              5) RETREAT              8) DISRUPTERS"
6740 PRINT"3) LASERS                6) CONTINUE TO YAVIN-4  9) DEFLECTOR SCREEN"
6750 PRINT
6760 RETURN
    8) DISRUPTERS"
6740 PRINT"3