10 ' F7(iTAo ;Se$cts typefae for ECI RX, FH >Xw/ Graftr0a=(RRD $rs
20 ' Cation  Will not)TORwith old RMX's I(IT requireSCII NULL fo60" 
0Tg Type tRCE R tOesetdC" selITM
ds  $s7 

E( $ 
)Tg TypeEor m t)$it to BAS$u5cg This RIC $ CNA4 
 ll NOT preventOratiAPl or meaninglesCo0ices, such CH 3Bo tryA' t9HoARINAITional mode o(Tnp$RCITn'G  OER tA
NNi25 ' S-pRat line 5(NT" (ut(Cish to A0   deTI1ETOl n X 3EI&N0 ntribtor is not r8,tAC 3He for the odd1 dA'   
L)=HRHun.  Note that
80oFaceLit wasOiginal

1RIi $cted, no doubt to prevA A$o X'RTI3Ru$l kiRX 4C0 ' at an example of amateurish BAoe6tC0o3I H0
NeTo0CO, '1E4 cOks.
100 PR
 CHR$(2X 3N HTaRINT TAB(1Ck ING$(s TB5X 3(oPRINT TAB(1NlR6B cAB(69)CHR$(58)
N  PRINT TAB(1NlR6B cAB(69)CHR$(58)
N  PRINT TAB(1NlR6B cAB(69)CHR$(58)
N5IRINT TAB(10)CHR$(58)TAB(35) ECELIF) B6T2N()<HR6B 9uP20AINT TAB(1NlR6B cAB(35)SING$(8,60n5"N(s
H6b) 3RICT INT TAB(1NlR6B cAB(35)TABB)<HR$(58) P( ICT INTRB(10)CHR$(58)5"HX"forHN$ EFR iMX, RX & FXAINTERS"TABB)<HR$(58) P)h PRIRT2T$CHR$(=IF(B")5"NCs
H6"Bo4"00 PRINT TAB(10)CH""Bd5"T) "NtbTp)"IRRS  i3.01F((69)Ce(58)
 HT INT 5"T$6NlR$(58F((69)Ce(58)
60 PR
 TAB$6N $5RcAB(6<HR$(58u30 PRINT TAB(10)CH""Bd5"T)No :dNT
 rTTR  $r $(d5"N()<HR$(58) ))Ta HF((10)CHR$(58)TAB(69)TH6"B 9u)5(oP HF((10)CHR$(58)TAB(69)TH6"B 9u)(BoP HF((10)CHR$(58)TAB(21);ING$(3846)TAB(69)TH6"B 9u)(EICT INT TAB(1NlR6B cAB(21)CHR$(58)TAB(58)CHR$(58)5"NCs
H6"Bo4"8PRINTRB(10)CHR$(58);ING$(10,46)TH6"B xOR TYPRECE ENU -RPRESS ANY KEY "Ce(58)STRI$$(10,46)CHR$(58u90 PRINT TAB(21)TH6"B 9k ($$(36,40
TH6"B  3C00 PRIN 3C10 GOSUB 890
320 IF H0e)a'EN GOTO 350
330AINT CH"IReA:PRIRCHR$(26):END
C40 LPRINL6IReA:P HlR$B5$Qn CDAM
35PRINTHR$(26u60 X$=""
370 GOSUB 80u80 PR
 CHR$(2$pAHKRH0R)R$(60)+HT"CH"N(5X 3C90 P HlR$B5$QEINT TAB(10)STRING$(60,46)
400 PR
 TAB$6N $5RcAB(6<HR$(58u10 PR
 TAB$6N $5RcAB(6<HR$(58u20 PRINT TAB(10)CH""Bd5"N()<HR$5R9u
wPRINTRB(10)CHR$(58)5"T)5Vns7;ECES"TAB(6<HR$(58u40 PRINT TAB(10)CH""Bd5"T)59RING$(ENa(7 B(69)CH""Bo3"5PRINT 
)(oPRIRT2IR(:rL8$ pT  TYPEFACE, PRESS LETTER   COMB,ON OF ETTER"
 LOW"
470 PRINT
4oPR
 TAB$6N $5RcAB(20)""$ 3NR9"fae"TAB(49)"<8SRnerlii)n5"N()<HR$(58) 
()IRINT TAB(10)CHR$(58)TAB(20)"<C>ondensed"TAB(49)"<8Pu3 
9<T tRR$"TAB(69)CHR$(58)
B$oPRIRT2T$CHR$(=IF(B6N(XA>lii)n5"T96<H>eavy"5"NCs
H6"Bo4BNt INT TAB(10)CH""Bd5"H(6N(s:P  3R
ne"TAB5C)s0MtalIN=7"N()<HR$(=Cu5)(oP HF((10)CHR$(58)TAB(20)"<W>ide"TA
5C)"<P>roporttAPlF((69)Ce(58)
C0 PRINT 5"T$6NlR$(58F((69)Ce(58)
"0 PRINT 5"T$6NlR$(58F((2V-NlANGE SELECT  i- t S C8 R"TAB(69)TH6"B 9u55aRIRT2T$CHR$(=IF(B)<HR$(58) 52PRINTRB(10)CHR$(58)5"T6R.t INTE)rMMA  S: RY$;5"NCs
H6"Bo4BEICT INTRB(10)CHR$(58)5"T$E9k ING$(4ATB50n)"9)CH""Bo45roPRINT TAB(10)CH""Bd;IN$(646)CHR6B xoSET PRINTTvRXIT RCELIFT, HITATURN "TAB(62)CHR$(58)STRING$BRTB50n5"X<e(58)
C0 PRINT 5"T$E<H""Bd;IN$(4446)TAB(62)TH6"B e&e p!