	REM	LABELS
	DIM	LAST$(6), FIRST$(6)
	DIM	ADDRESS$(6), CITY$(6),ZIP$(6),AREA$(6),TEL$(6)
	INPUT "MESSAGE: ";MESSAGE$
	INPUT "FILENAME: ";FILENAME$
	INPUT "HOW MANY LABELS UP: ";W
	COUNTER=0
	FILE	FILENAME$
 
10	FOR J=1 TO W
	LAST$(J)=" "
	FIRST$(J)=" "
	ADDRESS$(J)=" "
	CITY$(J)=" "
	ZIP$(J)=" "
	AREA$(J)=" "
	TEL$(J)=" "
	NEXT J
 
	FOR J=1 TO W
	READ #1; LAST$(J), FIRST$(J), ADDRESS$(J), CITY$(J),\
		ZIP$(J),AREA$(J),TEL$(J)
	IF LAST$(J)="END" THEN 20
	COUNTER=COUNTER+1
	NEXT J
	J=3

20	REM
	FOR K=1 TO W
	PRINT TAB(28*K-25); MESSAGE$;
	NEXT K
	PRINT
 
	FOR K=1 TO W
	PRINT TAB(28*K-27); FIRST$(K);LAST$(K);
	NEXT K
	PRINT
 
	FOR K=1 TO W
	PRINT TAB(28*K-27); ADDRESS$(K);
	NEXT K
	PRINT
 
	FOR K=1 TO W
	PRINT TAB(28*K-27); CITY$(K);". "; ZIP$(K);
	NEXT K
	PRINT
	PRINT
	PRINT
	IF LAST$(J)="END" THEN 30
	GOTO 10
 
30	PRINT
	PRINT "END OF LIST"
	PRINT COUNTER, "NAMES"
	GOTO 99

99	END
