10EM *******************************************************************
1GREM * 1"R1PU) 5,RIIIIIIIIIIIPROGRAM NAME: RC1 >=0U 
5,RIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII*

REM *
OCOMPUTES  E NE E1
 099;D VALO
1O4% U  STOR
;      *
60EM *      "OACORS1
AEIF90OOULATED R63O16PUT                   *
70 REM *GBY: M.F. KAV
RPI--VEALEY UNIVERSI
0I*0PG5,RIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII*
GRE
C( 1GPRINT:PRTI1 DO YOU WISFE
0TS16E 1P0V0HSTOR (1HM-0 MEG)"
120  INT)I(CEOA TOR (1PF-1T,4N9P4FO0UU;II"      (E)XIT"
0*VU INT:INPUT I$
15 F I"ER0 OT500
 GIF I$="C" GOI1T*O70 IFS="E" (
I9000000000000000000000000000000000EEP0 OTO11400 REM
R  E :
RE1R0U S **********************************
  
R"U0R
T$="RESISTORS":GOSUB 1=1O),*VU INT " 031T
 E RE1R0U  VALUES USING THPOWER OF EIFORMTEE
*VU INT "ERRON5M.9OFCRRE03EFTER ALL VA9U2  AVE BEEN EN,3R8NO)" FOR I=066SUB 164O$11CS "T I
561 F11111111111111111111111111111111111111111111111111111111111111111111111111111111111111O N: 8TI)="":NEXT I
560 OSUT D*FO50 FOI= 1 TN
600 
V(I)>=1E+06 THEN V(I)=V(I)/1E+06:V 0G
35M6 
OTO 630
 GIF V(I)>=10000! THEN V(I)=VG6GI1+,=E 0G"K/
T
I63OLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL
V$(IEEOHMS"
63BI"T OLUEGGOSUB 19FOL0*V EM ****** DI
U,N46"V"GLUE ****************
650 GOSUTB ALI
OI1I FO0T:IREM
1010 REM ******************** CAPACITORS ***********************************T L1GREMT .*(L=N3O3:HTORS":GOSUB 1=1O( ) PRII"ENT1TE R63O
1OAPACITOR NN9)31$R NG THE PO=,1TEN FORMAT."
T90 P6T "E1$
MVCFAN$;ECTED AFTER ALL  E VALOEG
A	