1 60)T0COD2 H000NES DOOR HENK WEVER2e4+M NAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA INLICHTINGEN BASI  ,i20d+M NOS, iJ)1.:"HILVERSUM  
5 PAT CHR$(26);:WID10255) 

OTO 10B2e n =PO 1010
I l)UCHR$(251
IP RN E R52H
S
P- HI=.00 E0b