10 DIM M10S,M(8),C08),1036 N=&A2 7M (36),SM(,),M2SF9(15)
.LRH5 I=TO 8:REAE(O10I),M(I),C$()1IO9T
30 F  HSTO 17,C: S$(2 7ANA2 9L):LS(I)=SM(I)^3.5:NEXT
10E5 I=18 1M6:READ 10I),SS$(I),LS(I):SM(I)=LS(I*U
2714:NEXT
R0 DA"/IAAS BL$SVI6PALE BLUE,A,3.2,WHITE,F,1.54I)".:E CCS 0 DATG,1.H  :LOW,K,.75,ORAD$A$RS!6RED,D,0."Y
7DATA SOL,G2,1.0,ALPHA CEN7RI,G4,1.08,ALPHAHNTAURI B,K1,.88
80 DATATSILON ER (IH OAR,."TAU CETI,G8,.8)
2D2P.U0 OPHIU0 "K1,("70 OPHIUCHI B,K5,.65
100 DATETCASE;EIAM R)5E *4,ETA CASSI1LAE B,K6,R8
AI0 2P,;0(81 MNKTE2E0".R,36 OPHIUCHM OAR WWCCI01L2P.M6 OPHK SOA 6.760"SOH03,K2,.76
130TFA D PP&ONIS,U,.98
R ERIDANI,G5,.91
140TFA BETA HYDRI,G1,1.O,H8832,K3 W$CCIS.L0 2P,;E ),A1,23,CANOPUS,F 1= VEGA,S R,AL25U K2,100
160 DATA RIGEL,B8,R000,C1DL G8,145, JYON,F5,16
E0 DATACHERNAR,B"1000,ALTAIR,A7,1 BETELGEUSE,M2,830S
EC0 DA")HBARAN,K5E,0,SPICA,B1H60,ANTARESVC30
E5D0 2P.TOLO9,K0,33,FOMALHAUTOO,/S7TA CRUCRE)= 8C(S
.
I0 2P.
EB,A2,R000,REGU05EE,160,B L0EYS STAR,M".0O 
210 PRINT CHR$VNBSN WTHI HILDET)
 DIH 1IN ENTER TH
EM0"RH5 THE OPON YOUNC LT)
UO0 PR )PI.N TE ,2ONLE1T5"
240 PRIITIR=2E1T5 NOT ONIST"
UR0RINT"3. LI OE?N START)
 0RINT"4. QUIT"
H0 INPUT"YOUR CH0I1 ))
U
DTRA<1 OR A>4)T
 210
290 ON(A)GOTO 360R00,320,300
300 INPUT"A1:OU SURE YOU WANI$QUIT? ",A$
310 IF0G0
/S89 ORSC(A$)=121)HN END EL1R10
R0 PRIN
ER$(&H1=N I KNO NETT1#ING STARS:":PRINT
O30 F  HSTO 12
340 PRINT$(I);TAB(20);S$EB1BTTAB(4=IB10I54)
20 NEX80/EIIH 1IALI2F"W0R,AR SHOULD HSE? ",S$
370P(S)"N1, OR$=""LUNIA0S
O80 FOI=1$36
3DTR
AMHM (I4IUN SK=I:WE..20
100 NEXTA
410 PRINT"I DMDT
H? TH E1T1":GE.R20
120C = A
 H0H (SS$(
S,1))/1S
1DELO1)LEM (SS$3AS,1)
140 FOR I=1 TO 7:ICDO1)SC$(I4IUN J=I:GOTO 460
150 NEXT
160 M7
9)K)I=L
MAS:AS=(MS^-2.5)*10
U0 P=(ER5MS/(L^.285714))/.005
180 I5M. (0*AS>1.IUP=1000T=
490 GOTO 690
R0INPUTHEAT IS THE STAR'S NA1 R B1A
5ITAET"WHAT IS THE STAR'SPECTR EAIHMFT DO1AR2IF(O1B>"")THEN 590
530
AET"EAT   LU AB:UTE O0NITUDE (0AS4.85)1 O
5DN0*2SEG.-.4*M):MS=L^.28U14
R50 FOR I=1 TO 7:IG*L)<M.IUJ=I-1:GE.2GS
R60 NEX80HH0 S1)SC$E7 =:SC=INT((MS-MKB40M(I)-M(J)))/10
C0 GOTO 630
590C=VAL(RIGHT$(S1"1))/10:S1$=LEFT0S1$,1)
600 FOR I=1 TO 7HT(S1$9M10I))TH OSI:WE.,20
"10 NEXTTRINT"I DMDT
H? TH 0(U2RELWE.210
620 M8*!=SC*(M(J)-M(J+1))
6DT==<3HR.5)*10
64PRINT S$;" HAS AN EI18D LIF?IEPAS  S:LLI"YEARS 
650 INPUT"WHAT PERC "(1..100) HAS ALREADY =SEW ",P
"60 I5M. (0*AS>14IUN PRINTIU BIE)(IECURRED2 BNTEC OIEA"AGO.":I2FE"THIS WHAT YOU WAOFT ,1DIF(A(
/)<>89)TH SA0S
"70 MS=MS*(1.25-.005*P)
"8L=MS^3R
6D H(= 00(OS2S^N8S0
I0 98BOG133333
710 PR "0H.$H1A);" :LAR DATA SRINT
H20RINT"TH4DECTED T5, ";1F"TE.
IH"'";O1FM( (;"' STAR."
M0 IFGOC175)THEPRINT"I1,"
40J+1)DGOTO 760
740P(S3125)TH IH 1IIT6";C$KP:GO1U60
750 PRINT " SAFRT ;C$(J);AND;C$(J+1)A
760 PRINTIN COLOR.": 1 T "HAS A MASS OF";=N SOLAR
SSRT 
U0 PR L
I IT IEEP"TIMEAS BRIGHT "THE SUE N8SAIIH 1II B1F" HAS AN EXPI1:IFESP"OFTAS;"BILLIOY2S."
79PRINT"I1DEPP;12CENT (ABOLEPASP/10T"BNTEC OIEA
"INTITLIFESCRR
800 IF(P>95)THEPRINT"I1,IN ITS DEATH THR)."
810 IF(P<5)THEPRINT"I1,JUS2S8<Y STAR 
820 PRINT" H"A MEAN SURFACE T;ERR5EF";TS;"DEGHS KELVIN,"

M0 I38+SC<2R  EK+MCU)HN PRINTC0  ""ISOT BELI"OI TO HAVE PL1PS.":GE.CGS

LIH 1IN AND IT OD HAE PLANETS 
850 PRINB1F" WILL D AA T
,0 IF<..5)THEN PR LUITE DWARF.IGO15C(SME0 IF(MS<4)TH IH 1INEUTR"STAR :GOTO 900
880 IF(MS10)HN PRINT17EC E1T5 AFTER GOING NOA."(OTO 900

5DIH 1IN BLACK :E AFTER GT(LE2;TH&A 
900
AET"HFH E1T-,A$
( ( IF(ASC(1S=8STHEN 20S
1LI(DMAA0S
(LIH 1IIEAER0&H1A);"RH5MAT
 WN # BENFH Y ABOUT T1OAINLANET OF  1=T."
94PRINT:PR LR,0TH HAS ANVT*H SURFACE T;ERR5EF 6DEGREES F."
950 INPUT"WHAT SURFACE TEMPERATURE WOULD YOUIKE1 NALTPNAB4GS
(LTTL2 DESIRED 0HTACE .O6"MI (EAR1) 1)? ",A
970 IF(G=0)THEN PRINT"COMEN, THE PL1P MUST HAVE SO.(RAVITY!IGO1G,0
980 RP=SQR(L/(O.220)^4)
990P(RMOS0P4IUNRINT"TH I
TC F6TOCLO"I$RE1T+LRELGOTO 940
1000 PP=SQR(RP^3/MS)
RAITE(CE$(R2FN8IA01LQRAAAR0.E
1030 RX=.0622*EI
STC
SU5I8CS
T3";<0 B6FCIAS.LTTL2F3W BLEL3UL LI
TC F RE S1RP ,I$E NDC2TH = 3FT ,D
T3 E+0M(L*D
1070 IF(M.055)TH IH 1ITHIS PLANET WO:T RETA TC 9YGEN ATMOSP2E.S
T3NDTR
>E.6)TH IH 1ITHIS PLANET WO:T LO""H"HYDROG TFMOLURRT)
T31TRINT"2TH'S ORBIT HAS AN EN0II.IT ORARO SSF 
E (0 INPUT"WHAT IS THE OR"P: EN0II.IT (LESS TH"1)1 OAA
1110 IDK=>1)HN 1100
1120 CA01-EC)*RP:FA=(1HC)*RP
113INPUT3W DOETHE 51,TILT (E N
EO.5 DEGHS)1 IP)
E $( IDPO"* O
2GEE1130
1150
AET"? MANY MOONS DOESEELANET HAVE1 ON
E $EITR
08O
T1IUN PRINT"FOR CONVENIENCE WDLL
LLIT.":M:A0S
E0LABBIAAAI<EEEU"*G
E K0 IF(MN<=0)T
 1280
E *0 FOI=1$MN
ER00 PR LASS OF B
 REPI;"(OUR MOON = 1)";1NAET"?  MN(I)
EAITTL2F"ORB (OUR MOON = 30)1 OR(
8I0P.LTR
09ANA<0(.IUNRINT"THOOON IS<0  ,(AINNN S9 C>1HP.":WE. 51S
ER30P(MR(I826*G)THEN PR LR.OC TE"TOO FAR AWAY ANOTPP".ETT OF ,:WE. 51S
ER40F(ISSQR(MR(MGM/M)4
1R0 IF(MRTB)F4IUMM=MP(ILR=MR(I)
H"0 H=MN(I)*.01235/(MR(I)^3BH
HH0 NEXT
ER80 H2=
2*D^4/M*(30M33CMKV(11759*RP)^3+H)
ERD0)1.7GR6E+ O5*14+10
1300P(DA>MM)HN DAOM
131PRINT CE.0&H1AP"PLANETAR INFORMATION:IPRINT:PRII NR.TL1P'S DAY SHOULD BEBOUT";DT"HOURS LO=E N8ISXEH T"THAT MAKES ITS YEAR"C766/DA*PP;1ODLONG.  WITH A TILT OFTTN  
1330 HI=(31025*DA/2S*TP-460:< ?.025*DA/1)*TP-460
1.0 IF1?,0)THEN LOW460
EM50 IF(HI<-46.IUHI=460
1360 PRII I'AY'S HIGH T;ERR5EHOU"S7";HI;"D
 R=  IT)
EM7PRINT"AND TO02F'S*8TED ? SHOULD BE AROUND";LO;"."
EM80 SH=HI+1.9*TI*(1+EC)^2:LL=LO-1.9*TI/(1+EC)^2
1390 IF(LL<-460)THEN LL=-460
1400P(SMW460LUNH=-460
1 ( PRINT"LS SUW2 R D18T IT TGET UTO";SH;", AND"
1420 PRINT"THIWINR R D18T IT TGET DPL IVSNPLEIEGHS F."
1430 IF(SH<32 OR LL>175)TH IH 1ITHERE ARE TIM OEN NO LIQUID WATER* H"
1440 PRINT" "MI KEY TCONNUE.":A$=I2F$(1)
 9EITR
08OO)0)HN 159S
E.60 IG80D0.IITE"0
1470 FOI=1$MN:FOR K=1$(MNI)
E.80 IF(MR(K+1S>MRC))THEN 1530
15D A5(K)OR()=MRC+1):MR(K+1ST
1500 T=MN(K)ON()=MNC+1):MN(K+1ST
1510 T=MP(K)OP()=MPC+1):MP(K+1ST
1520 F=1
153NEXT K
154IF(S0)HN 156S
E250 NEXT I
156PRINT CE.0&H1AP"YOUR SELECTED SYSM OF MOONS:IPRINT
1570 PRII *S:T","MASS","PERIOD"
1580 FOI=1$MN:PRINT2(I A0I),MPTBT"HRS"-PB4LT"DAYS":NEXT
1590 INPLEIO YOUNC "ATR212ENT SET OF B
S? ",A$
1600 IF(ASC(1S=8STHEN 1150
E,II1IIEAER$(&H1=N PLANETAL RP>IELPRINT
1620 PRINT"0"IH 1APAL PLANET OF INREST HAS AN AVERAGE SUIMNS 
1M0 PR LBFERATURE OF";OH.3T"*US F.  LS REQ ,=N E)"LTLO STDI1IN OF";)N ASECEBLC EENS, ORTRP*93;"TP1 K ADLEE N8IO 01LIH 1INEEDOS "LH K8H T";S$  TELEPCA;"AE.,S
E,60 PRINT"(  NR.(REAST DISTANCE FROM ";SF" IS";FA;"A.U."
1670 PRIN L,AL.OEANS THAT IT HAS YEAR TF IS";PP  OIEA"LONG."
1680 PRINPI. LI B1FAPPEA"TO BSN)$SUITR
AP!1.5 ORA<.75)TH IH 1I MUCH";
1700P(S:0.IUN PRINT"EEAME SIZE AS";ELSHT(SA>1)T
 PRINTLARGER THAEPELSE PR L
CDLEREAN";
EU10 PRINT" OUR SUN APPEARS."
1720 IF(G>.95 AND B1.05)T
 PRINTC1O ATE)SENTDLY THE SA,(,EAR!E2RELGOTO 1840
EU30 PRINTPT(I,NR.TLANEEAS A G&ITY";:IF(G<1)TH IOEGS
EU40RINT" GREATER TH"EARTH'S, WE EXPELT)
EU50 PR L N
8ER ATMLLU4  THERE IS GREATER TECTONIC LPEC TC0 E0REAR"
EU60 PRINT 04TT(LRH5CES; T05 EFRTC0NIPFE 9 .C PT1
TS AND SHORR"
EU70 PRINTB7NTAI2I  ,LZW
KES SHSHI BOORE FREQUENT AND 9 ,V $,
EUD0
FO 1840
15DIH 1IN  LESSEAN EARTH 9  R D18T"
180PRINT"A TTP12 ATBIL"$" NR5E ILESS TECTP0ITKTION AND LOWER"
1810 PR L0FE1T0 90IF THU  THER;PP"S7 FEWER C1TT1
 TC0 ETEWITLOAR0 PRINT"-PDN  ALMUGHEE MAY B+UITE TALL.  EARTHQUAKES,P MI,S
EC30 PRINT"PP"THS7 AS SEVERE AS ON EAI$,
184PRINT"A GR,"MI N (;"M
S THATP OU WEIGH 22POU15TCIOA20 PRIIE-T?DD WEIGH";G*2MT"POUNDS ON THTLANET."
1860 INPUT"WOULD YOU ONRT,LOFE0RAVII?  AA
1U0 IF0G0
/S89)THEN 960
188PRINT CE.0&H1AP"THE SUBJEC? NTR14..":PR 
8
5DTR
04UR ORJ W46)HN PRINS7CAUSE OF TH=MI ATMOLURT :GOTO 2270
1900P(R)F$ORP>RXLUNRINT"BEC0.""THE LEVEL OF YPION,":GOTO 227S
EG ( IF(SH<32 OR LL>12)T
 PRINTSONMESE THERE IS NO LIWLD WATER,":WE.R270
EGR0 IF030T<1.STHEN PRIIE8AUSE THE PL1P IS TOO YOUNG,":GOTOAEH0
1930 IF(P>.95)THEN PR LHCA.1 SIB1F" IS IN ITS DEA"N017S :GOTO 2H0
EG.0 IF(P<.05LUNRINT"BEC0.1IB1  IS SO YOUNG AND UNSTOIE,"(OTO 2270
120 PR LONDIONS AR.E0HTE5 THERI$BE SOME T
0,0P(A(T<2G)THEN PRIIEKRIA AND BL#GREEN AL2$,:GOTO 2R0
EGU0 IF(AS*P3*G)T
 PRINTPT(( E
SP"NTR11;E NUCL."(OTO 2250
1C0 IF030T<4*G)THEN PR LP-N .O"POH
SP"Y LIFE.":GE.R250
199IF(M0T<4.4*G)HN PRINOT212 VERTEBRATES AND LAND PLANTS.":GE.R250
20II1IN MAJORANDNIMALS, PECFS I(EEDIDTT1 :LIGENT LIFE 
2010 IF(G<.95)HN 210S
50 IF(G<1.05)THE2180
2030 PRINIDGHER GRAVITY MEH"A THICK A3SPHERERDCH WN EPPORIARGE"
2 ( PRINT"1HIS.  IT ALSO MEA"THAT SHORT FA 6CSHI BPATALEH,,C8TION"
20DIH 1INPW) WI E)RO"0HD SHORT. LL LIFEE5MS WN E SHORT AND STOCKY."
M EITR
J 42)HN PRIN L",(",L$7IEGGED ANIS15R S1.1TRIN L".O2F BE 2-L)DY ANIMA2RT)
.ME0RINT"THN0EA8 ATMOSPH ,P-E                                 0,SOUND.0I8:SSIOANDEDU="
MNDIH 1IN VISIBILITY EXCEPT IN THE INFRARED.  ANIMALS WOULD HAVE ",:Y"
2090 PRINA3RE "HEAR0)  B"THEIR EARS WOHI NOT HAVE TO BE 5GE.S
FTCLOTO 2180
FE1TRINT"?ER GRAVITY MEA"A THINNEATMOSPHERE SUIS, "ANY, PP"IC/E"
212PRINT"WIDE WINGSCE2ALL LIFEFOB OTP BE TALLEANDMRE SLE"5 THLT)
FEM0 PRIN L ,0AW
RPARTON EARTH.  HRE PROMMI A1OANY 2-LEGGE 
2140 PRINTCTACDS  LU TT"ATMLLU1EURTSOU" (I8:PECR  7,(IPKDS"
2.LIH 1IWILEIHR HAVE LAD,001,OR WILL NOEAVE &ELO: THE SEN"?IT)
F DIH 1IN HEARING AT TH "THENGS WILL BE ECH LARGRRT)
FG IF(TP>75)TH IH 1ISOMPORM I .OIIATION PROTECTION WILL BE NECESSARY."
2NDTR
AP!.75)HN 2210
2190 PRINTSONMESE OFEEMALSUNOTR I18T ANIS1,THER TO HAVE LARGODES"
2200 PR L, H,,:Y ON OTHERENSES, &ING NEVER D"S1W Y SIGHT."
FFTDT0SA<1.5)TH A40
F.LIH 1IN UNLESS TH2
3SURE IS OBSCURE  OTRGTECT RELIAN.HP"SIGHT"
2230 PRIIETT",:ATIVEL SSP" 'E  ASFON("L"
2240 I5D-LO>75)THEPRINT"E HW"IFERAT".$ARITE6FAVOR UND0
 ?
D AN$OR AQUATIC LIWE5ME N8A50 HM=((TP-460)>32 AND (OH.G3O5DAI G<1R ( E0>.2 AND M>. (AI M<2.35 ( EIA<96 AND SH<125 AND LL>-30 AND OO .0ND LO-0CSTU"0 GOTO 2280
2270 PR LHTE, ASI.8NOW IT, CANNOO9I EC DS PL1P.S
FU
DIH 1ITHIS PLANET ";HT(HM)HN PRINADGHT BE ";E11TRINOT?DAYT BE ";
22DI1IN CONSID Y HA"P+L3: MAN."
O00 INPLEF(II EFHERLANET?,A$
UO1IF((0
/)C9)THE930
2320 PRI 0U.0&HBSN OTHER PL1PS...":PRIN8AE*NPUI3W MAL  (IRH"ITHE LSTEM...15)?  NS
UO40 IF(NP>15)THEN PR LB1OANY...TRY AGAIN.":GOTO 2330
220 IFNA3)1)THEN 2790
UO6AM=1180EM=FGBAM^SQR(RP)
O70 R(1)=RP:M20GCCAEO80E5 I=2 TO NP
UO9PRINT CE.0&H1AP
2400RINT"TH7:ARY B"1,LAIEWPIKEEII": 1A
24II1IN PLAP",8)S","D P
RA1U.)"
120RINT"MERCURY",.UR,.387
130 PRINT"ENUS",.815 W53
U14PRINT"TE ) E"1
220 PR LARS",.3A"1.524
U16PRINT"JUPITER",317("5.)>8AE170 PRII ;FURN",95.2,9.539
2480 PRINT010AEE IOO  *.18
2490 PRINT1FTUNE",17.2,30.06
2500 PRINT"PRH6,.1,G144
UR1PRINT:PR LASS F TN10IR"#";I;:I2F"? ",NCT8S
UR20 IF(M
AM
TC
0.IUN PRINT"BODY THIS LARG;?I BEC7 A STAE SH0OTO 2510
2M0 PR LISTANCE FROM ";S$;" (A.U.)";:INPLEW,R(I)
2540P(RTBMOS/5)THEN PR LIANET IS TOO CLOSE TO ";S$;".IGO1R53S
UR50 IF(R(M
<O026)THEN PR LIANET IS TOO FAR FROM ";S$;".":WE.R530
2560 FOR K=1$I-1HT(R(K).9*R("AND M
S<1.1*R(I4IUN 2620
2570 NEXT K
UR80 A1=MP(I5BBR(
A
8AER90P(AD)+ 0ITI. LN THTLANET HATOO MUCH
SSE5 THE SYSM":GOTO 2C(S
U"00 AM=AM-A1
2 ( NEXT I:WE.R640
262PRINT"T1TLAN IS TOCLO"I$IUR PLANETS TO HAVE S<"*S:T."
U"3GOT2400
26DRH HI H,
ET3IFOR K=1 TO (NP-I)
2650P(RC+1)=>R(K))HN 2690
2,0 T=R(K):R(K)=R(K+1)F3
<1ST
2670 T=MP(K):MM
S=N3
<1):MP(K+1)=8AENDRI0S
U"90 NEX8
27IT0F=0)THEN 2R0
UH1NEXT I
2720 PRINT CHR$(&H1A);"THE SYSM OF ";SF":":PR )PI.N  (IR"#","MASS","OR""(EH.)"
UH30 F  HSTO NP
2.0 PR "T-ANA2 FC;
27DTR
ATCTLF$AND R(MSU9ND MP(I)>.055 AND NCTBM W46)THEN PRINT " LIFU-" ELSERINT
UH60 NEXTA
27DTTL2F"WOHI YOU LIKE TO TRY ANOTHER SYSM? ",A$
2780 IF(ASC(A$)=GST
 2320
2790 INPUT"WOU"OIOU LIKE TTRY ANOTHESTAR? ",A$
2CLTR
N=C(A$)=89)TH AGS
UAI C0T)
?/
2780 IF(ASC(A$)=GST, RT";OH.3T"*US F.  LS REQ ,=N E)"LTLO STDI1IN OF";)N ASECEBLC EENS, ORTRP*93;"TP1 K ADLEE N8IO 