1 <T RR1$1
HNR0tandaard inplNent
oRG=Ce4/83
,T door = k WHer2iR5O tE0oor aanpa
O"$"aiONANputer/$dNiVn4 REM  zrb
OEode.doc H"3Ad 5M
iskettn5 REM initialia
oRU
6 R3RRS0 55ITNGR DRLMBASIC 5.21 en S
$HT
!T)OINKEY$)
7olNT CemO 
R;"*";CHRVGP1$(0);CHRVGP1$(26); U3 H3eE255)
10 GOTO 10000
2R R3
 egels OUeE>(leL7 niet nodig voo$0Ma
OE
20 GOTO 1010
R9 REM  regel 10Uee>(learVeen
1 7o03RP1$;
R FT V6HR$(0) R$HTV);CHR$(0) R$HTUR471ETURN
OR R3
 egel 110RTH=MNREEursor$;HO en E
110 REM TERMINAL = NTE R =Mrs"e" IF HO>79 THENO=79
1bOCVE>23 THEN VE=23
$e6RA303R1$( N8=";Cep=(+32);$HT) 31O1;
$CCRETURN
119 REM O$HTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTV-130:aVT cursorpositie in HO enTFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFV IF HO > 79 THEN HO=80TH9 IF VE > 23 THENTaR
122 R3
vo:3R$dNinal 24 x 80TH0N5ONe:VIN$30>(R,1ETURN
90 GOS

200:IF IN$="" THEN10
211 RETURN
250 PRINT CHR;
R 3(2H
260 RV=RND(1):RETU N70 FR=80s):RE2Hd
300 SR$=STR$oNit) O7=LE)D(6N 
OE MHEN RETURN
30IF TRHT$oer
eR<" " THEN 304
303 SR$=LEFT$oerR=:=3NCNR
d2Nitsr0lF LEFT)DI:R)<>" " THEN RETURN
30RoeO5Te3l)DI5;
eR:GOT301
3104=SR:IF CN<0 mg
312 SR=INT(SR+.5):GOSUB OrNIO 33n3165=SGN(SR):SR=B)AR:E+s I)AR:O9=SRO8
31E
=14I6s
7E=2s=$peT =El 7n32O9=IT0aeI.5):SRa6NROSU 33n322 O9$=RIGHTn=n0H8+SR$,CN)
32T(
"=0 AND O9zR$0t=RR
32RoO
1E NROSUB 302pCOc61$0tHS(1E=8+SR$
328 eORoeO3 t IO9$
330OCLE)D(e s1C1$ 3O2i2 eOT
EFTnFE o ;R M):GOTO 340
334 SR$=RIGHT$(" "+SRMN O,HeU0O +URN
C2>  PRINSR$;:RETU N60 LPRINT:RETURN
