10 PR"  "Conversion from Inte8  :  :GnemonE$PPHU:EOP$ : D "I) TB
"OHTT T0 INP
O*ZPfileCame? "1  EH:"I 2 "OUTPUT f$: I"OPCI)e? ",NOTAF
HOPUT "Does  II
HPD S:E
D: DH,)D She ope1 
PCIL$(Y/N)? ",IN$
50 SPC$=" ":4P=
 $OOT",1)="O00I=r(R0 IF LEFT$(IN$+0 ,L$LF2HSO v  "Pleas$an IIF  $YH"I4LBH$NP" MOTO 40
0 NF"COAH:"OD$DIt=ROT)1" ("E<O)CA"$:OPEN "O",2"FTTDD:e46C1) THEN CLOSE:STOP
N
)$OINPUT # v ON=:"ODP OL
:DPH*M SP, "PE THLABE $OPERA
=$CODE, OPERAN5J=HCOMM" 
130 REMNE
0 IF RIHT$(IN$,
N0F2HEN IN<=35)HO$,LE
$O$)-1):GOTO0O:2OL
HP""ND H):IF IL=0 THEN IN$=" 0160 IFL<2 OR LEFT$$OCI
NBA" DL$1430NEIf+FADHC NTOIH="":OPC$="":OPD$="":CM$=""
  :e4P35)HO$,1)<>"PU=OD"+$(IN$,1)<>CHA L($THELC==PO$DTLC=2
190 FRHCHTO IL
200 CH$PID$("A"$FA+T T10 IF LCAR
$EN 240$T20 CM$=CM$+6)H"
COOTOR CM$=CHR$(9) THEN CM$=""
$ :"M"O ")T T40 IF CH$=":"P=HLC=1 THEN 360
250 IF ASC(CH$)=, OR ASC"$OOPTTHEQFE
 QF
260 IF$C,
$R$ ,0$T70 IF CH$=";
$EN LC=4:GOTO
 2 T80 BL$=")H"
PO$P EN BL$=SPC$
LW "
1 $<>BL$ "e"$$<>CHR$(9) THEN BF=1:GOTO 320EHT:e4IO$N"I=PRPOP
"0 IO$N:210 GOTO 360
320 IF CH$ =  
"e"$$ <= "z" THEN CH$=CHR$, O")1 >TT)EH$ :eNCN$UU=HC"CA4TTL$L"
:GOT$
 " 5AD LC=0I=PRP"T =LB$+CH$:GOTO 3:25 $W "
PC"$THENNF"=LC +5DM"PEL6E"L5T5 T5 $",OE+ IC
HP
)REM

fPP OP PHR1"1HE= 0$DTOPERAT=$CODES
HLf =PP
T:eJnRL$4GEF$EN 4:2AC GOSUB 1490:IF LE $(B$B <>"(" THEN  ="("+B$+O4
0"UEOD8IO:C 
IH
 "H:eJnRL$4= 2O" THR,60I 0 OSUB 1490:IF L$
 (B$,1)<"(" THEB$= 3O+ +")"
 E OPD"T +","80
LC ="N4
4:eJnRNGI9=00<PnRNGE1("L6N3
("+OPD$+"4
470F OPC$="LDED
$EN OPC$="NI,6NRD:0
$
= :O4
480 IF OPC$=1
"=00I=NPC$="LD":D$="BC,("+OS
0
02AE,HOP"C5E=00I=PSnRNGE1("L6("+D$+"),HL"
T:eJnRN= PER0I=PSGEOO0,$
"L5T"),DE":OPC$="LD"
"" "
"$="SBC
$ENL6N0,$
"L
0

BC
LC"LD"
  T0F OPC$="LDA"HEN OPC$==OI,ME3(0
$
= :O4
530 IF OPC$==P,HN
$EN ORNGE
PPFI:CP$"HT("L6A,("+OS
0
02 $AF
H"
C 50I 00I=NPC$="LD":D$="(PGEP
0

A"
  $W "
"NF"C50I I=P EN ORNGE
PPFI:CP$"HT("L6("+D$+"),A"
560 IF (OPC$<>"MOV") AND (OPC$ 4GDHE$0
2HE600
570 GOSUB 1490$"  ="M" THEN A$="(HL4
580 IF  =NTTHEN BF($
02 $t"NF"CPDNOP"BH:C 
I0$$" :eJnRND$e
$SnRN=H$F2 $CO)IFNF"COTTHEN ORN=POA GEOOS,"+OPD$
0",H"PC$="CZ"HEN OPC$=I OB
6N=P(O3PGE+T $"H:0PnRN=11+00I=PSnRN="JOP1MEOOZ,"+OPD$
,0 IF ORN=" THEN OPC$="
NP1("L6N,"+D$
650 IF OPC$O"" THEN OPC$="
NP1("L6NC,"+OPD$
R0 IF ORN=CTTHEN OPC$="CNP1("L6NSO,"G T7IF OPC$="=O
$EN ORN=POA GEOOSE,PGE+T $r)INPC$="C00I=PLC ="CALI,MEOOGAC 
"L5 T $"E0F (OPC$O9$$O: nRN=1PP") THSnRN="NI
P ANAOAH:22:eJnC EF2HEN GO
":C>" )MI 
"EAHT)H"
IH="" THENL6N3(C 
"$
710 IF OPC$=I
OTTL$OPC$=
PNI
FI OA630:OPD$="H FTOPD$
72IF OPC$="E$00I"PF"C )":OPD$=(C 
"L5 TPH:eJnRNRP)NTTL$OPC$=
PNI,MN39
"+OPDTP+,0 IFNF"C5JIC PC$="SUB" THEN OPC$="SUB MOSUB 1580
75IF OPC$="ID
TONPC$="SBI" THEN ORN=TCB MOSUB 1580GN3(C 
"L5PARIF OPC$="1 00I"PF"C )"
770 IF ORN3
OCP EN ORN3(
"L5 TPA)IF ORNROC F2HEN ORNRDNCMOSUBEAHTP+LW "PC$="DCO
$EN OPC$ E":GOSUB 1630
8,H"
"$="INR" THENNF"CPCB MOSUO9AH:2) "",HOP"CP  NI=PSnRNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNCI
FI OA630
+T0F OPC$="CH
00I=PSnRN= =5F) $ H"
"NF"C5"TH
 HSnRN= DIO4
840 IF OPC$= OA" THENL"PUB 1580nRANDT)

H"
"NF"C U"$00I=PSnRN3=02)
 ",H"
("NF"FBO($OR nRORI") THENNF"C FCANSUB 1580
P
)IF (OPC1I= 0C 
LC"XRIHTHEN ORN=C 
PPFI:CP$) :2)($:enRCMC" DL$OPC$OCC$02) LW "PC$="STC" THSnRN= OO,
900 IF OPC$=GTTHEN ORN=PF TDD"eJnRN= n0I=PSnRN= nB0EE20 IF ORN=C1  O
$EOP"C6C4
93IF OPC$=" CTHEN OPC$6RCATDD,0 IFNF"C6RC#" DL$OPC$6RC"
50 IF OPC$="RAL" DL$OPC$6LA"
96IF OPC$=", F2HEOP"C6,4
970 IF C$="HLT" THEOP"C  ALTTDtW OPCF"
0F2HENL6N0,$
"L
0

A"
9IF OPC$="4C"HEN OPC$=UT"GN0,4"+OPD$
10000 IF ORNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNTTHEN OPD$=" :O PD$+")"
1010 IF OPC$=P0OC00I=PSnRNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN"LDGEP
0 F
02ON,
:eJnRN=HIP TTHEN ORN9X"GN0,:4HLTON
  :e)nCPE$N($AND (OPD$= "O($THEN ORN3 ")I "D"
104IF OPC$="OePOTTHEN OPC$="EOA GEOOR
HLTON, W "
("NF"AN P ") OR (OPC$="POP") DL$GOSUBEO$ TON, ",H"
"NNG"$
$EN GOSUB 1490GEr)MO
":CPHT(= MEP,"+ :OPC$="LD"
1070 IF OPC$="LK" DL$OPC$PDN4
1H:eJnRN= PP L" THEOP"CPDNI,MEOO= PAPF TON
)IF ORN=+00<PGEOO=P
OP"C6O4
=T:0PnRN= ="IOI=PSGEOOnP("NF"C6ET"
NP P:eJnRN= CF2HEOP"COCACRN=+"
1120 IF OPC$="CCTTL$OPD$=C1("NFEOD
01130F OPC$="RPE" THEOP"C DNA nRN= =+"
N=,IF OPC$="PC
$EN ORNSO":C$="RO4
9 INPC$="RP" THENL6NS":OPC1$=+"
1160 IF ORN=NTTHEN OPD$="M":ORN=+"
110 JF"C6ST" THEOP"C) P A 3PGEP
0
1  :eJnRNBPP" DL$OPD$ AC 
"L2OND:eJnRNB+00<PnRNBPP":OPD17,"G T0" :eJnRNECP
TDL$OPC$AM":OPD$P1A 
= NL
,H"
"$="JC" THEOP"CAM":D$="C,"+OPD$NL
)IF ORNBPNC
$EN OPC$="P"GNn"
PGE+TOO  :0PnRNBPPE" THEOP"CAM":D$="PE,"+OPDTOL
,0 IF C$="JPO" THEOP"CAM":D$="PO,PGE+TOP$eJnRNBPM
$EN OPC$="P"GNGAC"L5 TOL
)IF ORNBPRZ" THENNF"CAN 1MEO7$
"L5 TOL
P
)JF"CAN ="IO
$EN OPC$=PR":ORNnP(O3PGE+TOL$:eJnRNN TTHEN ORNBPR"GN="
"+OPD$
T90 IFNF"CAN =CF2HENNF"CAN 1MEOOC,"+OPD$
1300 IF ORNBPMP" DL$OPC$AM"
13)IF ORNSCHL" THEOP"CAM":D$="(f4
1320=PP
1330=PP OP$RMENE8DTTHE
07PT RECOR0NN  ,0=PP
1350N$=LB$
1360 IFN$<>"" ANOP"N 4GP,C N" AND ORL$LDH" THEN INvP
B 
1370 IF NDO(O3
0O(  OR (LEN(OPD$)>0) OR (L0
1)>0) THENN$=INO""A L(IPn32ON ($H"
)P"("L5U4:
P (LEN(CM$)>0)HEN IN$ O$+CHR$(9)+OPD$NN  :e4P=P0M$)=0 THR"0O$ :1400 IF <("L5N),
$EN IN$=IN$"$A L(TTOEN)I<=35)CP5
1)<>" 0 ECM$A4$
CP5 TOE
20N$=INO""A L(IO1
1$ :L$v  IN$NE
40 PR"  #2,IN$NE
50 GOTO 90
E
60 REM
E
70 RP **** ENH
2HOPDU=O  OE
8REM
1490 A$=:B$="":IF L0,MEAOP=X HERET$=TTOL )LC=1:QF=-1:FOR 1CH$LEN(OPD$)
15 
,PD
5("L5
IC,1)= H
$EN QO8OP C 8OB"EP"",HQFP=HMID$(OPD$,0O":"C)F$EN LC=2PP"OP$ T30" "
PO"I=PS8"$+MID$(OPD$,IC,1)LSE B$T L+EA
MEIC,
 9 :==DHIC
1540 REPRN
1550 RE T3R0 REDHOP PHR1 ANE DPPF1  $REGISTER TO (HL)NL P+$=PP
15:eJGEOPOP EN ORN09,
150 BJRN
1600 REMNL CO)REDHOP PHR1"1HE= 0$REGISTEMU $"P
1620=PP
1630F OPD$="B" THEOP"CD
C OL 0 JEOO3F2HENL6N3n,
1650 IF D$="D" THSGEO=D02OLO:eJGESSW" THEOP"C ,R OL f =+U" TD O DD 