10 GOTO 11A2' n
SjuDhn0GOTO 101'   eREM COMPUTERS DIEOeo
 ODIG HEBB0
23 REM MOETEN OP REGE 20 HO eje ST. Dh
Sja$rgrrDij 
ieD5 GO  1010
100 P .cH0'eU
6O riRETURN
101 REM 100:VEEG HETls> 
at"eL ON
102 REM     OP APPLE5afa kD
E8 REM     OP TRS    : Ll#04 REM     OP CBM/PoO5   .c"e'e
G47)
 5 REM     OP .....  : .....
E$leeA=500:GOTOn+
E
EgneeTO 2500
1020 REA&AeU0  0Ae90"**** an
jeD
1040 B s1
1050<
 Urtd
A.aheUBTjU0
1060 AK0
1070 AKAK+1
1080 IF BK+AK>LEN(RE)THEN 1100
E$= Ibv YU
E$,BK+AK,1)<>"THEN 1070
1100 WO$=MID(RE$,BK,AK)
11110 BK=BK+LEN(WO$)+1
EW0 IF PL+LEti  an 3 n
LHEN GOSUB 121LGO<Pe$="t
>A  W90""GaUB 1210:GOTO 1be
E,ft0 WO$<>"#"THEN 1170
1150 GOSUB  nk:IF ARzEe TH0 Au0
ElA0 GOTO 1 s
1170 PRINT WO$;
EIae P=t
DEN(WO$)+1
1190 IF PL<
tdg> PRncrirg D
WgneeTlnr
1Ae PRIgD
W2AR=All D
W30 Ibe
RB Bha
V  1 D
W40 PRIgD
W50 P .crg 0HlOG 'n TOETS e<retEzEo D
W60 INPUT SP$
120 u00
W80 GOSUB 10L
ss PL=0
Gs0AerERN
1310 :
2500 GOSUB  0h3
E
S .coai 
I0araBiA2nOG32bj w computer"
2520 P .co""BtregeEbirg 2530.URL
eaae PRINiPRIN' 3i sm3a0T""  el TOls kunnen bij Uw comeouAol&8iA0 PRINT"opOt scherm ? ";
250 n2$eoRB l&Rae GOA) 100
25s P=iAR0
2600 GO  1020
2610 :
30000r "Hallo HOBB&Aru  VRIE>A  ! & &"8E2p0"& Hier is de uitleg ovede nieuweLhnVr ontIl
==== BAS"eeDE-2 ==== & &"
3030 DAD 
o tA
4Y2kz-n
0tA1rd
0Torn0de uit te"
3040 DATA"zendeHOBBYSCOOH z 
ramma's wordt gebruikt."
3050r "& & Wg AiOko-3)n & Dabet ent, dat"
3060 DATA" trEHOO-T0meer not A2jadi" IO0"
3070 DATA"door HO U
SCOOPT(faid
tz 
ramma moo 3080r "aanpaeevoordat h
""BkEm"
Router zondeVSA= 0ont:Bi'dTd t. & & Hoe kan dat? # 
tvoor eld:"8 0r "& & De opatiht 'CLEARSCREEN
o0 in elk D8110 DAD iomp er ander,
Bzz &iAaVSAWDATbn BASICODE-2 voDHUB
E "
3130r "uifrU0n programma dat op een z er ogenble"
3140 DATA"h
0ch hwil scho mU epiaoE A2"
sk de"
















































 0ontAe0tructie    GOSB100    bevatten meAls U dan"
Aak DATA"op regelns e
0uz eoTgTu z
San die"8be DATA"ttA$eEmSchine hescheT
mT r
O , dan"



















































































































 DATA"iE5s het p  " m ttAHmileaGonI3 TriA45DOpaAG s DATA"t
elost. &"
322p0ont
o tAja2A0het uitgezonden BASIODE-2L
Ae DATA"programmgaaladen, moBd&kl r  deL2
  DATA"benot  "8ae DATA"subroutin:r aE
s
&Ar $UN' k""ltten."8rs DATA"eZo zijnA
0Msrs0ubroutines, die"
32e DATA"elk een be4d  nuttigeaak kunnen verricBNn" a6DATsn wel allerlei ta n AE-n-eMsrs
angbare"
3270 DAD iomp ers ve chillende tmmUE"am0 nodig"
3280 DAD 2 bbaDmpa 0s DATA"2 rn1ibitAOl 5R"
330DATEtnE0 curbeoOen bepaalde p
e, &"
3310r "& Kijk of er een toe  is ingea t, tD8320 DATA"& WaTobT"2 r ebTv
is in
D3
et, &L1A
"so& PEo
oHD1 volgens een opgegeveaantal"
3340 D"D iifA2:bieen/of na de kmRuRtaM50 DATA"& et":biLD en":biLD"
3360 D"D lplS7DAT,rg0iroutiner
A1n zeezoTe5no
 uhI0o n"
3380r "& DeA:":ngen na een jaauit nAe
en in"
339DAToas
"eeD
bgg-p0natuurlijk aanL6
o0onztgrA1 lag."
3410 D"D 
oeA1 l alle ed0rT(faid
tz 
ramma's"
rTN DATA"zou
tm-4T0u  subroutin2aidTD D843DATsniab"2rAOm iOen op Uw t&"BieeG3,tD8440 DAD E rken. & M  er danogverrtA1ft zijn"
3zes D"Dd Ae
en als bijvoorbeeld: &dr2
rn o:gen,"
3460 DATA"& -Klro0ndBE=ten, & -KA"olSzr  D"D 
3eer
A
ejes, & Hireso oren"VSzeaAo0ontfAletmeerrE-37miiTA$" a6 DATA1 De belangrijk e redenen om hi3o tADtD852p0on"Hr
"eeDE-2 geen voorr ET2Bi0ffen zijn:"
3510 DATA"& -1- Hekomt te weiniribiA"ta" TN DATA"& -2- Er rDaR0t
bO  iP
T"maB rmplS" aA2p0onE AgT:2nOG3,
3540 D"D I"E"OTLiTd Ae
 nodig blijkt zal0"
355DATonE0tie van HOBBYSCOOP dat zeker bernd1,tD850 0ontfavd  nu vastgelegde TeAg0ubro i
2n13,tD8570 DATA"  echieb+o0t ni7j0e tijd vo3ct."
3580 DATA"meNatuurlijk wzBdH A cies wetenn
EolS" aes DATA"subrouting""klke D4Le riOsta6 ak0 DATA"& D
r0O"i &ie ko  zo diEi$tplS"A10 DATA"AllerrstT Or dit: & Vo0algT""OoolS"
 r "waarvoor e
 SICODEsrtrAorogramma be aiVS"A30 DAD3 CIn3  proatmeopsuw worden uitgezonden."84DAT
ODe suw uit te zekn versie zvA0dan teve "850 DATA"de benodigde subroutines UI> laar leveren."
3660 DATA"& Het is  
B
smrv0r t nodig dat U deze"
3670 DATA"nieuweO2op i
2atIhH3LB,2sdenken."
3680 DATA"& (Het mag natuurlU
0l

l an0sr "Hespreekt v"" lf, dat U bi het makb 6p D8700 DATA"p 

mRlm0 deze nieuw0tandaard d, oBo D8710r "passen. & Zonder dat zoan
eprogrammop geen"
3720 DAD0n le Akre tihine kunnen weeen tD8730 DATA"& & De nieE  standaard zal nog niet meteo 3740 DATA"U roTobtr0e5ee ti:On0 suwe"
3750r "lees- eschrijfprogramma
2a1n uitge"1d
6"VSzoU  DAD f)7rBAIOmaaniR wee duren, de vaneplSzr  D"DD U wegr1kmoDbtCuT:2oe0r zijn."
3780 DATA"& &  ta ete 
R
&DzA tUg aan
eondigd"
379DATsn vanaf dat ogenblii Utal2I kreL6
o0on" T74GnrOn pla=o fgT:20r uwe BASICOD
  D8810 DATA"p"T T"
lDD D8820 DAD 7v0 zBtz"T T"
IeeBtA c
$"VS aM0 D"D I"AkdaartoT:2
Ode0el van dit"
eaz DATAtz 
ramma en run haDRAolS" lr on&&&&"
50000 REM         HO U
SCOOPi Ae RE     UITEG B40eDE-2
 s20 REM       (EOaTl
UL)
503REM      8a0VAN COPYRIGHL 40A1ao
G SM
O U
"eeOP
50  REM     UITLE BASICODE-2
5020 REM (EEaTE
UL)
e30 Rus&
eo  zo diEi$tplS"A10 DATA"AllerrstT Or dit: & Vo0algT""OoolS"
 r "waarvoor e
 SICODEsrtrAorogramma be aiVS"A30 DAD3 CIn3  proatmeops