5 OPEN"O",#1,"SFAOBDES.0"
10 FOR X=0 TO 29:READ OB$:WRITE#1,X,OB$:NEXT
20 FOR X=0 TO 19:READ OB$:WRITE#1,X,OB$:NEXT
30 FOR X=0 TO 28:READ OP:WRITE#1,OP:NEXT X:WRITE#1,0:CLOSE#1:END
100 DATA A large diamond is lying here.,There's an emerald eye here.,A platinum chain is lying here.,There is a golden apple here.,A sting of pearls is lying here.,There is a bottle of rare spices lying here
110 DATA There is a jewel encrusted dagger in here.,A priceless figurine is sitting on some hay.,There is an old oil lamp here.,An old brass key is sitting here.,There is a worthless looking ring here.,An old black rod is sitting here
120 DATA There's an ancient looking staff lying here.,There's a package of incense lying here.,There is a bale of hay here.,A pack of Kraft Cheese is lying here.,There is a noisy little mouse here.,There's a box of matches here.
130 DATA There's an empty bottle here.,There's a brownish bottle of water here.,An emerald eye sits on top of the idol.,There is a knife wielding gnome in the same room as you.,There are rare spices lying on the ground.
140 DATA An angry wizard wearing a platinum chain is in the same room.,A giant snake is guarding a golden apple.,There is a large crystal ball on the ground.,A priceless figurine stands on top of the table.
145 DATA The window is open.,The window is closed.,There is a panel open to the North.
150 DATA Large diamond,Emerald eye,Platinum chain,Golden apple,String of pearls,Bottle of spices,Jeweled dagger,Priceless figurine,Oil lamp,Brass key,Ring,Black rod,Wooden staff,Incense,Hay,Kraft Cheese,Noisy mouse
160 DATA Matches,Empty bottle,Bottle of water
170 DATA 38,0,0,0,0,0,15,0,2,2,49,21,42,58,47,57,69,6,24,0,52,0,28,61,54,32,63,65,0
