	REM FINDCTL.BAS
	B9$="0123456789ABCDEF"
	A=1:PRINT TAB(20);"CLUSTER EXTENTS"
	PRINT "Cluster";TAB(10);"Min  Hx Tr Sc";TAB(40);"Max  Hx Tr Sc"

60 	CL=68+(8*(A-2)):MI=CL:MA=CL+7
	PRINT USING "### ";A;
        X7=A:GOSUB 100:PRINT P1$;
	D1=(MI+1)/26:E1=(MA+1)/26:T1=INT(D1):T2=(D1-T1)*26
	T3=INT(E1):T4=(E1-T3)*26:T2=INT(T2+.2):T4=INT(T4+.2)
	PRINT TAB(10);USING "#### ";MI;
        X7=M1:GOSUB 100:PRINT P1$;
	PRINT USING " ## ##";T1,T2;:PRINT TAB(40);USING "#### ";MA;
        X7=MA:GOSUB 100
	PRINT P1$;:PRINT USING " ## ##";T3,T4:A=A+1
	IF A>254 THEN STOP
	GOTO 60

100     REM ** DECIMAL TO BASE 16 CONVERT **
	P1$=MID$(B9$,(INT(X7/16) AND 15)+1,1)+MID$(B9$,(X7 AND 15)+1,1)
	RETURN

