1 PRINTa0:ew):GOSUB 950:0TF2E"$T$0:2 1B:REM * nUP ROUT
2Xc y:LEFRaH0  4000
1POSUB 9100:TFPG650n $P898HRPOKE E32:2 1$S185 PRINCHR$(26)
50 0
2to11 AN; "00 1800
95 REM                                                  **DRkING RO"a1 b28100 X$=2; .o
110 IF X$="4" TH01$0T 
$0
120F XL6THEN GOTO 1200
t 0U 
1*  THEGOTO700
135 IF
RL5" THEN
00
137 IF X$="0" THEPRINT CHR$(20a
140 IF  ;c  ENEN GOTO 1600
150   X$="" THE108160   ASC(XI227 THENt $T000 
"X=X-1:PRINFNP
"Bl);FN t)3;:GOSUB 9010:00 100
1200 X=X+"PRINT FNP$(X,Y)"eP
5IIPOHo11 E0:G O 1
1400 Y
-1:)tT FNP$(EY);FNG$(I);POSUB$10:GOTO 100
w Y=CPt30HT FNP$(EY);FNG$(I);POSUB$10:GOTO 100
700 PRINT FNP$(2,225 CORACTER:     "; PXO1
$=2; .o:I
8RT NEN
10
1820 I=;C(Y$t30HFNP
28gIFN t)3;" ";
1820U 0000000000000000000000000000000000000000000000000007 THENt $T PX $
18T1)0HT FFte=gI" ";
0u$ 0 XOSITION: ,Z$
1835RINT FNP$(42gI" ";
0u$ 0 YOSITION: ,Q$ P=1 X=VAL(Z$):Y=VAL(QIRIF ;C(Z$)=27 OR ASC(Q$g T H GOTO  TP?8188 PRI 0")nteB=2);"?R
1838 PRINT0IFt81EY); P5
1POTO 0
18"REE=+**SAVE DRAWING**
186:1M
"$0 PRINT FNP$(5gI:LINE INPUT "FYe 
me (CAPS) to save under: ";FIL$
8100 )tT FNP$( h2);"kXI0XTN U
00 O",1,FIL$+".BAS"
81900QE +1
EAT2I220
8205 IN=10,9T1)0HT #1,"10 PRINT CHR$(26)"
8212 FOR J=49E!O 521P! STEP 1EI0,s7 FOR=1 TO "0,s90Nn" I p50,s
 Z=PEEK(I+J)
8220 OUTE1
8238 IF Z=1600lR*EN01$0T09I)0
8240 X$=":0(Z)
825O$=STR$(I+J)
Eu5 LJFR
++II0,p0 K$=SFt=I0$F2I ;#ID$(K$,2,TH(K$RS04URLPOE":SL,RN ;c:NR0="OUT 0,1": $="OUT 0,65"
.T$=K$+" "+Q$+O:UI;0+S$"o+O$+R$
83 I0
$ 0"=c01
009Rm
83 PHT #1,T$09R K=K+
NR1M INC2BENT L

02NBER
833(1XT I
0iG NE"1K
835 PRI 1MP $0 CHAIN ";CHR
));"E-+ETCH2RHR$(34);",50"09I8 IF NOT FX X HEN END
8350 CN1IE:PRINT:PRI 0 FX ,RLOSED SUCCE;FULLY"
83cPRINT0IFteB=aP                                     ";
8360 GOTO 50 
9010 J=(100*Y)+X
9020 POKE 56500!+J,I11RT0FnURN
9100 DEF FNP$(EY)=C:0(A=I Ic+tR$(32+Y)+CHR$(32+0a
915d"0"egN81EYp
1S1 
*Y)+49E!;111AT2t U R eP$(I)RHR$(27)+CHR$(103)+C:0(=I:HR
ZN2I:HR
8II111u0 WIDTH 255
9300 
 t0S11PX F#                                           **OPENING SCREEN**
9410 REM
9500 GOSo11 AN;1S8XTOR Y=21 "1,01-1:PHT FNP$(5,0SFNG$(118);:NEXTII11P
$ FOR XcTO 7030HT FFt81E2);FN tE18);:N R a
970TOR
































"1s)0HT FNP$(70a);FUR

4);:2 1
98 FOR X=70 TO EITXK1:PRI 0")nt81E215"eP$(1185t1 F X

(00 FOR Y=21O 5 STEP -1:PRINT0IFtE2a);FUR

4);:2 1
9950 FOR X=12O 6:PRR NP$ Pt
Pu

4)t1 *F X
9960N a=6 TO 1t30HFNP
s7,Y);FN tE18);:N RSI1
80 FT
1263 TO 18 STEP -1:PRINFNP
"Be
);15$s
);1 *F S11
Y)X$"Y="00T0rSTEP -e0)  FNP$(18,Y)"eP

4)t1 *F Y
9980 FT
1219 TO 58:PRI 0")nt81E8);FNG$(118);:NEXT X1185 FOR
. T Re0)tT0IFt;;1 3;FN tE18);:N RSI1
(0 FT
1258 TO X;TE-1:PHT FNP$(X,15);FNG$(118);:NE"1 II11
7s"i)tT FNP$(27,);"Electro3r1Ike"hin PH RY
999 PHT FNP$(2 s)5"eP$(1155  1
4 Eo1m. vanRw 0 ; 
 RETURN
10500 REM                                          **INS5(t IO=Xc
1051:1M
(T$ PRINCHR$(26):PRINTAB(1II"InstGctions2$r Elec 1 a5  Sket= Pad"
11010 PRINT TAB(15);"***************************************"
120 PRINI I0O i)tT TAB30S"Basically, this p$gram lets you draw picture1 a           b
 een using"
040RINT TAB();"gr6hic charaNers:"
11045RINT
1105i)tTAB(1
P  
";$TFTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT6 TO 122:PRI 0"eP$(E);:N R
; 
3P5 )tT:PRINT 
(T1)0HTAB(10);"aU t1E 0222222222222222222222222222222222222222222222222222222222222222222222222lar char"terR"
165 )tT
11070 PRINT TAB(10)            ":$TFTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT3 TO :e0)tT CHR$1);1 *F ; 
382RINT
11075 PRINT TAB(10);"4P:$TFTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT1 TO 95:PRINTa0:FiS:NEXT E:TFT123O 126:PRINTa0:FiS:NEXT E
180 PRINT:PRINI I1 "PRI  E0(10);"After the1E2elp s"N6U goe0he
y, ou'll go b"k to the menu"
11095 PRINTAB(1
P which will allow you  "raw, save, or retriwITdrawing c
I3811100 PRINT TAB(10) disk storh1  To drsE se Ty gggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggG0er 
se letters on"
11111i)tTAB(1
P the0eyboaU, whX= NLome graphics12aracters F the screeE"
(
i PRINT TAB(10) or any of the other c
racters, which stay t1E1Yme as they alwas"
11130 )tT TA1 30S"were.  "
11135 PRINT FNP$(22,2aP HIT ANY EY "
RT) INUE.......";
137 AKS .o:IF A$=  ENEN 11137
11138 PRINTa0:ew)
11139RINT:PRINT
(280 )tT TA1 30S"        What thi131Yns is 2at you can't use the lower0G2 S 
sP0 PRINT TAB(10) letters to draw with  SelecITch 0h R
L I
00e2e prompt in the "
160 PRR OB(10);"lower8H1 8 1c 
I0e2e X"N6.tee the,4,6, and 8 Nb6$e F1I 
s8i)tTAB(1
P move the letter around.  0 change12aracters, hit the 5 key."
11180 PRINTAB(10);"Hie)Fg theH K+2i Nb$Y00e2e CHARA$1R promptYk1E,$u bacT1I 
s
5RINT TAB();"to the main menu.  HNting the <ESC> ko11111111111111111111111111111111111mNSIDEHE I P9rPHT TAB();"DRAWPcwill (non-deNructi6.M0R11Y6$e2O2Nhe3Fg.  >s"
11190RINT TAB();"takes about a minute2$r most drawiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiih"
192RINT TAB();"      Now, afte11Yectin a cha
cteE the p$gram asks for I 21
FPRINTAB(10);"X-POSITION and Y5OSIi0TEvet fYl innnnnnnnnnnnnn mN*
"
194 PRINT TAB(10);"?h3=at numbers, you ask?  Hit N to see what mGEY 1Is(5 PRR0t30HT TAB(25);"Hit N......"; 
1
"
ORKtKEY$:IF00 "HEN 1119S 
s(8 IF00 NOR A$="n" THEN GOSUB 1 $ ELSE
w
E
s(9 GOSo 20OT:e0)tT FFte)))))))))))))))))))))))))))))))))))))))))))))))))))))) H 100PnKEYO C0"a1H ZZZZZZ";
1120O$=INKEY$:IF00 "HEN 11200
1O
1)0HCHR$(26)
112"i)tN30$t30HT:PRI0t30HT TA1 30S"In summary:"
11210 PRR0t30HT TAB(10)    5  =anges12aracters OIP $e)ie and allows you to" 
mRINT TAB();"       jump the curso0e "aB plac
IT t1E1*reen7Wn:"
(g= PRINT30HT TAB(2
P X POSITI1R"
224 PRINT TAB(20);"Y POS 5T(: 
11230 PRINT:PRI  E0(10);" <ESC>     h316E,$u b"k to the menu f$m CORACTER:"
11235RINT TAB();"         or l66$e2e X"N6 you are2 2)3F on"
240 PRINN30$t30HT TAB(10); "NNhing to it.  2Pst tB it out. Hie)Fg any key takes"
250 PRINT TAB(10);"ou bac R Rs twU2T0GE :P* haX1$e "read the1rS 
h52 PRINTAB(1
P instGctions"
11255RINT FNP$(2122);"HIT e
 KEY TO CONTIN ZZZZZ";
112T
O;NKEYtP"T;c" THEN 1w811265RINT CHR$v) 
80 GOTO  T; 
i00 TF
(T00T "$1P 10:)tT FNP$(E1) 
EXT X
12100 FOR Y=1 TO 22:PRINFNP
2 .3;Y;:NE"1
=00 RETUII 20OT"PRR NP$3E175 For Fstan1C  XOSITION 40  and  Y POSIi0Tr16ut0e2e Grsor" 2I$ PRR NP$0.

wN
here:;FNG

4); 20( :1TURN
w$ REM &**R02t C SUBROUT
2Xc 210:1M
40 GOSUB 1 (817050 PRR 
0:0(26)
4
"GOSUB 17190
1708i)tTa0:ew)
17170t $T 
$
121 "PRI 0")ntE0,0S"=)1Iu16XNure to show: ";
17200 LI
0HT"0"=c; 2
2 PHT FNP$(10,85 Loading emory, please02Y- a moment......"
17220 CHAIN FIL$
17230 RETUII 2
240mnEN 25; 2
2"DEF FNR
"Bl)=CHR
ZN2I Ic+C:0(xY):HR$0=+X; 2
2T2t  FNG
O)=CHR$N2INR$3))+CHR
O;:HR
ZN2I:HR
81)
17270 RETt0S 2
2"RETt0S 2
900 REE=%**M1Hc*
1$0 PRINT C:0(1):0
2to 2

0:GOSUB 200000
 T1)0HT FNR
m,5);"aectrFic Sketch Pad Men"
18020 PRI 0")ntE5,85 1. 8 eate new drawiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii
7030 PRI 0")ntE5,9);"2.  Display and work F an od( I2e3h 1I PX
ari)tT FNP$(15,1
P 3.  Instructions" P4i)tT0IFtE5,3;"B.  ExN  "#
3X 1I PXI$ PRINT0IFtE5,8aP C.  Exit t1RP/M"
18060 PRINT FNP$(15,185 Please inicate6.sctionTRY
18""A$=INKEY$:  A$="" THE18070
18080 IF A$="1THEN PRINT CHR$(26):GOTO 5
 I 0U 
ORL2" THEN G O 1T$
7100 IF A$="B"0"ALb" THEN PRINCHR$(26):END
7205"10T"C" OR A$="c" THENRINT CHR$v)IYSTB
18300 IF00 3" THEN GOTO 11000 ELSE 18060
1800 GOTO  T; mmmmm GOSU11 (820O i)  CHR$(20a
20t R0TF
127 TO N20040 Y=2:C=160POSUBNP/(820050EXT X
20060 FOR Y=2 TO 1I m0T
1270:C=160POSUBNP/(820080EXT Y
20090 FOR X=70 "
"

 EP -1
20100 Yi:C=160:GOSUB 300000 m110 NEXT X
A
i FOR Y=19 TOTSTEP -820130 X
:C=
:aHd102
  "NEXT Y
20$ RETUII10).P$  I p510 A Ue;FNV(X,Y),C
30020 O" 9S10OI0O :1Tt0S1ZS m130 27:C=160:GOSo10)h
20X 0
2 1
20150 
 t0S10)h O" p5
310OKE FNV(X,Y K1I1rR:::::::::::::::::::::::::::::::::::