5 '     -------------->> ENT)B' = B s)s17/Ju 1s<)"o
VG)=o96ft
 on S $ware ToU
"doM, Australia lR8lo-997-183o
12 '
5.-o: En2A gme-loggin"RBT tln1B)esi 
rfd2.2,     (r cRLM$from Hoard Mou02BE  or  "
al t 5=
	
  0g
R025k15 '    : Bas 1p Ce,0t  to13Pem lpBpc0nso8RBBS or     :
1
-o:	1BL De: ftae Ratoff, and extensiu 
Y 7ised/    :
17 '    : expanded by 2dFoler to become RBBS22.  
 0 '    :-----------------------------------------------------------------------------------------------------(r  or$$Byhe Foler ver0f38RBBS22, was spliinto 2 mod- :
20 '    : uleS"u uA1B)ecnd 	NIRBBS,2A B23 on.       :
21 '  t O:A=E2RLM$Both were revised and givdRBB8aompatiblver-  :,6 '    : s2dnos. Rr3/81 by Tiu 	aholas, to i                                                                                                                   orate:
24LM$BT
lr
FcD16iis ver0fd24 of RBBS.              (,:G-0"o6
26I AF1  test for "*" R
pd1r
RS r 
	D11Gn1B)
1s 
d,vI if C 1A =hle finaiC  Ihn beginningf calletpt,S.IE
 =Qit wi,not an2NH
M694uGs a2
98a8log
29 '	 him off imme	 NsT. (For 0f e who persist R2)g-
30 '	 ging in withTa0
0E0ftcA =4Y 'U
 BUG eyE). Also
31 '	 aF1  "83, I0H6; i)m:Bbo foi
Nwi :s dSo
32I Sysop can N		2 gs foie
 t INr "cAame.
 GI DeHim Nich"
a
1'L  0/81
34 '	-------------------------------------------------------
35I C  
ged o $2CUmPb
Pnsto q2hon2T:cI	2E
(
. anything?STe#Tt i FPnsether than "Y" or+k37 'or "N""n" will r    Ut ie que
0fW33"
 noisy lint
,  '	 condit23  iwB1	e(o Mi f T defN z06	N"/"E & 69 '	 Add  suggestion by FVonson to mou4cl
ing of
40I "BULLEmS	0H6 06 Ou,0gme-ttT
 e 
Nther 0an
41 'in procedures.  by Tim 	r1 	
Pnr$ar/81.
42I------------------------------------------------------- 
4R8More modifications yB=I30$ar/81): ch.E'"L2or-msgs
44 '                                                                                                     e tr6 ferred 0om MINIRBBS, lines 8109dG ) new
45 '  ve
rfdNGS lS
  AND sysY
ow drops 	0ect tohsk
3 '  witfoIhncrem5 "
g COUN 
.Hs8' --------------------------------------------------------- 
   '  Modifications by Bill Bolton $
SO61: OI : 1U8dGodboutH4s'  Tstem $
anSRgd Pck roE	
 , DATAT6 bWG2N8tt
L=oc=eformenus a8BULLEm6aho  $4o( cR0ee RN show
51 '  date of latest udate to BULLETIN,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,e "structured" - :e.-, ier reading/maintenance (ut now MUST use MBASIC editor)
5R8MAGIt =F1  -p$o1	

9N-Bp
t

9N-B95>)nger ecbru E54 '  more secure t'uTE e. SUMnRY ieck for Do4  f3 l2
55 '  '  dN7)us ot21T"$0nahang . Vers2dto 2.7A (for Aus$0s	 1St
= G-LN8
57 '  Twit loel1  ianNF
 Twits areglZ
F# NI$LASTCA'HE1G
58 '    =a	  G Then l"  N8out through EXITRBBS for consistC9s 11E
59 '  that EXITRBBS a8RBBSUTIL have been sim Xp=Nv
Ye  
lr
(nh=oc ke utNf this   D 0
$in LASTC Ol
 ST$ reset iTe(SMhingI


iVS" 
4ons
"
gme logo 0SY0edundant Rl1"
o0
	
T
55555555555:r Mn 8(nY8If comma enteredSMween FEdand a0
0Ihs ianged to a eriod
63 '  to make lifeasier for Et oB'   d eT stateme	cdd  at
64 '  a
1O6 low for ianges to disk between calls without havR  k65 '  to col0
11E dVersio$o 2.7D, Bill R
0 (nAs'-----------------------------------------------------------------------n48'  5	npr/81 add
0f3 :Aoth6)WD 
l0 e,to1e"0Stn,  '	 thrueeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeedisct0a$sD1
I
4'M$k69 '  11/Apr81: Change "SYSOP" to an ier wordeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeedit8W v0 '     (see lines 600610)
71 '  02May/81: a8YN f6UtTas  R md CC$IN
72 ' 9May/81: a8routine for rea	
g special
 C7FTsIs (=SPE	AL) 
73 ' r/Ju 1odadd utting P$ (SP or.hnto LAi8
LR suser
74 ' ,8cla2r ae status can be pa
N8to MINIB'  (
tR1 E6oa81: change specr,user :
1Tg0
0f& v
-0WLAuL81: inlRmd0 6s 0nest's)utiFcl-3at
ting
77 ' ,8  f3 l2 (sU10 R m
S c
 =
RS, C 1A 8S

7EP91pdOlts  '  01/Sep/81: ad: fA KanL5 Kp( MImoB'=E94uGTE C82t"(  v9 ' 7Sep/81: 1-,re-call6?raight to CP/M
1
-r9/Se/PdCALL TI
X addeZ+oG7T rouE#44444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444444pil  with-cnd
ad'     linuW=
"$: r t)
o8pgm withCi calling an ASM
82 '     pgm above01LMeLFS  1 ing the M4f)ck; other  PckseGs'
 n probabl be	
:w
r
 bsM
SRE0eads)
84 '  TLSe/PdGivesvaial (o) useac 1GpBc =Au
85 '  10/Sep/81:	S41-2$$wit signout; POKE reset bits -1$MIe
3827/Se/PdAdd	
PE SeHszka's time interval so2f.
87 '  9/OO 1c)dA83rd user categor, N SH(hout direI0	( 'B5=s a2
ptS.-0O/Oct/81: 
d add 
$6(T' e3 	
t$esat 390 &  rrrrrrrrrrrrrr
89 '  .Sr0 1c="r70Eo8c
pBc =Au fo
 wl2  too.
90801/Jun/85elMrouslE sie ianges, see abov
 0  Bolton
91 '  15/J
/82: eI2)gout changed,,$cbove. Bn,Bo02& sY '  26/Mar/83:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::e de  
ding user n =
ahe(Ur=F.T90ft0 elased
93 '  MSg=ugTR
 NF
 Version 2.8 Bill B
02
94 ' 4/Apr/83: Added eOP   aess X	
	"hntDIREC0H6 F f)sing
5 '  of LAS8
LR wasoIT	
:=so8properly -p$o-RCr 2.8A. 0  Bolton
96 
































C
C41L83:B
 ed MAXTRYest4o that turkeys can't' :SARU
 e the
97 ' 2Yuriting pro0amshat just senNccas2(0,  0riage return a(4,  'FBev9  answea$o prompts (B	Ues)npsf1rHRN=-RC>1. Bill Bolton
99 '----------------------------------------------------------------------
100L8n"(EBr  5TB
 ed 13$c200000 to wriEaurrent calle$o status
1VS 
E#e)sterminaRhreOsT (bypassing e) so SYSOP can know whtrO2 ' aNn 	$4ysI6 d hNe
t	$2T have been 	2b
ien not runnR  k103 c hardcopy lU
 V2Ye 
$DN SSC32  r3"
g l+Pu wanto TAT or
1aRD5'sdPut a Rs 0=6 M P2SDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDyou dont need 	"p
dlCD (Vl63=BR
02d
105 '----------------------------------------------------------------------
106 ' 02/Jul/8500F1  Se$o
	

9N-B9cko NS 1fo
#sM 210000 :FtreGf 1 ded code to incorporaml9,ofhe month as"
1INe ts"

9N-BA
1aR=0CS t,
 0 . Use 	EFP .thnstead  
tFiDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDou do	T	FE  0 s' r0,time clo(9Edyour systeG  Ve6.1 Bill B
02(roO ''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
1111 ' 17/Jul/83: Addeddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddde to NN4
 er $0vey routine to counthe numer
)f Nf 2t2h3  skipped. If more than 2 are <o7$ed> the callehs
113 ' "7en a 2
U"E O
foS Fg co-oper
	e :8give$emporary TW
) c
0
e 0O1Te  e uhich gets then
icuWi TT+
 tem immedr
os & 0oBGf4"aall6uill	
 FE f bcdy been l"  N8into USERS buthe
11
f
b
RS re- counter is dect 
ted :8writte0e  t?o USER & 0omb areme
	
g the USE FSNrd cou
lC78 
s that thlast rrS:  CtroW t$s0e 
 =rH6 thsffectively ignored yhe whole ENTRBBS prog" 8
119 ' "$i                                                                                                                   d forhe next ne casl6ui,be writ 
ver thecta in
1C)e iegst re- unlCE"2
$srcumstances, effectiu 
Yt

"
g thtrf1 'ntry fo$he unwelcomcaller. The me
 u
 isplayed to the
oY ' unwelcome call6"cs
taC1  i$he GOO5,	cDNr eas customa8k123 '$ion. T$e=Tf
 
21, Se,H is)w done s$
0rIcfter the display
124 ' of NEWCOZs	
e 60) so th	$he s0
$of the Do4  f3 l6aan be
ont4 iR  N8to TW lT=s9i T before loggi m06KC$n =s 
d
P91pdOltFl
f  
d canSE
a'  9 ed (ie. iuckedff the system)2W trappingrf7 i)utC p
 Vea6.2 Bil:)lton
199 '----------------------------------------------------------------------
200 ' NOTE 	 TE er privit Te  Mchs rea0TR(CE"$SERST6 9	2bn
201 ' the fol2$"
g c  0ac 0cre inserted (with Ru3rOS:6"the first
202 4pace ofhe line:  * = se 0Otea+7V0cslp	0,Us:E8 - = 't 3gr
hdGf
21(e
  
d (spacC V0w
 :mE204 e(Dt9:"=0 thathe code fC1E"3alocks  1 trun withhis prog" =E20RD$r 6L =
Ns                                                                                                              ed  Usehmila2 	
etchf you can but separ
t$2(,r6FSf lecnt lines and call 	$i FT1n	
1B3eItE1.B8Sn1 u	tE2BAS, etc.
$S


















































































s(,r8 ' Howard)oker's suggested additions at 13030 were re-1 4 they
h  s' di:oIT1SNcnd even when correct  were no better thR$hee5
,e k(V2uhei $
ni Ee :F 0 BY dBill Bolton
211 '''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
$VG
310	0KE = 3h= s'<-- iange "JMP$o "CALL$o prevent Ctl-C
BLC'A LISF0 s)TR  o----------------------------------------------------qaL F4F 0sion NGS lSt
Y0	DEFINT S
0
Y5	MT
MPORT=&H5C:

	CO ttnZRT 3hE
	nXTRY = k330	DIM A$(17),M($l 2),H(6),HTlo,HDlo,TTt5),DOY(5(
nnL
I,ha1gN------ In casdisk was changed betwees  f3 
k3MI  && dMIo 
OR GOTO50000
35Ga(COTt ,T SO
35ItAGIC$=" 0n 		'The magiT+
 op pasword
AhI'TtEX=&HEMW3"U"=led	0nOC$HTtE.CO(fe 6>  2
UU20 f t n' O
4(
AnLRALL ItEX      cS.
s,2oI+)u'll	
 FEi Fm0CG13r2y 140000- & 440 oG
370	 '	
372	GOSUB 140000:
  'Nc
50 U r0    'Set time counters A  pRl1
	1St7E4nIBR2nIBN(AsnmnR2nmnE
	AO  DR):

	HT. AEN(A	AO)1nO)))))))))))))))))))))))))))))))))))))))))A	HTlo=Hlo
4lF	t=74:

	0R I=1 T
AtA )OKE M,AIOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOgO0
$+1:t Aar$O"
 Fm
"$$ime in lo=	RL (
4FH0E380-ranon e 0
0f3 ....
c(1mE385	PRIN'Tt )RfeiC>f ioi
	(n LE(
TH$  -5620 o e1r1$ f l6  0ity test
MtO7mb )1tA	nLLS=L
S+1:

	MNU o50 O9i=U :B  e$=E43Io16	I"6F

o"+CHR$(&HD7)"DS. "+CHRO 34
0'TtIfS
OF(1) T
N
 E.L(o"Lgsswo8file
4MI -= o6lo
2)2$  otpENDor totG
e the fil
 
g.: BANoA,APP
,COW
450	CLOSE #1
460	BEL=-1:

	XPR=0       ' (61
	 feNn,38noexert(Hsl$  'NcL5if0
4M 8
V$=""
510	OPEN "ES6F

:LAi8
LR":
I oPUT #1,Y$,M,F$:

	 Moe n
5$  'N:3s050:t                                                                                                    
50dr2222' 0int WE#P73 lt
D	BK r:

	A$F0m-'tSA
(	023Le 
4ystem is 81 y for input).":

	0SUB3020:

	GO :/5if0:

	XXlN(A	COUNd= 0:

	C 0f =
5dmN	hi
tA	O$ =i
tm9M = "'Tt #Sif7 ttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt2 + 1:

	IF$8027E
XTR
4wwE
		GuC:UR
bE55 #SiN=
ne-r2 + 1:

	Y#SDo=
r

X3e99$u( gDt/d 080
F$ ISF0iat is
2tFIRST n =
i
tA	GOSUB 13h1tA =
r1tA	GOSUB 13FN(A	C = 0:

	N$='m(A0Yo$ = "" THEN

		GuC'dbEer	Yo$<"A" OR$u'e)=1 THEN t 1L (
8=/
e-r2edr
U$ - u*l=ifed 1TtIf ttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt1 = MAXTRY THETt gRfe1rxd 0
o.LTo	SF0   " T
  your LASTgme ?'Tt  'Nc
50d r:

	C 01tA	GO :/5,
h1tA	e66666666666666666666666666666666666666666AN	S='m(A	IF O$ = "" THETt gRfe1
oUSt9IfS0 o
" OR LENNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN1 )D9$ulTt O 0
lTRR 595 '
598	IF N$<>M 'G
4wwlTm 0O 
600	IFM=MAGIt oD O$<>P1$ THEN t '2e1
D 5
 r5	IF N$tAGICToR4Oe)1$ THEN
		GOSUB 2)$$5I	IF eOP 0D9$uE
																																																																								OTO 730

		EL 9(O$$ '2e1
Dn
610	IF INSTR(N$,  e,to-16uwlTt)RIN'Tt mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2eiT Nn
now you're not the SYSOPOo$$	:

		PRINT:
 gR$V s(nios'
 eE
$="Che(T
'"wse0H6 l


































:

	GO :/5if0:

	V=0:tIouFG Ll 
:U"CHR$(ylo+"ERS. "+CHRO 34
0232:tf$I3
eSd1H RZ$s Aeo M,6 AS DT$Tt  '+do6L

	NU=VAL(RZ$)
625	FIELD o  ePe
 dt
6U i 3o$ + "
y"o
630	FOR I 
6oU+1Tt gR H#1,ITt mIv/-h)mmmmmmmmmmm2oT$):

		IFE  > 0 THEN 

				LE
TH = LEN(NT$):

				IFIfuX&&&&&&&&&&&2+tum s4S:1e6" THEN

																																										0hOMesi d(o
S:::::::::::::::::::::::::::::::::::::::::A					GOSUB 15990:tO2S1SsN6LGtIoCLOSE:
O2Smtoc
50d r:

					X&)(A																																																																																																																					Rfe1sl
64 ot
e	go' If reco
ized, caller as"

p1  to CALLER-loggR E0ouE>649	' But a calleAot inhe USERT6   N
aC,$"( oIS1D$0ther..............
650	V=(A	A1$=" "2bG7 NS P
LTown AND State) at+)u cal	
g from  	Tt  'Nc
50drN(A	 )1tA	GOSUB 13260:

	C=0:

	ST$=B$:

	IF STe	" wwlTt O3.ltnno/
ZINTER = INSTR(ST$,","):
If2)OINTER wE
	IOHOmM,POINTER,C 3
"
 
	A$=4onnEyyyyyyyyyyy+Iy
+I0)m y0GtARRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50drStnA"A1$IEacny of this misspelo8?":

	G   :/5if0:

	C=1:

	GO :/5,
h1tA	 t 

L	f0
FT$(B$,1) = "Y" THE9	GOT:T
ltnA4	fS MesiOO'ES:14o> "N" THEN t  s5
60	PRINT:

	A1$Es""checking is 59eRNne the ff t time you  f3  /
tA	GOSUB 1302tn, 0	LSET1r	r0  " t(0)Tt-b

 $="  y +	+t+" "+STy2P t(44):

	GOSUB 15990:

	NU=NU+1:

	PUT#1oU+1:

	S$=i#X








































A	GOSU01ho$$5IPUT#1P(A	C0SE
690	MF$F	i
tA		L$ = "NE1e1$":

	0SUB80000:

	'	NT:

	GOSUB 350 ogRoa8made to rea$he NEWCOMer file
695	'	NT
700	0SUB4200     '  Now eveTbody ge  logN8to CA Mn
705	A$="Logging+t+" "+O$" to diss'M$	:

	N=1:

	G   :/5if0:

	OPEN 3ES6Fo)  Ey8h#Z 3 o+0 
 
 yi#ZTA0)30:

		ELD#1,60 AS RR$:

	GET#L=E71 '
=VAL(RR$)+1:

	S$=STR$(RE):
 ' 1e30:

	GOSU01ho$$5IPUT#1P(A	RE=RE+1
715	S$=E+Ii+	o
+Ii+e
r
+I+ n	GOSU01ho$$5IPUT#1'
:

	 Moe CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC7$1-
aall2  (who are no"twits")))))))))))))))))))))))))))))))))s$
0rI$o CPM
723	IuM=Y$ AND O$=ZToR4 r	so> "*" AND XX520 THEN t 'Nc
: r20:t )0ecNs                                                                                                              e back.  	
ce you Ee 
9M
C1  off, go stpTz06/o/M"Tt gRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50dr20Tt OhIS=hI+
	 Ren 0 ":

		GO :3FP2S1tA		GOTO  Ti (,TiR (s
LR8Ul6
avilege level0TR(6
b
 '= ( Me (hO1T addedo nSTCAdGGGG
726	f00e	aE4wwE
		t="TW(sl v	IFf00e	+" THEN t r0er- k72IOf=" " wlTt OhOe	NW(sl sh	fS$F$="-" THEN t r0e8/n
73Io16	O"6F

"	+CHR$(&HC1)+"STCALR. "+CHR$(&HA0):
 )RINT #1,N$;",";O$a ei
	30GE2	;DZ$:

	CLOS otA	G   :3FP2S1tA0Yo$=MAGIC$ T
N 

  'Nc
50  ho$$5 a  '2l eHi (s=hRl1oe
X NI$he twits through exit roE	 pt
4l	Of00eeaE4w( mI oT:

		PRINT:
 mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2e,Nu have lo	cccess privilege$o thi4ystem":

		PRINT:
 m  Rm6	BYE(sD
M1B t

	GOSUB 1302(A	O
N "R"6F

8Ey8h#Z r 3RDT
 02e 
 8 d"+CHR$(&HA0),5:tf$I3
eS'HoVe k75 )RINT
760	A$="You are cnslC=2Bh
tA	
P(A	GOSU0dr20:

	Gn o6l8
LLS
2 l$ 1 3:rtRR$)+INC:t Oe8i1Gr:E
	=
T RRen$:

	GOSU0dr20:

	PA o6l8
 O.
790	 Moe 
tARRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50drStsFhR B  now the use	
o
a$chootTE	N
"21eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeanswe$he sur,H at 350 t(sFTF22(0m t34wwlTt gRfe  00tN(N  
  n	$h	Aew users have) cfg
ltsFTdE
1$="H FEfos 
sere$he user $0vey questions et?":t                                                                                                    
50dr2(A	C=1:

	G   :/5,
h n	C=0sFT  	IF LEFTO'ESdLeL
4wwlTt goc
56500000000000000
799	'
800f4"$eaetMARY file iAow checked -e2
	 c$o the cnslS  30	'
835	GOSU0dr20:

	A0e	W0ITE	r "Eaheck to,$hf you have=4sag  waiting ....":t                                                                                                    
50dr2(A	GOSUB 13h (68	L=te
s0	FT=1:

	MX=0:

	MZ=0:

	IU=0:	 '26gg first time f6
alting7 ing)
850N1
i
 	,1,"A:S"+CHR$(&HD5)"MMARY. "+CHR$(&HA0),30:

	RE)(A		ELD#1,28 AS RR$e
31Bp to
	GET#1,R'TtIfS
OF(1) T
N 

 
r
 l$  5:
 
L(RR$):

	(d)G0+1:

	tMZ,1)=G:

	IF G64wwlTt E/, 80	IFsCO THEN 

		IU=Ge

iIIF5299998 THE9	MZ=MZ-1Tt gRfe14Ah (4haR H#1,RE+3:
  'Nc
501nLO:

	IF INS)mr
N01r AT" oSTmr
S01= TH1sn		930
10	IF N$<>MAGIC$ T
N 

 
0 
9200|oSTR(S$,"Br g=0 THEN 

		950
930	IF
eHH1sn		L=yE931	IF FT THEN 

		A$="The fon2$""	S 9 ages for "+N$+" "O$+" are waiti E"
 MINIB' 13	:

		G   :/5if0:

		FebE940	A$=STR$(G):t P1tARRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50drN(A	0SUB3020
50	
T#1, +:
tA	M(MZ,2)=VAL(ROOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOA	MX=MX+M(MZ,2)+6:

	RE=RE+6:

	GO1e
30
9600r y
N 

 )RINT "N8thetcren'tAy messa2a0u+e "+N$+"":

		'	NT "NIs ie(ctImoB'  
yway fosUUUUUUUUUUUUUU 
g =4"  2
G":

		GOSU0dr20
965	 Moe n
2MN
mE202'  EveTone ce2aT70e,o N	i 81e$oooooooooooooooooooooooooooooooooto CP/M
204'
2GL.OSBHimio
veTone sees the DATA file befot	Sus
2046 '
h pT  The get menucccor	
g to thei4tatus.....
205'
:t(IfS$F$<>"+" T
N 

 lZ0
2052RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50drN(A	t="Ac seciawl28yoH	
 Fm
"$0llowing optionsm(A	G   :/5if0:

	GOSUB 13020
2053	t=" CON  Re8CONFIDENT
L msgs     MIN
o to MINIRBBS":

	GOSU0dr20
2054	A$Ie(
v Latest syst

 at02SPP	
 53 00aht to CP/M":t                                                                                                    
50dr2t,r5

$I	d
QL"	)i 
rG7oD$ely":

	GOSUB 13020:t - u*lSF:= "GOSUB 13020:t )0eciich ?":

	G   :/5if0:

	C=1:

	GO :/5,
h1tA	 t e30	'L
eeeeeeeeeee4wwlTEc(tMN)E"$e01
C
L file
2065	IF B$=tIN" T
N 

 Kp( o "MINIRBBS"  'to thmess  $	RBT1n
2070	'Le(
c	 THEN 

		22220tN)E"$:  CC$yIN file
2075	I
)0 /o	 wlTt mY30    'theHD 
 fsF hen CP/M
2076	IFM="OF	 wlTt m  4132E"  ig  it to log-o2 m ult,r78	COUNd= COUNT1 + 1:

	IF COUu*L)gh3e99$uE
		GuC:UR
bE2080	0TO 2056
2099	'
2100	f00e	
4wwlTmY/=' Note that new call2  don't N	c 26tk2110RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50drN(A	t="Now you can do one of thfoll$"
gm(A	G   :/5if0:

	GOSUB 13020
2120	A$="t
v Lat t+Et VsMa          C$  Go$raiit to01LM'Tt  'Nc
50d r
2125	A$="I o  Goo 2
U"E9oS 
H
t /fStd
QLogoi 
rGoDI0
osT":

	0SUB3020
)4lGe-r2e
i (,0M  'NcL5if0:

	A1e	Whii do you want ?":t                                                                                                    
50dr2(A	C=1:

	G   :/5,
h n	C=0,0d:ObtIN" T
N 

 Kp( o "MINIRBBS"
iFiIIF B$="NEW" THEN
		22220     ' RG callers   
 do everthin,16aalleas   
2145	IF B$="C$" THEN
		2230                                                                   2N   2 
	i 81  the SPE	AL file
BLIIFM="OF	 wlTt m  4132E"
215Ge-r2 = COUu3yr1;	F C 0o=
Togh3e99$uE
		GOTO 18080
2160Rfe1,0dr
2170 '
2197 ') discourage new call2  from 	"
hng this ic bulletin board Tstem,
2198=
""chs the only choice they get
i8TT
mE2200	COUNd= 0
2202	COUNT1 =$802 + 1:

	Y#SDo=
r

X3e99$u( gDt/d 080
 r5	A1SF0  
t latest system information before entering CP/M ?":
  'Nc
50dr20Tt *1:
  'Nc
50denh1tA	C = 0
2210	IF LEFOO'E5* oHHEN 

		2230,erBO,9M(B$:14o> "Y" THEN t ,r2
iM$M  -56040 ' Print  CC$yI0H6 lt,	OM="+" THEN t iBeAiM$3	IF MF$=8	 THEN
		2110
223'				Used to be DA
 r hrD8mouWl r45
223G
r0SE ' (just in case any r 7c0e stn,open)
Y36	PRf.
22e"GO1HHnY0  ' The$o the time-on-sysI60outine, andhen....
2240	0SUB3020:

	PO"9
e'Tt n$I A 0R E/o/M...."Tt  'Nc
50drSt,enhIPOKE 0,&HC3:

	e, uiIRt$i Fe0e the "JMPcnd go to CPM.
30000 '
3010 ' The main rogr 3ias now ended  It's Ee 
9o0outines 0om hetNn
3015 '
3020 ' Thehsplay BUL
TIN file subroE	 k3040 '
3050	Pm2r(ARRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50dr t6060RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50ffff0
3080u0"t="BU MyIm(A	G   :/d M$5 n	Pm2r(At 
1 o
40 o
4020 ' The d

6g WELCtE file subrouE>4030 'HiBr	GOSU0ffff0Hi1hIFIL$="WELCO
":

	0SUB80000:

	 HURN
4065 (H lCThe display DATA file subroutine*
MS'
408  'Nc
50f tE4090	FILe	DA
":

	0SUB80000:

	 HURN
4095 '
41V24"$Rp"
T SPECIAL filsubroE	
eG
4h=tk4140	0SUB22220
41Mf$-M="SPECIAL":

	0SUB80000:

	0TO 2052
Lo$N
122220	RETdo
oTTN 'rdrrrr	A$="Use ctL8?abort, Ou  tp$p G(rdrC(k13040 ' RouE#eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeprinstring fromo	Nssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssole
1N r 'rdr80	IF 
M<>"" AND A
 ehi
4wwlTt Eo0e	":t IyURN
1(ttF A1$<>IHHEN
		A$=A1$:

		A1$EE(rPhIIF RITT$(t,1)="?" OR N=1 THEN 

		Pm2eT;:t NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNen$:

	Rfe1rd00
13140	OenSC(IN"H +"):

	IF BI=1 TH1sn		BI=ASC(INPUT$(1bBio r	IF BI=11 THEN 

		BK=-1:

		GO1rde,r 

,Oe 
 n																																																																																																																					m2eTo
(rdU$ en+LEE
$)
1322 n$="":

	N=0
13240	RETURNrdenh=tk13280 'Nutit$os aept string :0C5th)m console
13300 '
133$IfSB
L AND SAV$="" THEN 

		PRINT TR$();rd640	B$Em(A	BK=0
13360	IF SAV$=IHHEN
		LINEeo-9lB
M
13380	SP=INSTR(SAV$,tg1N(A	IF SP=0 THEN t o0e8
V$:t 
: 'Oe	":t '2e1rdT0
13400	O
 Mes17 
M,SP1):

	
V$=MID$(S=o
rfT:bE13420	IF L1tB1 y
N 

 '
TURN
13440	IF C=0 THEN 

		13480
13460	FOR ZZ=1 TS$u':M):

		MID$'E2(2L5do  h#k
StMID$(B$,10,1))+3 =tASC(	D$(E2(oO,1))>96)):t AaY(oO
13480	IF LEN(B$)<6HHEN 

		13580
nLO	t="Input lit$olong	T165a=e trunc
o8to:":

	GOSUB 13020
13520)0
 2
r0O'E232):

	'	NT B(rd:0	LINE INPUi
 N
Tpe line (YN)?";QQ$:t                                                                                                    
56F$o(Ee
uS/EFTEe
u)
13560	IF QQ$=ehaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaT  Q$="y" wlTt mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2e
NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN	1tA 8
Ve	"Tt gRfe1rd30
5
otfeR+ e51)00000000000000000000000000000000000000000A	RETURNrd
hGIyURNrd
Y0 'r UtN
Hr
t	
o0
(	4ubroutC k11Z	BA 
1 = &H50
14013	CMDPORT : 
SEPORT + 10
Fio1h2HD 
PORT = CMDPORT  1r U9d=N:r Ue.1 La '
 sTHE DATE DIGi IIII*r U:G1 =N:
1402OwNt2" E,= 12 TO  STEr"& U:it0UT CMDPORT,(y3yeha AbE
1DUDOY(DIG,- 7)L1:0+6po1DR=E1403	NEXT"  '
s(r U2
M EAR= (DOY)1
rO) + 0Y(4)
1fGh0																																																			9NO=T0Y(b3
f
3	MONTH1  = DOY(2(r U2

i2HFO = DOYBStr U:=h2HF8= 0Y(0)
1405Rd=N(r U:oc=" OwNt6eHHE$ d8,DATE S(m$.Fi1i1                                        UN 	nTE1$="         (r UN vIOHOO+6e 0M,1,1)l(g6s17  t+lZ),1)
14070	MIDO+6e 0M,S:1e6'	TT$(i#Z621):bE14SF	tID$(nTE1$,3,1) =  g k14076	MIt(DATE1$s,1)l(g6s17  ttONTH10S:bE14079		D$(nTE1$,5,1) = g6siO
r=0ItONTH1),1)
14082	MIDO+6e 0M,e0'3	/"
11 "MID$+$rM,7,2) 
I  3siOm1 
e"112
Sts088	DZ$ = nTE1$
1401	DT$ S$esiOO+60M,5)
14093Yu/fuZ+6e 0M,1,2)
1- OT$$ = MID$(DATE1$,4,2)
141t +RN
14190 '
14200 ' Time-findR E9oS 1foE	
e
F,r5	FOR DIGIT :
w61, u/=E14(t I-9l=HoORSt&H1+"  '
nbE1l:/"TTtDI	T) = INP+
P10RT)r UiI	IF D
IT = 5 THEN TTtDI	T) = TODT	GI1HoR43
142/
XT DIGIT
14230	H(C 3RA0)E142/(2) = TOD(4)
142M T P = TOD(3)
F,T
L(4) = TOD(b3
ldM T(5) = TODBStr U ::Am PDe1 na
14260+7	
	:

	DI$ =ai
tA	DS$ iainF,
nLID$(Dt,1,C 3a6siOm91 t(HB:2L5o(A	MID$+ ee0'3'	GhOm91 t(H(2)S:::::::::::::::::::::::::::::::::::::::::AIOHOOT	$6L5*l(g600m91 t(H(3)),1):
O	OHf" l ) = g6siO
r=0EAE.:2L5o(A	MHOOH M,1:1e(g6si 8i1
AO)1o,1):

	MID$H M,S:1e6'	TT$(i#kGn:2L
14280em0
 ,+Si+2+M+":"+DI(r U S
LHD$=DH$+":"+DI+L+2,M
F,shIRETUR(r pTN '
150000 Hhe ON-E(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((Tndler....
15001 (rBr20	IF
-&5
1F64wwlTt mt eaetE 18L (d1F$F Er t2M34wn		 SO:

		RESUME 710
15100t 
o	 
oEXT
1v 7 '
15888888888888888888888888888888888' Small rouE#ru 1Hgl"
g date, etc., 3
b
 L hle (lms	 c
nh= (
i'' (rBSe

.mE15990	S$=
FT$&&&&&&&&&&&&&&L' y(g6siOEI0$$H  i#Z 50tLOfT: 4)" "+RIGHT$("0"+DD$lo
B 
4Y	S$=S$+"/"+RIGhOEgL+2rYlo:RL=62    ' (2Nr4fe ftGGGG)
160000 '
o (VS 33lpB tSmDE k recoF




o  r '
16hILSE
 0
 MesiOmr2P tuX)  lo,rSe
2H8h#;5
2H8h#;t5 0040	RETdo
o MV 0510FsChU.
 d
(pS aord....
16 r '
16 r	ZZr
N(RR$)-2
16541cTI
 	D$(#Y(2L5dL k16/G0Z=ZZ-1:t f2(o
RHHEN tO$NP :vtr1
hIWEND
 :v0	S$r
FTm==
OZ)
1658IfS$ID$(S2(oO,1)="?" wl M M+"n
1d
iIRETUb(21N 'rmioRD
X	 t  
 v0t user mode
222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222=tk21FC)na)R=NOT XPR( Hdo  (inacg2 N8here but kept fo0H1
$0e uobE1040 '
17050 ' Toale bell rompt
17060 'rmimiSB
L10Tte	5'
 08(ditto(rx)$N
mE11Z ' SS 1foE=N print a file
18h=tk11F$ItuF	 e2	A:H eO"tTt1 e
18040	IF EOt1)1mB  9N 

	d 050 

	EL 
I	LI am8
eC,A$:

		GOSU0dr20:

		GOTO 18040
1805 &00SE #1:

	 HURN
1801
mE1800 (rxd ' SubrouE#eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeelogff an 
wanted callerrx8 '
1Z0 '
18110	'POKE 0,&HC3gN------Restore "HMS4IcBASE fo
r1$ (doesn't

MNh 8f3 T matter if thahsn't donif ou use BYE

	 o1e
$08this program
1PhIRUN "58 tn GCOM" '8Mest log off ishroug
32E
18140	END
aBL=tk190000000000GOSBr U r0	'Now lo, e,to  aceFcl->gter ieck
8hf0	OPEN
 Ll 
:D"CHR$(y

2GIn9  d"+CHR$(&HA0),40:tf$I3
e2s0 AS RR'Tt  '+do 1r  h U$ '
 = VAL(ROfTP(mr	S
r=0mt P:

	RL = 40:

	GO :/o rrrr:

	PUT#Lo(A	RE = RE + tr  h0	IuM = MA	C$ THETt mN	he
2SOP"r  hxt LISllllllllll+
" + TI+E	 + MHOmgt Dlo(A	GOSUB 160000:t  
o6l(tA	C0SE #1
19100t 
1 o
19110 (,o ',r02' Optional HAR8 
RE DEPET
NT roE	m06ur
tsller
2004' datao a0
  linof your terminal if it has one
20060Dp
E  2oE	
elE t accea$heeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeesotRhrr0sT (yassi  k20080 ' BYE) so aAU 9 arily   0dware deendent
2010'
Pf0	s
TUISl8h17v) + "	  CHR$(27) + "f"sN$ + i
y"o	+
" + ST+ eEyyD$ + ", " + DZ$ + ", " + F$ + TR$(n6yn90;t5=E2014f$ot	m
yS$u'e
pD  $)
20160		CHAR =or '0	OHOm 
 0|e0'' 201M OTILE (Io(CO ttnZRT1) AND &H1)o> 1
20200		WEND
20220I8
e
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeedMn1 l84
R
20240	NEX	 eif60	RETURN,r280 ',0OOOO '  e,to14"4word ieck
()O '
ito	O$ = "":

	A1$F7Ad Codeword?":

	GOSUB 13020:t SLo(O'IS o
 1	(:

RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
50dT0:
 * o(A	XS='m& er r	PRINT
21040	|oSTmgt,P2$) THEN

		IF0	O0O+r
S6L5C$ID$t0
SZ,1)ToR4tID$+YD5*	OHOat,9,1)) THETtO$N 7
m(A				SYSOeCP(AM$'
 0 (,2GLR  e 	"chn pl  $Nf 21040osyo
 5EiausE00,time clo(sn	IF INSTR(X$,P1yHENt r	SF
tA		SYSo 01tA		 HURN
21050	SYSOP = 0:t +RN
21060 '
Y0000 
4"$P/M f l6  0ity testing routine  (2o,free to mtw4 iang )
32001 '
32010	XX=0
 r20	G   :/5if0:

	A1e	Whais thegme of Digital,p   9 a4
:lUG ebugger?":

	GOSUB 13020:t 
P(A	GOSU0der:

	C=t
Y0MIfS	NSTR(B$,T + O1yHEN 

		32400
 r50	IF INSTR(B$,==
O1yHEN 

		32400
Y055	IF INSTR(B$,"SI	) THEN

		PRfeie'( ";B$;", try the ot21ee....":t '2e1
Y020
32060	1Ge(0gyP(i	f2X=3 wlTt I5x/MNLog the calleNff....
Y070	Y(0m )D9$u( mI oT "You onT gm i2
GGGG":

		GuCF  r
320800Y(0msTHEN

		PRfei	l=7	$ try....":

		GO1
Y0St
TiO	RETUb esTT
mE35MN
-oBK's system use4urvey module  (aga68make cha  2GSt
nLd'
35002	PRIN'Tt )RfeiaSN =N    SYSTt =
R SURVecC o$$	
35005	OPEN
 Ll 
:S"+CHR$(& nofyG1
tH sB/+
90=0O 3hL P+"S",40:tf$I3
e2s0 AS RR'Tt  '+do 1
nLOmt 7&:rtRR$)+1
/e"IF	v/34wwlTt mt 73D(
nLO8r0e
+Ii+	o
Ii+2n
(
r09	0SUB:eiO
35010	G   :/5if0:

	GOSUB 13020:t Oe	 7  pE  
ser allhe followin
U $2hons. Thecta"
nLf0	GO :/5if0:

	A$="about wh	+)u are doinH a?o ensurthat this"Tt  'Nc
50drN(A	t="system takes
2tneeahntaccou	cs it,7elops.":

	0SUB3020
/FtFod =
i (
r25	PRIN'Tt )RfeiZ  Yleach ane =0ClcharaEl2   1imum.)"
3502mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2OEs"=
  0e 8 2t2h3  in23' m(A	PRINT
350$ )RINT " " M kind offffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffputer SCElX 	
al) aryoTE in =S0O0, OsborF "
nLdmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2I
o=STooooooooooooooooooooooooooooooooo S"M-PC  a.; if S-100, whichhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhtr
slC CPU   0d?":

	G   :&600:

	Q$=" 1":

	GOSU65100
35040	'	NT " 0fuhich operating systemsmm 1:r$80?  CLM-86?  CP/M-684t"
35045	PRINT atSD  SnPp+
 tem?  More thRNne?)":
  'Nc
5656o(A	Q$Ieh
tA	0SUB:0O0
/M )m2eiow =out the modeaCp	0	0e0:8& baud rat
GSe 	:

	GOSUB 35600:

	Q$=6":
  'Nc
565100
nL1hIPRINT "Where did you 8 0nf this system"Tt )RI," Ils 
 RCPMr BBS, whichne)? ":

	G   :&600:

	Q$=" 4":

	0SUB:0O0
/r	PRfei2+eDN-oE ith comuters rofessionalT?   ""ah kind 	Tt  'Nc
56560(A	Q$=" 5'Tt  'Nc
565100
3508000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000m2eiyow long have you been involv  withla
1-0X  U1
l2 ?":t                                                                                                    
56F$o(Ee
S	

tA	GOSU65100
35085	Pm2ei2 you rite your own programs, wh  i lang I
F. yoTE ually pEm(A	GOSUB 3F$o(Ee
S	v":t                                                                                                    
56(t=E3500	PRINT "Are you interested R011 rerI
r-U<r other(
nL0IPRfeiaSrDE'"8NLU1U $"
 F'k<ftwaregCp
g
"i
'Nc= :
hO:

	Q$=" 8":

	0SUB:0O0
/ei
	 r(A	'	NT "l+Pu'd   0e to "7e f0ther details, leavea l"	hn MINIRBBS"
35094	Oe8i1GI
St
nL  nGOSUB60000:

	
 N6Lo(A	CLOSE
nL F	OYo
NSW >= HHEN

		GOSU65700:

		RETURa1ICh 0Wsthe n9Ace callers
nL  h
Ntm2r(mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm2Es"  Es for thinfo tion.  Now back tohe log-in 2oE	
eeee":
 )RINT:

	RETdo
nt(tV2)UTe>$-tA
35120	GOSUB 13280:

	IF B$EIHHE9	S$="<omitte Dm(A		fPN
  =
utFoN DT n	ELSE 

		S$=E(
nt3
M LF  $+": "S$
352t 0 r
>2  'Nc
501ho$t
nTiIPU o RE
35260	REl( 
yr (
ee
M '
TURN
35290 '
3530' D

6g a ruler line to show hNe
t	cnswert
TS k3 0R (
n=O	PRfei0"o	10---------------------------------------------------------------------------------------------------------o"o30-----Iin
3562 '
TURN
35630 '
n= Ti24"0Ns uay call2  who125E  
ser qu t23 
35650 '
n8l	FIL$ =.1  e":

	GO :/d 0000
W 10	OP1h
 	,F

:U"+CHRO 3ATlo+"ERS. "CHR$(y1o,6'TtfELD#1,50 AS RZ$:

	Gn o6Lo(A	NU= d
L(RZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZA	NU = Nr"01tA	S$ = STR$(NU)Tt ' b
nY:

	0SUB60000:

	
 N6Lo(A	CLOSE:

	 r	SF0":

	RETURN
n8l=tk44620 ' NutiFcl-3
al
ing the time & MSOr2' y
t 3k44625 0$Ntfor T clock, ut adaptable for oth6alo(T
StHHnr '     a. Print just time
s640	GOSU0 hO 
4465 )RINT "T$$ime now is (Hrs:Min'  lp
S




 "TD$
4359 ' ,)eG Print el UwWE07t$oo
s660	GO :3s4940HHn4l$  '2e1,eHi (HHei=or2S's  f   e3Et$htime dl2erence....)
s83	OYT(6DsnID9$uE
		HBC nIB6y, n		H(1e6T(2) + 4
s840	IF H(6)D

m34wwlTt EAm  DRP+10:

		H(1 ':P-1HHeGLIIF H(5)D

O)1yHEN t 
O)1 D5)+6:

	nE.R2 s)-1
44860	IF H(4 oAE.64wwlTt EAE.RR s)+10:

		H P=t3)-1
s870	IF H(3)D

O P THEN t 
O P=H(fHF'Tt EAmnR2nmnP"& 488If2T(2)<HT(1yHEN
		H(2)Amn2T1tA		H(R2nIo"& THe

iIHD(6)Am PHT(6)Tt TD(5)=H(1SyT(5):

	 n
.R2n )-HE.StHshO	 n0 PAO SyT(3'Tt TD(2)=H P-HT(2):

	HD(1)=H(P99'0'ysitt '
TURN
44920UT u	tE= ey,M,M,2=h
4nIB2Dsnmn2Dsn
2Ds s),HT(5),HT(6)
44930	IN
 	LATER ItE H,H,e0
282=;H(1),H P,H P,H.+'o,H(6)
44940RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
5THeG
4450	'	NT "Nu've been on the system fS






 "G
44960	TFe	#"
44970	FO	b1 TO 6
s980		Pm2esING TF$;HD(I);
44990		IF I=HHEN 

				PRfei
L
	y0000		IF I=4 THEN tO$$)RINT dmI (H
10	NEXT I
GLf0	PRIN(H
Ldr	Rs 0=StH ImD
hm,OR n	Gn o6Lo(A	NU= d
L(RZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZA	NU = Nr"01