10 OPEN"R",#1,"SFALDES.0"
20 FOR X=1 TO 72:READ DE$:FIELD#1,128 AS D$:LSET D$=DE$:PUT#1:NEXT X:CLOSE#1
100 DATA You are standing at entrance of old shack. To the West is a rocky path. A road goes north.
110 DATA You are inside the old shack. There is a door to the West.
120 DATA You are at the edge of a rock strewn path which continues East. Small walks go North & West.
130 DATA You are in a forest
140 DATA You are in a forest
150 DATA You are in a forest
160 DATA You are in the middle of a road which continues North & South. A small path leads Eastward.
170 DATA You are at the edge of a murky pool with dark liquid floating on top. There a small path North & a small walk leading East.
180 DATA You are at a 3-way junction. A road goes North-South. There is a passage leading West.
190 DATA At the entrance to a small cave. A small narrow hole is West. A passage leads East. Notice on hole says `BEWARE SMALL THINGS'
200 DATA You are inside a cave. Light filters through from the East. A small path leads West. A smaller path leads South.
210 DATA The path is full of broken rocks. The path continues North & South.
220 DATA Inside a small cavern strewn with skeletons of the fallen. A path leads North. A passage leads West.
230 DATA You are in a long hall extending East & West.
240 DATA A room lit by sign reading `GNOMES NEED FEW TOOLS FOR DIRTY WORK'. Passages lead East & West. A small path leads South.
250 DATA This is the Tool Room. The floor is covered with small knives which disappear at a touch. A passage leads North. A walk leads up
260 DATA You are in a long corridor leading East & West
270 DATA You are in a twisty little maze of passages.
280 DATA you are in a maze of twisty little passages.
290 DATA you are in a maze of twisty little passages.
300 DATA Dead End!
310 DATA You are in a maze of twisty little passages.
320 DATA You are in a little maze of twisty passages.
330 DATA A tall wall rises above you. You are nearly encircled by unclimbable canyons. The only exits lead South & East.
340 DATA You are in a long hall. Engraved on the rocks is a message. Exits lead East & West.
350 DATA Three paths meet here. A small one North - larger paths East & West.
360 DATA A broad chasm separates you from a ledge to the North. A small path leads South.
370 DATA You are on a small narrow ledge. There is a cavern across the chasm to the South. A walk leads down.
380 DATA You are in an extremely narrow part of the cave. Exits lead East & West.
390 DATA A `T' junction. A North-South road is intersected by a large path leading East.
400 DATA You are at the entrance to an old abandoned mine. A small path leads South. a large path leads West
410 DATA You are standing by an old oak tree with a message carved in the bark. Paths lead North & South.
420 DATA You are inside the mine. Passages lead everywhere.
430 DATA You are inside a mine. Paths lead in all directions.
440 DATA You are inside a mine. Paths lead in all directions.
450 DATA You are inside a mine. Paths lead in all directions.
460 DATA You are inside a mine. Paths lead in all directions.
470 DATA You are inside a mine. Passages lead in all directions.
480 DATA You are on a road - with a cold wind in your face. A sign says `LUCK DOESNT LAST FOREVER'. The road runs North-South.
490 DATA The road grows smaller. To the East is a seldom used gravel path. The road continues North-South.
500 DATA On hilltop with view of strange house over river. Sharp rocks protrude from the base of the hill. Paths lead East & West.
510 DATA The gravel path ends. A large rock marks this spot.
520 DATA On the rivers Southern edge. There is a small sign on the shore. A road goes South.
530 DATA On the river's Northern edge. A big sign says `WELCOME TO YOUR DEATH'. Small message in red below. A road goes North
540 DATA A crossroads. A road goes North-South with exits to East & West.
550 DATA The ground here is littered with large holes. There are paths leading East & West.
560 DATA You are near an old stable. A sign reads `OLD ODOURS NEVER DIE - THEY JUST ACCUMULATE'. Paths lead North & West.
570 DATA The road ends here. Small paths lead North & South. A new road goes East.
580 DATA At the riverfront. On the banks are the bones of failled crossers. A path leads North.
590 DATA Standing by a large statue of a Gargoyle. It is looking at you. `13' written on base. Road goes S. exits lead E&W. House N.
600 DATA You are outside an outhouse. A path leads South. Other paths lead East & West.
610 DATA A large stone idol stands in front of you - a small charred pit in front of it. A path leads East.
620 DATA You are in a garden. 6 fresh picked carrots lie on the ground. An orchard to the East. A path leads West.
630 DATA In the Orchard. 1 solitary apple tree surrounded by oranges. A path leads West - another goes South.
640 DATA At the entrance of odd house. In the mail box there is a letter to `Wizard of Oz'. A walk leads South.
650 DATA Inside the house. A large door to the South - a large hallway North - an arched door to the East and a small doorway is West
660 DATA The dining room - and guests are expected. There are 7 plates on the table. There are doors to East & North.
670 DATA This is the kitchen. a big pot of boiling water is over a wood stove. A door is South.
680 DATA The living room. A small statue with a round head sitting on a table. A large doorway is West.
690 DATA You are in a secret chamber. A rope hangs from the ceiling. There is an open panel to the South.
700 DATA You are in the basement. A corridor leads North.
710 DATA In front of a large vault with sign reading `DEPOSIT TREASURES FOR FULL CREDIT'. A corridor leads South. A door is East.
720 DATA The reception hall with large table that looks back at one.  Can of Pledge on far side of room. The hall extends S. Stairs up
730 DATA On the middle floor - stairs up & down. Doorways to East & West.
740 DATA The library. A large heavy book is open on the desk by a window. A door is West.
750 DATA The bedroom. A large walk_in closet leads South. Large dresser with central drawer near bed. A door to the East
760 DATA You are in the large walk-in closet. The door is to the North
770 DATA You are on the top floor. A door leads West. Stairs go down.
780 DATA You are in the musty attic. An old chest is in one corner. A door is East.
790 DATA Inside the outhouse - a strange message is pasted on the wall. A doorway leads South.
800 DATA Inside a small cubicle. Written at top of door are letters I F & T. A letter is missing. The door is to the West.
810 DATA You are inside a vault
