280 REM  AUTHOR:  TOM SPEER          24 NOV 1983
290 REM  ********  SAMPLE ROUTINE FOR DEMONSTRATING FILL PATTERNS  ********
291 REM  TY : DELTA Y
292 REM  TX : DELTA X
293 REM  LG : LENGTH
294 REM
300 TY=1/15:HT=1/16:TX=1/11:LG=1/12
310 X1=0:X2=LG:YF=1-TY:Y1=YF+HT:Y2=Y1
320 FOR I%=1 TO 13
330 FOR J%=1 TO 10
340 GC%=(I%-1)*10+J%
350 IF GC%>127 GOTO 500
360 GOSUB 182: REM SET COLOR
370 GOSUB 190: REM FILL BLOCK
380 X1=X1+TX:X2=X1+LG
390 NEXT J%
400 X1=0:X2=LG:YF=YF-TY:Y1=YF+HT:Y2=Y1
410 NEXT I%
500 X1=0:LG=1/65:YF=0:Y1=HT:Y2=Y1:X2=LG
510 FOR GC%=64 TO 127
520 GOSUB 182:  REM SET COLOR
530 GOSUB 190:  REM FILL BLOCK
540 X1=X2:X2=X2+LG
550 NEXT GC%
560 GOSUB 196:  REM CLOSE OUT PLOT
570 END
