10 REI0"1(E"$I2.MB $E72 D$P  JOATA#61,OV.981
N RINBON06LPT (E"$I2 -MIV:TR 4DATABASE CONVB ION ;L82ION
ROON LEALTT, )) ,E0LF(1U$
OD$0T210Q,5BFLTFT "20G1LU2ENT6LENF
ET0GPOE0MC fET2C (assumed 6 0 O .ADVTPFC$
80F TD0 ( THEN P101"ID(IL 0HA$$
D"G#,2DF 1FEOE"(FC$,"."10 TH1110
10FC$H0 8IL$,INSTR(FC$,".")-'
FF :0 36".ADV"
N 5:0 36+".MNOOD 30 TEST= 
) IMLFMnJ 0 IAT0 ";F$
1FLN2101"OUTPUTILE = "MC$
16PRINT
17OPE"I",1,F$
$1$2HM3  92, 6
200 PRINTL
)ADVENTURE Z8DATABASE SYSTEM"
2 IPNT#2,(TBMJEM6TQR $0 OF OPC p0$)ic domai1198P. $Ergill,DL
 IML=
1GE( $L5m8T $Eicatio1b2$1$EN)T oon, Nov. 1981"
$N IMLFH 
1GE(O1$EN NNI$A5F )01FD)TAMJ8T7Le$
FCFALTT#2," for thFN $0D71ET :E ONN0D)DFT0HNT58TIOA51LCGEM1) L6 $ 50MUI$0Gch"
23READ W$:IF$DQ
"EOFETEMIMLFH 
1DG B2D"GL  1
240 REG
QNF2E0 1EJ ,2G G
M GOSUB 1580
$  1
D0 (NEM$,N
280 IF LEeBG91)=" " TET Q$=MID$(Q
$EDGOTO80
290 IF LEFT$(Q$$E1CHR$(9) TH1Q$N $(Q$,2DGOOL61G5C ILEFT$
D
i"*" TH125 
 0E0Q  20F Q"NN$(Q$,1)=" ETEMIG2E1N$(Q$,LEN(Q$)-1):$SUOL1G5UCF 1F2E1NBG96)O,R1 7ET0)EE R) T1OOTO 4507N"IF LEFTBG96)O,R)E7+HEN TEST=R) T2OOTO 510
C1F"N= A,$,TE ""NCHW" THEN TEST=R) T4:GOT540
360 IF LEFT$(Q$OTE "MSGETEM"E4)04) DDG"5:R0
370 IF LEFIT
D
E1"UMESS" TET T T=TEST+16:GOTO)) G5C:1F2E1N$(Q$,31"LOC" Es)E")0)E")  2:$SO:#, "2DF 1F2E6(Q$GE0R"1""EQT7ETEM"E4)E4) T6$$
D", 
400 IFEFT$(Q$,5)="BM3"EM"")0)E") T1$$$
D"5F=GDAFL nE N$(Q$,4)="FLAG" TET T T=TEST+256:G"5F-GDA#1F2E1N$(Q$,61"OBJDS  "aET R)0)E"BC/$$R5/:# 
R16 IF LEeBG96)=DIM  L3"aET TESTEEO=T1024OOTO 10# 
R19 IF LEFIT
D
E0 Tlb)T ID R)0DTTS $)NEMIPNT#2,Q END")OMFL nE N$(Q$,81"END)TTR AND TEST=2047 THEN PRIFBU EOF] ALL CORRLR:I"2 E:GOC 6 GDA  0 IF LEFT$(Q$,T8
AE$2TNTR EsLN210"PV"I1E4:PRMIGTDCLOSE:GOC 6 GDAR0 P101"MISSI$(TSH0s(N END OF GAEB2  (T$
D"5Fh0
C1IPNT "PROCES16G D"$ 1 5+ABR
:1IMTTL
O,R$ 1 5";
470 GOSUB 148 
:F 1F2E1 A,$,TE ":TABLE" EsLN210D ,E0 TCNIDN$$
D",N#,T"85 MID$(QC EOET
D
UOE
iE ","
41IMLFH 
1G#E0 T7EL,$
NNF

D"5R70
510 PRM+LS 5E" 16G D"$ )EE2T2E 
N RIN
1GR$ )ECD"
51,,$SC T GE) IMLFM+L
TE"(65N(TN64"AT4
550 P100
L
B0"NC$DD";
N$0 G UB480
3"1 nE N$(Q$,TE "ENDTRN4 TH1GOCA61
T:1F9$="MSa P "EMIMTTL
7)="S-,255":G"GC#,
 Q0 IF LEFT$(Q$+D,2TT(NCU"M2"NT$(Q$,4)<>EST" THEN 610
6 IPNT#2,)="S";MID$(Q$,INSTR(Q$," ")1):G"GC#,TT FF "FT$(Q$,6)<>"ACTIONETEM$L3(T0N2101"C:/ACTIONAULT":PRINT Q$:$SC 62 
MFIRINT#2," DEFB 25G01$(Q$,I TR(Q$," ")+1);",-
630 GOT560
640 P101"PROCESSI$LPOE2T2 GD$50 PRINT#2,""
2BTOD$60 WE$=HR 
*"1OSUB480
D61FF "N=N$
D
YEF)0:TABLE" THEN GOTO 480BC
1FFT=NBG91,D,2T7ET052G
+TFLN21 
" DEFB ";Q$:GOC$70
7 IPNT#2,)="S00"
720T2100 G# "S";M6(Q$F4)SG9" ""=)
730 GOT670
 T"0T2101NO,NE"( 16GTTS TABLE"
7FLN2100
   NTT4(o)I
71IOT6="UME G
#+ OTO 61G
$1IMLF TLS 5E" 16G1 5+ABL,,5T IML=
1GI":";
$H ,,""5 TC 480
81IF LEFTBG98))0:TABLE"NEMN"80
L1FF "NT$(Q$,1)<>"'" THEN 84 
"TMLFH1G#E0 T7EL,$:GOC:N#,T$R0 PRINT#2,)="S00"
850 PRH 
1G#E0 T7ELNT5"Q$,INECBG9" ")+1);",2 SGD:$GOTO 800)
+ IMLFM+L
TE"(6GE2T ""EQL)"HR
880 CN 0)
,PRINT#2,"TABK
8R
90GOSULT"80
910 IF LEFT$(Q)
ETlL4"AT"aET 1030D
L1FF FF4)BG9" ")=0NEM$TTT=CNT1:PRH 
1D
D0T85 +PC6$
D"GN#,25CF91$H0 8IT
D
LTSTR(Q$FOE CQ,2TF9FN Q6(25FTR(2GF1T1)
950F 0 (Q$,1)=7ET09$=96(Q$,2):GOTO 950
91$TTT=CNT1
970 PRINT#2,Q1$;"QU JM
980T2100 G30 ";CNT
Q0F 0 (Q$,1)=5U"MA9"NN$
D
i"'" TET 10102NT,  CLOSE:PRINTLTCORRL1KE47ELTDGOT1620
T 0 Q1$=MID$(QDTs"Q$)0 )
T 2 Q$=LEFIT
D
MA,$)-2)+"'"
1014 PRINT#2,,E0TT7EL GD 016 PRINT#2,,E0 TC,+PQ1$;"'+80OOD 020 GOTOB=GD30 PRI1
1GNHEN DE $0":"INT#2," DEFB 250"
TA1IML=
1G#E0C,"aETA1AL,3GD 042 PRINTL
7)="SG'+80H"
 C1IMLFH 
1(1D 1CFB)LALTT#2,)="S251"
NT$0 PRINTL
7)=0S'IT  THE'"
T$2 PRINT#2,"EFBCTT
 "E$ME
1070 PRINTL
B(PN DEFL52":PRINTL
7)="Sr GD80 PRI1
1G#E0TTC,IbBMTELQ3GD 082T2100 G# "S'E'+80OOD 090 GOTO 4802N Q1T2101NO,NE"( 16GIM  L")""AT4
1092 PRINT#2,DIM  LIBTP
1
  GTO 1263
1100 PRINTIROECUFWAI0ABLE"
11110 PRINTL
CP0o)I
112GOSULT"80
1CF 1F=N$(Q$,8)="ENDTAN4 THEN 480
1140 IF LEFT$(2
 "E,D"CHR$(" THEN 1160
1150 Q$=MID$(Q$,6):Q$=LEFTBG9LPT
GE Ci,,LL0 "INT#2," DEFB ";Q$:$SC 120
I$ T IMTTIROECUFWMZ"4"E"
1$1IMLF,2,"FbDEFB0"
1
1,," "S148 
TT1F2E1N$(Q$,81"ENDA"N4 THEN 41GD10 IF VAL(Q$)=0 TET CLOSE:PRINT B)LALTT "IN(IPD FLAG":G"5Fh0
122IF LEFTBG921"14" TET PRH 
1G1I0T":9 
/  0 IF LEFT$(Q
$E1"( THEN PRINT#2," LT)I
1240 IF LEFT$(Q$$E1"2+ET PRH 
1G1I"$A0
cC1IMLF,2," DES";MID$
D
LTECBG9" ")+1)
1260 GOC 190
1261 PRINT "PROCES16G D"$ )U2ABLE"
1262 PRINT#2,D"$ )U2o)I
1263 GOSUB 148B1F=N$(Q$,1)<>"'" THEN P100
L
7)="S00"
1265 IFEFT$(Q$,81"ENDA"N4 THEN 41GD66 M6(Q$F4)SG9" "D 1","
1267 PRI1
1G#E0 T7EL,$2$ND'GOC 263
121,4NA "                                                                    ,AGT$,"      DSEG,LD5
"
RNA " PUBLIC OBJ
T2GFIUBLLGBJDES", " PUB$LLPLS6G,,LD5)7)2E23UBLIC PM KOFIT2PC A5DSK,LDT$)2EUIUBLIC TI0 9"5 T2PLP G"FIUBLIC UM S"
129DATA IUBLIC LOC"," PUB$L)1""EQ
UIUIe FLAG"
FCNT"L XRIeL14"," PUBLIC FL20","5 T2P F1"
1F1,4NA "01DEFL 249"RHQL=Ic7 OPN
E1IFHOD 320 DAT LII#E0 1N2GM TB0"
E1Ic7 OM T8FCB, I
TAOOD 31,4NA "D"K 0 9I"O$R (TO DEFL 252""LF
EFL  L "0 DATA "LF
E1I/"OP DEFL 3   5#E0N"","OW DEFL 5"2FOC1,4NA "O5#E0 1ND2G"2=DEF7", E)=IF62G"C"L
E1IG,,"T#4NA "8,,E0 1I2GH$
I,E0IIKOET# ID O"=0 F GD 370 DATA "E1DEFL 14","ZL DEFL5","ND E LTD2G41DEFL 17,L "T$1,4N  =#E0 1IN,"NTF DEFL 19","G  DE $2GI  DE $OOD 39DATA AO)=DD 9""O)=I/ 
2R D 1R","N"O)=IcCO1400 DAT L:O)=IFF"TT1DEF2","WR DEFLKO$4 DEFL 4"
1410 DATA "PR DEFL 5","PRM DEFL 6"," , I"2GR TE IF6OOD 420ATA)O SD"
E1IKOQ"SW
E1IFFP9"MV DEFL 11","2O)L KOYE1IFF  "
N"3DATA  =#E0 1IA
OF 0 #I9"EX"
E1ITD2GR5E1IF-O,,LT"4DATA $ E1IFF6"CREFL 19","D  DE $2G1PSDEFL1"
1C1,TA "LA DEFL 22 TCT(#E0$F7Q"SM
E1I/R"6
1DEF25"
1460 DATA "F
E1I/:2GRNDEFL 27","IF
E1I/9"GRUN DE $  GD 470 DATA "EO,,LT"80 LI1INPUTF
,$
1490 GOSUB 1580
1NF 1F2E1N$
D
i" " THEN Q$=96(Q$,2):GOTO 15 GD 510 IF LEFIT
D
E-0EI =THEN Q$=M6(Q$$EDGOTO 1500
,nF 1F2E1 A,$,E1"*ETEMIN"80
1530F 4)SA,$,T4$,))=THE1550
NA1$=LEFT$(QC EOET
D
 a SQ))-1)+" "+MID$
D
LTECBG9CHR$(9))+1):GOT1530
1550 IF RIG8ITQ1)=7ET09$=0 (Q$,LEBG T1$EDGOTO 1550
156IF Q$2 TEMR80
1570 RETURN
1580F 4)SA,$,267"E10 THEN RETAT
1590 IFNSTR(Q$,"*/")=0 TET CLOSE:PRINTT($-TLHR:PRINT Q2OOTO620
1H IGT1LEeBG9INST"Q$,"TG3T1C0)NT5"Q$,INECBG9"*/")2)
NDF1,,$SC 51GD LIRIF2$278i5F"T
4)Sto1eturn to CP/M"
1630 END
GN,6 4 C2GM T8FCB, I