1 REM BAS1RNO2N4:
NPET; HT1NK WEVER8REM NADNe0NLICHTINGEN B E hN

 
 REM NOS, HOBBYSCOOP HILVERSU  

!INT CHR$E7I;:WIDTHEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE tPS
 (E0000
2LO 1010
100 P1e$Ee T REE7I;:
 8110 REM
5 IF HO>51 EtHTQ111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111IE*0F VE>21t!1=23
113 P1e$Ee T REE  );"=";CHRNF 30;CHR$(HO+S0;
1y2 S"812 S
1NEEK(0T1F5A)91=PEEK(0T1F5B):=DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDE2S*SE E22 IF HO>127 THEN HO=HO-128:VE=E+121 
 VE=VE-PEEK(&HEF62)L0 E<0 THEN VE=320 E
124 RETOE82 I"""""""""""""""""""""""""""""""""""""""""""""""""NKEY$:
 8210 GA"e(00:s1"U1 1tlE0
211 RETURN
250 TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT1e T RE  );:RETU18260 RV=RND(1):RETU1827VRNNO1c 4O
300 SR$A CM2U I
5 Q7EN ,$)L
0U6E 1tu2 S"8302 IF RIGHT$(SR = I<>" " TH
04
7Hc$=LEE4ND

7-1):G!g)1
304 s1FTNDR$*0<>" " THEN RE"305 Ts R,$,Q7-1):GO2A0+
1

",:IF CN<>0 THEN 3

 
12 SR=INT(SR=5):GOSUB 300:
gg3)
316 Q5=SGN(SR):SR=ABS ,):Q8=INT(SR):Q9=Ue
8
318 FTOV                                                   N-
EA
9=Q9*1
1P-T Q6
320 9=INT(Q9+.I:SR=Q9:GOSUB 300
322 Q9$=Rs RF1"+SR$,CN) 
R)F Q8=0
1 g
9E 1t!*1++ITDR=Q8:GA"eRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRF 5=-1 THEN S""BR
DR$
S
 SR$c$"="+Q9 +
30 IFRt 2SR$)<=CT THEN 33 +
32 SR00:6+RQ1$R1BNLO 340
33TU1 >GH"2"                     "+SR$,CT)
"v0O<;O* 4OE8359PRINT SR$;:RETURN
360 LPRINT:RETOE81000000000000000000000000000000000000000000000000000000000000000000000000000000000003111111111111111111111111111111111111111111111111109* (N
2I10 G!el5
102L  -3PI:GO -35
1030 TT"          Astabiele multivibrator":PRINT
I40 N"eR)RC!INT:PRINT:GOSUB 40000
1 0 GA"eT^ N 
"e0000
1180 TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT  Gee$4e gewenste duty-cycle RBGB m
1190 PRINT"  uitgangsspanning op punt 3.  7P243
1I TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT  moet liggen tussen 50% en 1%."
1210 HO=3:VE!FIA  110
1 Z TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT "StyU2"U6E HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH %          ";
1240                                                                                                      "1B

21IPl 0S :!2Et280
1260 PRINT"* Dut"SRycle mag 5et negatief zij T":3
12/* 1210
1280F D>5E IT  *
1290 P1e MTT=M
u-cycle groter dan o:I1ezen! * ";
13 GOTO 1210
0Nl 03,PIHEN
402 VTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT* DtyU2"U6E oTlein5 dan 1% maken! * "
1330 GOTO E0
1340
HF i0t*nNHTQ1 91=109I"7110
1360 FOR I=0 TO 1
  6FhTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT                                       "
1380 N-T
1390 TT"  Geef  RR O sE  GY
HT----------------------------------angs- N43
1400 PRH"
R:FN
uenti0: N3 u
et iggen tussen"
1410 PRINT"  0.1 Hz GTI0 kHz."
1420 
0A91=16:GOSUB 1
1430 P1e ",5!angsfeqentie in Hz ";
1450NPUT F
1460F F>.1 THEN 1H*
1470 P1e MTR6666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666662"7GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGG hg5 dan 02e PoTiP2

 8Mn 
ge+O                                                         1490 TT"* Frequen5e lager K 100 Khz 01P2

"
i00 G!e+O                                                         151LO 1350
1520 IF F<1E I-:1.9999999E-06:GOTO 1560
i30 IFoG0 ,2EtW9.9999999EsGOTO 1560

-l 06,1! THEN C=9.9999999TG aL* (E560
i50 GO2E49,EM FREUENTIEE 
)581560 PRINT"                                        "
i70 FOR I=0 TO 8:TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT  Ok";:NEXT
1+9a*1)wNO10E/(K1*F*C)
1590B=K2*$E 
02wI RA=K2-2*S816 RaGOSUB0000:RB=R12Y 9AA:GOSUB 5:RA=R1
1630 GOST
PnS0A  50RFIA"eR))))
1640T ""
1660F RAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA THEN R1=RA/10000:K$="kilo-"
1660 TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTR1=";R1;K$;"ohm"
169a40" ,2=RB
1680 IFB>>>>> THEN R2=RB/10000:K$="kilo-"
1690 PRINT"R2=";R2;K$"oh m
170NRINT" C= ,t=IIIIIII!;"G:Rrofarad"
1Po!INT"Frequentie= N6g.13b3+2*RB)*C);"Hz"
1720 PRH"T=M
u cRRle" NNI2RA+!0/(R
N
,B);"%";
1
0 GO -;-5
1740 N R                                                  F  -3333333333333333333333333333333333333333333333333333
175NRINT"Dit was eezei BASIODE program  Du3
 60 1 

26T: t G F=,EM  NIET B0TEN BEREIK
20 K=0:REM  EXPONENT TELLE
Pr w RR12I-H2N42, 1n T11E82030 IF R>1Es2Et61+,EM  TE GROO
P= R. Q
2050 REM  ZOE WAAR1 IN TA1L
2060 IF1<=1 THEN 2100
 sF"nNN42
 0TL;<
R:Q
2080 K=K+1:R(, 1L ERSHUIVINGEN
2090 GOTO 201cEM  ILTNPNEN BERSCV
I0 B=1:R(
NOINTERAAR ARRAYTTGE82110 E=25:REM  POINTDD;, cA412DE
2120*10NTNR +E)1 NN42
NOINTER222222222222222222222222222222222NO IBRUIBAAR VAK
2130 IF*! HEN170
2140 L=A(M)TtlN=========================================================2160F R1<A(M)TtS*u+09* (NE20PE60 L>AR
0THEN B=M:GOTO120
21w 0 2R1-ATOl $(A(E)-R1)TH. 3g )9* 219tE*
0 R1=A(E tEI!O$N;1P42TT1e 1 
 TNs) P0JNDE
2200 R1=R1*1n :PNE0F R1> TtuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuINT(14444444444444444444444444444444444444444444444444
2222O* 4OE82230 :
30ANRINT0014nEK
"3)10 P1e m1!                  !"
)20 TT" +5V-+-R8 d  FI R
7R " +
030 P1e m1!      !5A1!"
3040 PRINT"      +------4                  01$BF5ER83050 PRINT"      !      !                  !    !8sNRINT"      !      +--7---------6--2--=9!"
3070 PRINT"      !         ! 1I T
 T0:R"
)80 PRINT00R R5+ ! R5+ ! eT.K+!8GR6NRI m1+-! HR-+-"1*.$B.$BFR!--+" 
0 PRINT"        +1+    +-;;;;;;;;!!"
================================================= RETU183120 :  Ri 
i:VE=%LIA"eTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT2>NToe 1R\....";:GOSUB 210
-------------------------------------------------ETURN
-1 9 P10000 PRINT:PRINT:PRINT:PRINT:RETURN
60K  22I
6010 FOR I=1O 25
60u
D A(I)
6030 NEXT I
)40 GOSUB 0:GA"er0000
6050 TT" - "0aOIETROS$ 
H
$1E  - "y
6060 TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTP I70 PRINT"    *;K0 
1
0I 
1****     **************************************************************************************************************
600 PRINT"    *    *  *    *  *    *  *    *  *    *"
609NRINT"    *    *      * OT00 
eQ    * HI 
43=I0 P1e m1$:=T H$:
    * HI 
eQ    *"
================================================= P1e m10
NET-
    * HI 
eQ    *8E 2>NT00e1*       *    

    

    m
616NRH"
1*       ******    **** ;9     I  tHFhTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT  tHI10 PRINT"Astabiele multivibrator met d(1-5"m
6No!INT:PRINT"D
o(0
 *BAma  75 e  G
"we5standen"I=6FRINT:P1e "7GR Rondensator in het volgende chema"I= +/IA  40000:G!eP1                                                         619 

00000 REM  S PD3RD WAARDEN
)010 DATA2$ 0Ea7a2  $ 0+a2\a2 + aP3
320 DATA .  aPUU 0Nec.3,. $ 0AR.39, m
30NS :3 3 .47,.51,.56,.62,.68,..............................................82=91,t6"9Sg0E,I
K127a2  $ 0ER.1R.1,.2
)02SATA .2K4,.27,
,.33,.36,
9,