1 1:0:  
 DODE 2 RO28neCOOR HENK WEVERS
2EM NADERE INLICHTINGEN BASICODE6IBE5T7T TW2:5DOOP 0 
AEMN M 
5 PRINT CHR$(26);: RUP25 =
10 G-2I
20 o1010
100 PRO
CHR$(3 TNJ"N
110 1W10$ 47 G70 2  :1 THEN H2S=112 IF EV0OR01RlS6:10
$)(RINCHR$H                                   =";CHR$(1E3555555555555555555555555555555555555555555555555555555555555CHR$(HR32);
115 RETURN
170 NREVVFAIEF5A):VE=E1AN 1Q
:I-&HF0
W VE=VE0:10BCF T,RUTHEHO=HO-128:VE=VE1
123 VNAE(EE(&R"3 2
VE<0 THEN V2YE(TE"0B( 0TUR1TI
 IN$=INKEY$:R1 RN
210 GN : D)N$="" THEN 21<WRETURN
250Q SHR$(7);:RETG0"30 RVG0)$O
TUR1TI  
F2J+46O
TURN6 = SR$=E:340$ =IE(O=LEN(SR$) 9F9
 THEN RETURN
0rO$0F134$,1)<>" " THP)$=
303 SR$=LEFT$(:3 2R O-1):GOTO 3016 RINe0B$(SR$,1)<>"  N0HBURN6 M1291)GH340B3A O1):o301
LGVW
2 O O1Af=PFO516"2R=IU51s.5)NGNOOOOOOOOOOOOOO:GOTO 33-6 Q5=SGOB"NUNSO40$ TF)JU0OU511111111111111111111111111111111111111111111111111111111111Q9=93R 0 3N4<VN=1 TO R6=
Q9E =RA:GV516: 
Q98 26RF9":)"NB6< :T 
322 Q90RIGHT$("000000000000000000000"+SR$,CN)
324 IF Q8=0 AND Q9=0 01RG6S
1
3X
B0Q8:GN 3 DF3S W THo4
"-"+SR$
328 SR$=S;N0
BRQ9"63 
IF LEN0B3I<=CT THEN 334
332 SR0LE"34R5 ) NDNoO 34-4 SR$=RIGHT$R60AAR
B3)T)
3
SR=Q4:R1 RN
350OG4 < :3WSB1" RN
360 (RIBNJ" RN
4 5O "EL):GOTO 20:REM ST -EIMTE
E NoO 705TN5CNITIALIS20E0
1100 AW=0:1:Vd
2T UWOOREN
1111111111111111111111111111111111111111111111111 HO= AE
4+2*AW
11O VT
OMIf=H=
1130 HOMO
AE
2*AW-6
1140
:R0:."R:0 SR=AW+1:k0)NB 9HT 31."
PRINTR$;" ";:ML=9:GOSUB 6100:IF A$R1THEN 1220
117F :R0:TI4 5T)KOELOR01R0$ 40
1180 GO B 4800
1
S  00 lSGF IT 110
TI
 PRIN
F 0
H
+ETURN> NOJ( het srteren.... 3E0
1LONGN B L2 GO  O68230>13 THEN 12=
1IO GO=00 THEN 7S=
3I7NGN B 26:REM OVERZICHT0B( 95T I
:REMNELSOREE:1050 HO4
2Q
1 TO A0
1260 E
2*R1:GOSUB 11  Q 0O
S$(OB0RA:C
I HO=0:VE=22:GOSUB 1100BI"
PRINM
Llt U TE
o=
ROPat langzamer ziE *W:GO B 64
1290 IF N= THEN 13110$I
 IF Y
 01R0B 1R; NGNOUUUUUUUUUUUUUU:REM  l3N  DHT
132F :R0:6":REM OPSCHUIVEN
63 
GOSUB 330NpS +AAGSOREE:1040 GO B 54:REM SPAT110$3

EI
1360 :
I4 58aG SUBR CONTRSEE>OORD  A$
2 
E
0
0IOWTCr
1 TO LEN(A$)
I60 VB=AS :R  XR3TV,O  2SO G7 21A64 AND VB<ROR01Ut 11TSS) AT>64+HL00 AT<91+HLHEN070
206 
ES<I0 NEXVK
2080 tEN
THEN 2110
2090E$="Woord bevat ie alleen maar lette+C0
2100 GO B 50000:G-RU1B
A=01+1:WO$(AW)=TBIJN90W30
230BE5TN BR SNELSORTEE1T3W0 GO B 28
2320 -
01 THEN 240<33I<VEH9ro
O"
2:
F,28BUro
"T33

IF03                                          <1$(J)THEN 238<3(IOW"F21$(I):W$(I)=W$EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEW4EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE"51T3I FT$=S$(IBN3C=S$EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEES$(J)""51T3I"
NEXT J
2390 NEXT I
2400 RETURN
2

:
260BE5TN BR OV3N  HT
(W0 GOSUB00G4 <G. TTrteerd"
2620 HO=29:VE=0:GOSUB 110:$8  9 TRorteerd"
2630
N(EI9r
"T40 HOB AE
2*I+1:GOSUB 110:$8 1O$O  2SS91KS)
222222222222222222222222222222222222222222222222222222222aW 0"T(I  0"TI"=EM SUBZET OM IN
 R ETTERS
gS; N(0
1 TOT
" =IO2FSR1TINNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN<V
1 TO LEN(W36ON1TI"5G2E02 PMID$(WO$(I S J))
2850 ::IF BT03 THEN B=B+HLTI" :Q NP0I3G:1TI"O0 :NE:T1
2880W$(I0A$TINN
 :S$(I)=WO$(I"TvN
NEXI
291B1" RN

U
16"00 REM  BROUTINSHI"16"10
3120 TV 1EH9,cS9H-1
3132WTV
1 TO A0
3140 O 02*J+1:GOSUB10
3

::PRO
MID$(WO$(J)LEFT$(LE$,29),I,1);WO$(J)
3160 :N  SaSFeIO=RA =
31SNJ"N
319S0
33 R:TN BTRA:
 N lEB"63"S0
337NGN B800
33330 IF A
1 THHB1" RN
33
FOX=1 TO A
W
33
:BA0
3360 :FOR Y=X+1 TO AW
I ::IF 6 :2 R  "$(Y)THEN B::163 0
 :NE:6M"3N
 :IF B>X THEN GOSUB 36
3400 $o X6 F

RETG0"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""OS0
)
 RETN BRaDg2P(0  B
3610 :
3620R=24FBMaNN
m+1
3)O)=28LEN(S$( C
3640 ICE  I0V: 3 I1
365 GOrEW=B 01RCC=29
rI8aG-- SC(ON6 :2 8E: IT --
3670 F)IO4
OT1C STEP-1
3680 GN  )H
369,01R:GOSUB 110G4 <$(B)" "
3700 $o HO
3710 RE
9X
 R9:RX) ERUIT --
 :IF IC>2OR01R H  116 O30
NIIO=29 TOC STEP1
3740 GN B 4200
37
VE=IR:GOSUB 110:$8 06 3                                                            " "
I S91KS  
S-)  O0 RET2 UR9F03 :2 eA3F03 3                                 NEER6 O80 HO=JC:FOR SK=JR TO IR+1 STGO"
3N
 GO B 4200
3800 E
SK:GOSUB10:PRINT LE"3CSE6AEN(3G: 400
3810 VE=H
W:GOSUB 11  Q 0O
S$( =
3820 NE:T AS)NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN0  D:TV
ANU1I9,1 W
38
GO B 4200
3850 VE=SK:GOSUB 110:$8 0+"" 0p3TLEN(S$(X)5=
3860 VE=SK+1:GOSUB 110G4 <$(X):NE:T AS)"O0 1:T2 URCF STRINGS TERW16 0
1
TCIO=JC TO8
3890
:R0:200
3900 VE=5R0:00:P <" ";SG:I6FnS9o
S-3iIF IC>2OR01RN
H 33333333333333333333333333333333333333333333333333333333333333333333333333333333WT 
 D TO8
3940 GN  )H
395,01R:GOSUB 110G4 <W;S$(I
3960 $o HO
3970 F216(I:W$(X0W$(B):6 :2 1R
3980 T$=S$(I:36(I=S$(B):S$(B)=T$
3990  NSF :R 5200
$O:JN90:ELGSt)HREM SUBR PAUl"OIT

1OIGIe3 NE ER-0:4TI
6I8aW RN
PSOS0
4400 RETN BREoCER
F

1O:)H7NGN B 100:T010:VE=1:GOSUB 110O:rI7G4 <"ALTTETISCH SOEEkB
"O:r3UT010:VE=2:GOSUB 110O( 40 Q 0O

O30AA="O:r0T1" RN
4460 :
4600 REM SUBR INSTRITIES
4610
4H70 N=:VEMO
9HT 11t3I7G4 0
)ru7Tp RETGo<1e ER0Lngevoerd A&   0
"640Q 2Q S VN0GtweerSECB1" RN voor h
PEA:(terE"0

"O:3:0 RETURN
4660 :
48 R:TN BWIS ONDERE
REGELS
:0E 
:
:00I70 2$1 VE=19 TO 23
:060 GOSUB 110:$8 0p3J1840 NEXT VE
48
RETURN
4860 14L) R:TN BFOUTMELDING OE$
50OS0
5020 GOSUB 0
0:REM WIS ONDERSTREG2
0
5030 HO=19-LEN(OE$)/2:VSHT :T LS(RINT OE$
5040 GN 
:REM SPAl"4L:0 GN B 480NpSFCS ONDE2E
REGELS4830 GOSUB              :REM INSTRUCT
N148 H8aW RN48 GS-20 REM' I WACHOX SEC0)EN
5210 :
5220
NI 3R1EH9)u$B 34T0RAW:230 RE R14T0 :
5400 REM SUBR SPATIE
F
0"420 HO=2:VE=23:GN B 110
543(RI

)
Rn op de SPATIEBALK voor tvolg";:GN B 580-2:
GOSUB 21)F IN$<0U"01R4O:5114O(

RETG0"460
5= REM SUC: BELP: T0
5610 :
3UNGN882
NEOAO lN0T 95R0:0
O:67G4 <"ALFaLDH"
X:
HO=16:VE=11:GN B 110
5650 $8 :
N lB=T
"4OrIOWTCIOUTO0000:GN B 20)F IN$<0B
N E00 NEL:=
































 
NEXT
S-S380 RETURN
5690 :
5800 REM  BR BUFFER LEEGMAKEN
581S0
582F :R0:TI
:-$<><HEN 5820
5830 RETURN
5840 1OF
REM SUBR INVO)r 0E=o2EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE1O10 A$R1
6120
:R0:UB; NI  T0TO ML:$8 ARFT91KS H7F6 
GOSUB 110OFOONGB 5800:R:0WGE1
1a00"150 GN :"0:GBH0)823ODF GB=13 THEN 6260
FO)O G7"nR 
UAND A$=""T=H3150OFeIO G7"nWADL THEN 6220
6180 t
V,6I=1 THPT4
"":o6200
FG0T4
1W"36T6 
(A$)1)
*N
GOSUB 1200 NR0 ":GOSUB 110O*J P < " WSF :R0:UB  
NR0 ":GOSUB 110O*iONoO 6140
GIO
LEN(A$0ML OR GO$3UE0H3250
6230 IF(GB>I  =) GOEO)CTHEN 6250
6240Q S
3FT4
3EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE$:GOTO 6150
6

GN B 250:GOTO"50O*30 RETURN
6270 :
6400 REM SUBR JA <0EE"OrnS5
6420 ML=3:GOSUB"00
rIe:NiEFT$(A J)
6440 Y=-1Or :0F OB$=EWOR OB$=r; N E0P:9ESX::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
OB0"N"OR OB$="n"THP:9
OrS  
RETURN
rS"
:
7000000000000000000000000000000000R:CNITI0)SERING
7010 DIM W3G
,6 W A0N3G
D
70200Ev"                                        "
7030 HL=0)(HRIASC(E0$ODF HL<0 THEN H
-HL
7040 GOSUB00eIG 
GN 
:GN  55=
706IO= AE
7:GOSUB 11StO070 PRO
n2n hoogstens tiE VTorden in,"
7080 $8  eEBtmet TEVa MTaOES 0ES
TE
0
e (s."eIT0SRINT:P <"H
PRB1Jnt ni
H
0NOOTN0OH 1OO0  R tNe VFM
710(RI
 2R0OlekeE  ters zi3E"="eW10 PRINT:PRINT"Nadat    
eAKN AIen I k  igetikt, zl"
7I7G4:1de com9Nter ze sorte 8
11
RBUP <:P <"TiOE"Nd 1OG<1(akter i wat aN(b8N0F
T
7122 P <"om een kraker te 92+sE 61S5R0:TWtT3) 
 
682300
717NGN B 5=
7:
GN  55=:GN  55555555555555555555555555555555555555555555555555eW50 o1100
71
:
100000 REM"ALPHABETISCHORTEREN     "0
=10 :

20 REM EEN PRO4Q1:VAN :
10030 REM"     And 0AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAhapman        "
10040 RE60V(RT"0
SSNpSR6O:01erry  TEFE
3R :(I30A:1
8NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNaG 5PRR0EU o 
0DHI210
=70 REM            &
8N0REM"    Richard G Warner       "0
=90
101 R:7ORSPRONKELIJK GE U1JA1="0
E0

REM         VQl"0
U
R:1BI UN  
8E A mi4K29  :EBt("
10130 10
EO0TE5O lASSTVoB"J
REM 'EENVOUDIG  BASIC
8-I8aG EN GESCO  GEMAAKT Vm"0
 H8G"BA2 )E-22odoor:     "
10
SNpSR60
 T1. Haubrich        "0

I
 REM  ECEMECRN
=:10rHUG2  VO
GEMAAKT VOOR0
EeI8aG"BASICODE-2       door:     "0
EG0SN51        . Haub
$N (I"
10