1000 PRINT TAB(32);"ROULETTE"
1010 PRINT TAB(15);"CREATIVE COMPUTING  MORRISTOWN, NEW JERSEY"
1020 PRINT:PRINT:PRINT
1030 PRINT "ENTER THE CURRENT DATE (AS IN 'SEPTEMBER 23, 1987') -";
1040 INPUT D$,E$
1050  REM-ROULETTE
1060  REM-DAVID JOSLIN
1070  PRINT "WELCOME TO THE ROULETTE TABLE"
1080  PRINT 
1090  PRINT "DO YOU WANT INSTRUCTIONS";
1100 INPUT Y$
1110 IF LEFT$(Y$,1)="N" THEN 1600
1120  PRINT 
1130  PRINT "THIS IS THE BETTING LAYOUT"
1140  PRINT "  (*=RED)"
1150  PRINT 
1160  PRINT " 1*    2     3*"
1170  PRINT " 4     5*    6 "
1180  PRINT " 7*    8     9*"
1190  PRINT "10    11    12*"
1200  PRINT "---------------"
1210  PRINT "13    14*   15 "
1220  PRINT "16*   17    18*"
1230  PRINT "19*   20    21*"
1240  PRINT "22    23*   24 "
1250  PRINT "---------------"
1260  PRINT "25*   26    27*"
1270  PRINT "28    29    30*"
1280  PRINT "31    32*   33 "
1290  PRINT "34*   35    36*"
1300  PRINT "---------------"
1310  PRINT "    00    0    "
1320  PRINT :INPUT "PRESS <RETURN> TO GO ON";X
1330  PRINT "TYPES OF BETS"
1340  PRINT 
1350  PRINT "THE NUMBERS 1 TO 36 SIGNIFY A STRAIGHT BET"
1360  PRINT "ON THAT NUMBER"
1370  PRINT "THESE PAY OFF 35:1"
1380  PRINT 
1390  PRINT "THE 2:1 BETS ARE:"
1400  PRINT " 37) 1-12     40) FIRST COLUMN"
1410  PRINT " 38) 13-24    41) SECOND COLUMN"
1420  PRINT " 39) 25-36    42) THIRD COLUMN"
1430  PRINT 
1440  PRINT "THE EVEN MONEY BETS ARE:"
1450  PRINT " 43) 1-18     46) ODD"
1460  PRINT " 44) 19-36    47) RED"
1470  PRINT " 45) EVEN     48) BLACK"
1480  PRINT 
1490  PRINT " 49)0 AND 50)00 PAY OFF 35:1"
1500  PRINT " NOTE: 0 AND 00 DO NOT COUNT UNDER ANY"
1510  PRINT "       BETS EXCEPT THEIR OWN"
1520  PRINT :INPUT "PRESS <RETURN> TO GO ON";X
1530  PRINT "WHEN I ASK FOR EACH BET,TYPE THE NUMBER"
1540  PRINT "AND THE AMOUNT,SEPERATED BY A COMMA"
1550  PRINT "FOR EXAMPLE:TO BET $500 ON BLACK,TYPE 48,500"
1560  PRINT "WHEN I ASK FOR A BET"
1570  PRINT 
1580  PRINT "MINIMUM BET IS $5,MAXIMUM IS $500"
1590  PRINT 
1600  REM-PROGRAM BEGINS HERE
1610  REM-TYPE OF BET(NUMBER) ODDS
1620 REM
1630  DIM B(100),C(100),T(100),X(38)
1640  DIM A(50)
1650 FOR I=1 TO 38: X(I)=0: NEXT I: REM  MAT X=ZER
1660  P=1000
1670  D=100000!
1680  PRINT "HOW MANY BETS";
1690  INPUT Y
1700  IF Y<1 OR Y<>INT(Y) THEN 1680
1710 FOR I=1 TO 50: A(I)=0: NEXT I: REM  MAT A=ZER
1720  FOR C=1 TO Y
1730  PRINT "NUMBER";C;
1740  INPUT X,Z
1750  B(C)=Z
1760  T(C)=X
1770  IF X<1 OR X>50 OR X<>INT(X) THEN 1730
1780  IF Z<1 OR Z<>INT(Z) THEN 1730
1790  IF Z<5 OR Z>500 THEN 1730
1800  IF A(X)=0 THEN 1830
1810  PRINT "YOU MADE THAT BET ONCE ALREADY,DUM-DUM"
1820  GOTO 1730
1830  A(X)=1
1840  NEXT C
1850  PRINT "SPINNING"
1860  PRINT 
1870  PRINT 
1880  S=INT(RND(1)*100)
1890  IF S=0 OR S>38 THEN 1880
1900  X(S)=X(S)+1
1910  IF S<37 THEN 1970
1920  IF S=37 THEN 1950
1930  PRINT "00"
1940  GOTO 2070
1950  PRINT "0"
1960  GOTO 2070
1970  RESTORE 
1980 FOR I1=1 TO 18
1990  READ R
2000  IF R=S THEN 2050
2010 NEXT I1
2020  A$="BLACK"
2030  PRINT S;A$
2040  GOTO 2070
2050  A$="RED"
2060  GOTO 2030
2070  PRINT 
2080  FOR C=1 TO Y
2090  IF T(C)<37 THEN 2760
2100 ON T(C)-36 GOTO 2140,2240,2270,2300,2350,2400,2450,2520,2550
2110  ON T(C)-45 GOTO 2580,2610,2680
2120  GOTO 2760
2130  STOP 
2140  REM  1-12(37) 2:1
2150  IF S <= 12 THEN 2200
2160  PRINT "YOU LOSE";B(C);"DOLLARS ON BET ";C
2170  D=D+B(C)
2180  P=P-B(C)
2190  GOTO 2230
2200  PRINT "YOU WIN ";B(C)*2;"DOLLARS ON BET "C
2210  D=D-B(C)*2
2220  P=P+B(C)*2
2230  GOTO 2860
2240  REM  13-24(38) 2:1
2250  IF S>12 AND S<25 THEN 2200
2260  GOTO 2160
2270  REM  25-36(39) 2:1
2280  IF S>24 AND S<37 THEN 2200
2290  GOTO 2160
2300  REM  FIRST COLUMN(40) 2:1
2310  FOR I=1 TO 34 STEP 3
2320  IF S=I THEN 2200
2330  NEXT I
2340  GOTO 2160
2350  REM  SECOND COLUMN(41) 2:1
2360  FOR I=2 TO 35 STEP 3
2370  IF S=I THEN 2200
2380  NEXT I
2390  GOTO 2160
2400  REM  THIRD COLUMN(42) 2:1
2410  FOR I=3 TO 36 STEP 3
2420  IF S=I THEN 2200
2430  NEXT I
2440  GOTO 2160
2450  REM  1-18(43) 1:1
2460  IF S<19 THEN 2480
2470  GOTO 2160
2480  PRINT "YOU WIN ";B(C);"DOLLARS ON BET ";C
2490  D=D-B(C)
2500  P=P+B(C)
2510  GOTO 2860
2520  REM  19-36(44) 1:1
2530  IF S<37 AND S>18 THEN 2480
2540  GOTO 2160
2550  REM  EVEN(45) 1:1
2560  IF S/2=INT(S/2) AND S<37 THEN 2480
2570  GOTO 2160
2580  REM  ODD(46) 1:1
2590  IF S/2<>INT(S/2) AND S<37 THEN 2480
2600  GOTO 2160
2610  REM  RED(47) 1:1
2620  RESTORE 
2630  FOR I=1 TO 18
2640  READ R
2650  IF S=R THEN 2480
2660  NEXT I
2670  GOTO 2160
2680  REM  BLACK(48) 1:1
2690  RESTORE 
2700  FOR I=1 TO 18
2710  READ R
2720  IF S=R THEN 2160
2730  NEXT I
2740  IF S>36 THEN 2160
2750  GOTO 2480
2760  REM--1TO36,0,00(1-36,49,50)35:1
2770  IF T(C)<49 THEN 2810
2780  IF T(C)=49 AND S=37 THEN 2830
2790  IF T(C)=50 AND S=38 THEN 2830
2800  GOTO 2160
2810  IF T(C)=S THEN 2830
2820  GOTO 2160
2830  PRINT "YOU WIN ";B(C)*35;"DOLLARS ON BET";C
2840  D=D-B(C)*35
2850  P=P+B(C)*35
2860 NEXT C
2870  PRINT 
2880  PRINT "TOTALS:","ME","YOU"
2890  PRINT " ",D,P
2900  IF P>0 THEN 2930
2910  PRINT "OOPS! YOU JUST SPENT YOUR LAST DOLLAR"
2920  GOTO 3240
2930  IF D>0 THEN 2970
2940  PRINT "YOU BROKE THE HOUSE!"
2950  P=101000!
2960  GOTO 3010
2970  PRINT "AGAIN";
2980 INPUT Y$
2990 IF LEFT$(Y$,1)="Y" THEN 1680
3000  DATA 1,3,5,7,9,12,14,16,18,19,21,23,25,27,30,32,34,36
3010  IF P<1 THEN 3240
3020  PRINT "TO WHOM SHALL I MAKE THE CHECK";
3030  INPUT B$
3040  PRINT 
3050 FOR I=1 TO 62: PRINT "-";: NEXT I: REM PRINT 72 DASHES
3060  PRINT TAB(50)"CHECK NO. ";INT(RND(1)*100)
3070  PRINT 
3080  GOSUB 3280
3090 PRINT TAB(40);M$
3100  PRINT 
3110  PRINT 
3120  PRINT "PAY TO THE ORDER OF-----";B$;"-----$ ";
3130  PRINT P
3140  PRINT 
3150  PRINT 
3160  PRINT TAB(10),"THE MEMORY BANK OF VIRGINIA"
3170  PRINT 
3180  PRINT TAB(40),"THE COMPUTER"
3190  PRINT TAB(40)"----------X-----"
3200  PRINT 
3210 FOR I=1 TO 62: PRINT "-";: NEXT I
3220  PRINT "COME BACK SOON!"
3230  GOTO 3260
3240  PRINT "THANKS FOR YOUR MONEY"
3250  PRINT "I'LL USE IT TO BUY A SOLID GOLD ROULETTE WHEEL"
3260  PRINT
3270  GOTO 3380
3280 REM
3290 REM     THIS ROUTINE RETURNS THE CURRENT DATE IN M$
3300 REM     IF YOU HAVE SYSTEM FUNCTIONS TO HANDLE THIS
3310 REM     THEY CAN BE USED HERE.  HOWEVER IN THIS
3320 REM     PROGRAM, WE JUST INPUT THE DATE AT THE START
3330 REM     THE GAME
3340 REM
3350 REM     THE DATE IS RETURNED IN VARIABLE M$
3360 M$=D$+", "+E$
3370 RETURN
3380 REM RUN"MENU
3390 SYSTEM

3340 REM
3