rem  con
pt be de2 programs to mere a 
ren:
ne CB80 pn:e o fedgSn:
cihkk Weven 
ci pn)
	ikp%	zmputerahd
ru$rdgs



gs

r$i								 filames --------------------------
gs
	filey).f$i(indas"
	fileg=commande".>in 
	fii
kott$i(eno $
"
	ftoy1fh)b
r .dat"i le5$="function.dat"


c$i	rnnu feafns                         